#
# spec file for package yast2-bootloader
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           yast2-bootloader
VCS: https://src.suse.de/SLFO-pool/yast2-bootloader#3bbb3b048fa485cfef5446e006be76eee424e28e9a7d16284c378e93e0f32757
Version:        5.0.15
Release:        160000.1.5
Summary:        YaST2 - Bootloader Configuration
License:        GPL-2.0-or-later
Group:          System/YaST
URL:            https://github.com/yast/yast-bootloader
Source0:        %{name}-%{version}.tar.bz2

# ReducedRecorder
BuildRequires:  yast2 >= 4.5.16
BuildRequires:  yast2-devtools >= 4.2.2
# yast/rspec/helpers.rb
BuildRequires:  yast2-ruby-bindings >= 4.4.7
# BlkDevice#preferred_name and Filesystems::BlkFilesystem#preferred_name
BuildRequires:  yast2-storage-ng >= 4.3.36
# lenses needed also for tests
BuildRequires:  augeas-lenses
BuildRequires:  update-desktop-files
BuildRequires:  rubygem(%rb_default_ruby_abi:cfa_grub2) >= 1.0.1
BuildRequires:  rubygem(%rb_default_ruby_abi:rspec)
BuildRequires:  rubygem(%rb_default_ruby_abi:yast-rake)

PreReq:         %fillup_prereq
PreReq:         /bin/sed
# Base classes for inst clients
Requires:       parted
# ReducedRecorder
Requires:       yast2 >= 4.5.16
Requires:       yast2-core >= 2.18.7
Requires:       yast2-packager >= 2.17.24
Requires:       yast2-pkg-bindings >= 2.17.25
# Y2Storage::Arch#efibootmgr?
Requires:       yast2-storage-ng >= 4.4.22
# Support for multiple values in GRUB_TERMINAL
Requires:       rubygem(%rb_default_ruby_abi:cfa_grub2) >= 1.0.1
# lenses are needed as cfa_grub2 depends only on augeas bindings, but also
# lenses are needed here
Requires:       augeas-lenses
Requires:       yast2-ruby-bindings >= 1.0.0

# only recommend syslinux, as it is not needed when generic mbr is not used (bsc#1004229)
%ifarch %ix86 x86_64
Recommends:     syslinux
%endif

Supplements:    autoyast(bootloader)

%description
This package contains the YaST2 component for bootloader configuration.

%prep
%setup -q

%check
%yast_check

%build

%install
%yast_install
%yast_metainfo

%post
%{fillup_only -n bootloader}

%files
%license COPYING
%doc %{yast_docdir}
%{yast_desktopdir}
%{yast_moduledir}
%{yast_clientdir}
%{yast_ybindir}
%{yast_scrconfdir}
%{yast_schemadir}
%{yast_libdir}
%{_fillupdir}/sysconfig.bootloader.*
%{_datadir}/metainfo/org.opensuse.yast.Bootloader.metainfo.xml
%{_datadir}/icons/hicolor/*/apps/yast-bootloader*

%changelog
* Thu Feb 27 2025 schubi@suse.de
- Enabled secure boot for grub2-bls (jsc#PED-10703).
* Thu Jan  9 2025 schubi@suse.de
- Added grub2-bls support (jsc#PED-10703).
- 5.0.14
* Fri Dec 20 2024 jreidinger@suse.com
- Always filter out from installation parameters "root=" as it
  needs to be always changed to installed system (bsc#1234678)
- 5.0.13
* Tue Nov  5 2024 jreidinger@suse.com
- Sync warning text from s390 secure boot to be identical in
  installation proposal and on running system (bsc#1219989)
- 5.0.12
* Wed Aug 14 2024 jreidinger@suse.com
- add arm and riscv64 as not supported for secure boot
  (bsc#1229070)
- 5.0.11
* Fri Jul 19 2024 aplanas@suse.com
- Rename menue_timeout (menü) to menu_timeout
- Reference in text messages to menu
* Fri May  3 2024 schubi@localhost
- Writing "root" entry into /etc/kernel/cmdline which is needed by
  sdbootutil. (still for bsc#1220892)
- 5.0.10
* Fri Apr 26 2024 schubi@suse.com
- Creating kernel options for systemd-boot. (bsc#1220892)
- 5.0.9
* Fri Apr  5 2024 jreidinger@suse.com
- Follow up of previous change to use even more precise wording
  (bsc#1219989,bsc#1222353)
- 5.0.8
* Fri Mar 15 2024 jreidinger@suse.com
- Improve warnings and help text for secure boot on s390 to reflect
  state with new hardware. (bsc#1219989)
- 5.0.7
* Mon Feb 26 2024 schubi@suse.com
- Feature: Do not timeout boot menue in systemd-boot. (bsc#1216366)
- 5.0.6
* Tue Feb 20 2024 schubi@suse.com
- Proposal: Trying to take the bootloader which has been defined in
  the product description file (entry globals/prefered_bootloader)
  (jsc#PED-1906)
- 5.0.5
* Thu Jan 25 2024 kanderssen@suse.com
- Persist s390 cio_ignore kernel argument always when given
  (bsc#1210525).
- 5.0.4
* Wed Jan 10 2024 jreidinger@suse.com
- Do not try finding undefined bootloader name to avoid error
  in logs (bsc#1218700)
- 5.0.3
* Mon Sep  4 2023 schubi@suse.com
- Fixed testsuite for architectures other than x86_64.
- 5.0.2
* Thu Aug 31 2023 schubi@suse.com
- Supporting systemd-boot for architecture x86_64.
  This feature can be enabled/disabled by the "enable_systemd_boot"
  flag in the product description file for each product
  (default is disabled).
- 5.0.1
* Wed Aug 30 2023 jreidinger@suse.cz
- 5.0.0 (#bsc1185510)
* Mon Aug  7 2023 snwint@suse.com
- support 32 bit UEFI firmware on x86_64/i386 architecture (bsc#1208003,
  jsc#PED-2569)
- 4.6.3
* Thu Jun 15 2023 jlopez@suse.com
- Persist zfcp.allow_lun_scan kernel option for s390 arch
  (needed for gh#openSUSE/agama#626).
- 4.6.2
* Tue Apr 25 2023 jreidinger@suse.com
- Do not overwrite user selection during migration (bsc#1210811)
- 4.6.1
* Fri Mar  3 2023 lslezak@suse.cz
- Bump version to 4.6.0 (bsc#1208913)
* Wed Feb  8 2023 jreidinger@suse.com
- make secure boot for ppc64 consistent with how secure boot works
  on other architectures (bsc#1206295)
- 4.5.8
* Wed Oct  5 2022 jreidinger@suse.com
- prevent leak of grub2 password to logs(bsc#1201962)
- 4.5.7
* Wed Sep 21 2022 jreidinger@suse.com
- write stage1 location on transactional systems (bsc#1128853)
- 4.5.6
* Wed Sep 21 2022 mfilka@suse.com
- bsc#1203418
  - added default proposal for hidden timeout
- 4.5.5
* Mon Sep 12 2022 jreidinger@suse.com
- Allow bootloader to run on transactional systems (bsc#1128853)
- 4.5.4
* Thu Aug 11 2022 snwint@suse.com
- adjust trusted boot help text (bsc#1197608)
- 4.5.3
* Mon Jul 25 2022 ancor@suse.com
- Execute the command grub2-mkpasswd-pbkdf2 in the target system
  so the module can run in a minimal container (bsc#1199840).
- 4.5.2
* Thu Apr  7 2022 jreidinger@suse.com
- AutoYaST: do not clone device for hibernation and also check
  during autoinstallation if device for hibernation exists and if
  not then use proposed one. (bsc#1187690 and bsc#1197192)
- 4.5.1
* Wed Apr  6 2022 lslezak@suse.cz
- Bump version to 4.5.0 (bsc#1198109)
* Fri Jan 28 2022 jreidinger@suse.com
- Allow product/system role to select boot timeout (jsc#SLE-22667)
- 4.4.16
* Tue Jan 25 2022 igonzalezsosa@suse.com
- Use Package module instead of PackageSystem (bsc#1194886).
- 4.4.15
* Fri Jan 21 2022 lslezak@suse.cz
- Unify YaST module mocking in unit tests (related to bsc#1194784)
- 4.4.14
* Mon Jan 17 2022 jreidinger@suse.com
- Autoyast: add support for password protection (jsc#SLE-20928)
- 4.4.13
* Mon Jan 17 2022 msuchanek@suse.com
- Add support for powerpc secure boot (bsc#1192764 jsc#SLE-18271).
- 4.4.12
* Thu Dec 23 2021 jreidinger@suse.com
- Always check tpm device for trusted boot (bsc#1193886)
- 4.4.11
* Fri Dec 10 2021 snwint@suse.com
- rely on yast-storage-ng to detect UEFI boot support status (bsc#937067)
- 4.4.10
* Thu Nov 25 2021 mfilka@suse.com
- bnc#1193016
  - fixed crash due to missing require
- 4.4.9
* Thu Nov 18 2021 mfilka@suse.com
- bnc#1092950
  - improved invalid input handling for custom boot partition
  - added support for defining custom boot partition by UUID and/or
    LABEL
- 4.4.8
* Fri Sep 10 2021 jreidinger@suse.com
- Fix calling dracut to regenerate all initrds (bsc#1189915)
- 4.4.7
* Mon Aug 16 2021 jreidinger@suse.com
- Replace mkinitrd with dracut (bsc#1189374, jsc#SLE-20347)
- 4.4.6
* Wed Jul  7 2021 shundhammer@suse.com
- Add the os-prober package to the set of packages to install
  if the package is available and supported on the arch
  (bsc#1186369)
- 4.4.5
* Fri Jun 18 2021 dmueller@suse.com
- add riscv64 support (jsc#SLE-19562)
  * done by Andreas Schwab <schwab@suse.de>
- 4.4.4
* Wed Jun  9 2021 guillaume.gardet@opensuse.org
- Enable linuxefi/initrdefi on x86 only as grub does not understand
  those commands on other archs (boo#1183795)
- 4.4.3
* Mon Jun  7 2021 guillaume.gardet@opensuse.org
- Fixes for 'arm can boot on uefi' (boo#1183795)
- 4.4.2
* Sun May 16 2021 dmueller@suse.com
- only list specific files installed in common directories (metainfo,
  icons, fillupdir) (bsc#1186066, bsc#1184786)
* Wed May 12 2021 guillaume.gardet@opensuse.org
- arm can boot on uefi (boo#1183795)
- 4.4.1
* Tue Apr 20 2021 lslezak@suse.cz
- 4.4.0 (bsc#1185510)
* Mon Apr 19 2021 jreidinger@suse.com
- Fix crash when bootloader is not managed by yast and security
  module wants to show cpu mitigation (bsc#1184968)
- 4.3.26
* Wed Mar 10 2021 jreidinger@suse.com
- Add validation to device map dialog to prevent exceeding BIOS
  limit of device map (bsc#1183218)
- 4.3.25
* Thu Mar  4 2021 jreidinger@suse.com
- Fix boot summary on s390 (bsc#1181801 and bsc#1179168)
- 4.3.24
* Wed Mar  3 2021 jreidinger@suse.com
- Respect if efivars is mounted read only (bsc#1174111,
  bsc#1182749)
- 4.3.23
* Mon Feb 15 2021 jreidinger@suse.com
- Adapted unit test to recent changes in Yast::Report (related to
  bsc#1179893).
- 4.3.22
* Tue Feb  9 2021 jreidinger@suse.com
- use shim for secure boot also on aarch64 (jsc#SLE-15020)
- 4.3.21
* Wed Jan 27 2021 jlopez@suse.com
- Do not propose resume kernel parameter when the swap is smaller
  than the RAM size (bsc#1180977).
- 4.3.20
* Tue Jan 26 2021 ancor@suse.com
- Ensure the proposal is re-calculated when the partitioning plan
  has changed (bsc#1180218 and bsc#1180976)
- 4.3.19
* Thu Jan 21 2021 jlopez@suse.com
- Fix unit tests (bsc#1181175).
- 4.3.18
* Tue Jan 12 2021 ancor@suse.com
- The logic for calculating a device udev link is now delegated to
  the yast2-storage-ng module (jsc#SLE-17081, also related to
  bsc#1177926 and bsc#1169874).
- 4.3.17
* Mon Nov 16 2020 jreidinger@suse.com
- Make wording in summary more consistent
  (related to jsc#SLE-16033)
- 4.3.16
* Thu Nov 12 2020 jreidinger@suse.com
- Use shared Yast::Kernel.propose_hibernation? method when
  proposing kernel parameters (jsc#SLE-12280)
- 4.3.15
* Thu Nov  5 2020 jreidinger@suse.com
- Improve wording in summary to see where boot code is written
  (jsc#SLE-16033)
- allow to specify extended or logical partition when boot from
  partition (bsc#1165042)
- 4.3.14
* Thu Oct 22 2020 jreidinger@suse.com
- "write proper value for NVRAM for UEFI (bsc#1157550)"
- fix failing test on s390 (bsc#1177986)
- 4.3.13
* Thu Oct  8 2020 jreidinger@suse.com
- Fix definition of initrd_module in AutoYaST schema (bsc#1177058)
- 4.3.12
* Tue Sep 29 2020 igonzalezsosa@suse.com
- Drop the 'suse_btrfs' element from the AutoYaST schema
  (bsc#1176970).
- 4.3.11
* Wed Sep 23 2020 msuchanek@suse.com
- Add UPDATE_NVRAM in /etc/sysconfig/bootloader (bsc#1157550,
  jsc#SLE-11500).
- 4.3.10
* Mon Sep 14 2020 jreidinger@suse.com
- merge SLE15 SP2 changes:
-- fix detection of present of efivars causing grub2-install
  failures on some arm boards (bsc#1172114)
-- add workaround for ARM to make GRUB2 works for
  every device. It can potentially break multi-boot (bsc#1167015)
- 4.3.9
* Tue Aug 11 2020 schubi@suse.de
- AutoYaST: Added supplements: autoyast(bootloader) into the spec file
  in order to install this packages if the section has been defined
  in the AY configuration file (bsc#1146494).
- 4.3.8
* Thu Jul 23 2020 snwint@suse.com
- add rd.zdev to allowed kernel options on s390 (bsc#1168036)
- 4.3.7
* Thu Jun 18 2020 jlopez@suse.com
- Avoid random failure in unit tests when there is a serial
  console.
- Related to bsc#1172390.
- 4.3.6
* Wed Jun 10 2020 igonzalezsosa@suse.com
- AutoYaST: import AutoInstall only when needed (related to
  bsc#1171335).
- 4.3.5
* Wed Jun 10 2020 schubi@suse.com
- AutoYaST: Cleanup/improve issue handling (bsc#1171335).
- 4.3.4
* Wed Jun  3 2020 snwint@suse.com
- update comments in /etc/sysconfig/bootloader (bsc#1171912)
- 4.3.3
* Mon May 25 2020 snwint@suse.com
- s390 secure boot: enhance disk type detection to cover multipath
  (bsc#1171821)
- 4.3.2
* Thu May  7 2020 jreidinger@suse.com
- Autoyast schema: Allow optional types for string and map objects
  (bsc#1170886)
- 4.3.1
* Thu May  7 2020 igonzalezsosa@suse.com
- Set the AutoInstClonable attribute in the desktop file(related
  to bsc#1171356).
- 4.3.0
* Wed Apr 15 2020 snwint@suse.com
- update s390x secure boot message (bsc#1168165)
- 4.2.22
* Thu Apr  2 2020 snwint@suse.com
- limit s390 secure boot to SCSI disks (bsc#1168165)
- 4.2.21
* Fri Mar 27 2020 ancor@suse.com
- Reverted the changes to delegate to yast2-storage-ng the
  calculation of udev links. See previous entries for versions
  4.2.16 and 4.2.19.
- This fixes bsc#1167779 and is related to bsc#1166096 and
  bsc#1151075.
- 4.2.20
* Wed Mar 25 2020 ancor@suse.com
- Fixed the calculation of the udev name used to reference devices
  that are not formatted, like PReP partitions (bsc#1166096).
- 4.2.19
* Tue Mar 24 2020 snwint@suse.com
- support s390 secure boot (jsc#SLE-9425, jsc#SLE-9471, bsc#1166736)
- 4.2.18
* Fri Feb 28 2020 snwint@suse.com
- add support for S390 secure boot (jsc#SLE-9471, jsc#SLE-9425)
- 4.2.17
* Fri Feb 21 2020 jlopez@suse.com
- Delegate the logic for calculating a device udev link to
  yast2-storage-ng module (related to bsc#1151075).
- 4.2.16
* Fri Jan  3 2020 jreidinger@suse.com
- deduplicate kernel parameters after merging them
  (bsc#1130954, bsc#1043103, bsc#1132328, bsc#1134895)
- 4.2.15
* Mon Dec 30 2019 jreidinger@suse.com
- Report proper error when /etc/default/grub missing and allow
  user to repropose it (bsc#1100755)
- 4.2.14
* Tue Nov 26 2019 dgonzalez@suse.com
- Abort the execution when the module run without enough
  permissions (related to bsc#1137688).
- 4.2.13
* Wed Nov 20 2019 ancor@suse.com
- Improved detection of the root filesystem in non-standard
  btrfs configurations (bsc#1151748, bsc#1124581).
- If there is no file system mounted in "/" or "/boot", report the
  error and quit instead of crashing.
- 4.2.12
* Mon Sep 30 2019 jreidinger@suse.com
- Add to autoyast ability to set secure boot flag for UEFI
  (jsc#SLE-8787)
- 4.2.11
* Tue Aug 27 2019 schubi@suse.de
- Set X-SuSE-YaST-AutoInstResource in desktop file (bsc#144894).
- 4.2.10
* Thu Jul 25 2019 jreidinger@suse.com
- Fix testsuite on AArch64. Related to changes done for boo#1136601
- 4.2.9
* Wed Jul 24 2019 ancor@suse.com
- Better handling of broken bootloader configurations during the
  upgrade process (bsc#1138930).
- 4.2.8
* Fri Jul 19 2019 lslezak@suse.cz
- Added "BuildRequires: update-desktop-files"
- Related to the previous desktop file changes (fate#319035)
- 4.2.7
* Tue Jul  2 2019 guillaume.gardet@opensuse.org
- Replace --suse-signed-grub with --suse-force-signed to follow
  update from boo#1136601
- 4.2.6
* Tue Jun 25 2019 jreidinger@suse.com
- adapt to new rubocop (bsc#1139270)
- 4.2.5
* Wed Jun  5 2019 guillaume.gardet@opensuse.org
- Enable Secure Boot on AArch64 (boo#1136601)
- 4.2.4
* Fri May 31 2019 hellcp@mailbox.org
- Add metainfo (fate#319035)
- Revamp spec
- Replace GenericName with Comment
- 4.2.3
* Wed May 29 2019 dgonzalez@suse.com
- Improve the readability of a technical problem description,
  splitting it in multiple lines (bsc#1136746).
- 4.2.2
* Wed May 29 2019 schubi@suse.de
- Proposal for s390: Set kernel parameters without "resume"
  parameter (JIRA#SLE-6926).
* Fri Apr 26 2019 jreidinger@suse.com
- renamed "smt" to "cpu_mitigations", improved naming and help
  (bsc#1098559)
- 4.2.1
* Thu Apr  4 2019 shundhammer@suse.com
- Propagate serial console params to XEN kernels (bsc#1080928)
- 4.2.0
* Mon Mar 25 2019 schubi@suse.de
- Removed double "smt" entry from *.rnc file (bsc#1128707).
- 4.1.23
* Mon Mar 11 2019 schubi@suse.de
- Added tag smt to *.rnc file (bsc#1128707).
- 4.1.22
* Thu Mar  7 2019 jreidinger@suse.com
- Add option to Disable Simultaneous Multithreading (bsc#1098559)
- Allow to modify bootloader configuration during upgrade
- 4.1.21
* Fri Mar  1 2019 jreidinger@suse.com
- remove resume if user wants noresume (bsc#1079537)
- use for resume the biggest mounted swap (bsc#1071354)
- make help text formatting consistent and improve some help texts
- 4.1.20
* Wed Feb 27 2019 mvidner@suse.com
- Use the correct path for /usr/bin/mkdir (bsc#1127138).
- 4.1.19
* Thu Feb 21 2019 jreidinger@suse.com
- Relax check for bios_boot when logical device over more disks is
  used to check that at least one disk can be bootable.
  (bsc#1125792)
- Also relax installation of grub2. When at least one location
  success then do not complain, just log it.
- 4.1.18
* Thu Feb 14 2019 jreidinger@suse.com
- Do not crash if generated grub.cfg is missing (bsc#1124064)
- 4.1.17
* Fri Feb  8 2019 dgonzalez@suse.com
- Improve the layout of "Boot Code Options" tab (bsc#1120793)
- 4.1.16
* Wed Feb  6 2019 shundhammer@suse.com
- Improved error message for broken by-path device names (bsc#1122008)
- 4.1.15
* Fri Jan 25 2019 dgonzalez@suse.com
- Fit the "Boot Code Options" tab to full width even when there only
  is the BootLoader selector (bsc#1120793)
- 4.1.14
* Tue Dec  4 2018 jreidinger@suse.com
- always use absolute path to binaries (bsc#1118291)
- escape properly shell arguments (bsc#1118291)
- do not show grub2 password in list of processes when encrypting
  (bsc#1118291)
- 4.1.13
* Sat Nov 24 2018 hellcp@mailbox.org
- Provide icon with module (boo#1109310)
- 4.1.12
* Tue Oct 23 2018 jreidinger@suse.com
- Do not crash if an unknown device is found in a cloned configuration
  (bsc#1111236)
- 4.1.11
* Tue Oct 16 2018 schubi@suse.de
-  Fixed path to license file. . Build error in bsc#1089829.
- 4.1.10
* Wed Aug 29 2018 dgonzalez@suse.com
- Do not crash when required package is not installed (bsc#1089829)
- 4.1.9
* Wed Aug 22 2018 schubi@suse.de
- Switched license in spec file from SPDX2 to SPDX3 format.
* Tue Aug 21 2018 schubi@suse.de
- Changed dir of COPYING file.
* Tue Aug 21 2018 jreidinger@suse.com
- Update: Do not crash in detection of gpt disks when some disk
  disappear (bsc#1105351 )
- 4.1.8
* Wed Aug 15 2018 mfilka@suse.com
- bnc#1053559
  - do not crash with internal error when GRUB_TERMINAL contains
    multiple values
- 4.1.7
* Fri Jul 20 2018 schubi@suse.de
- Update: Fixed crash while reading grub settings from installed
  system (bsc#1094031).
- 4.1.6
* Thu Jun 28 2018 schubi@suse.de
- Added additional searchkeys to desktop file (fate#321043).
- 4.1.5
* Thu Jun 14 2018 jreidinger@suse.com
- Warn user when updating with different boot technology
  (bsc#1081355)
- 4.1.4
* Tue Jun 12 2018 jreidinger@suse.com
- Do not propose obsolete kernel parameters (bsc#1047222)
- 4.1.3
* Fri Jun  8 2018 jreidinger@suse.com
- fix typo in parted path (bsc#1030620)
- 4.1.2
* Thu Jun  7 2018 jreidinger@suse.com
- Use full path to parted (bsc#1030620)
- 4.1.1
* Wed May 30 2018 jreidinger@suse.com
- Fix detection of GPT disk to properly set pmbr flag (bsc#1093887)
- 4.1.0
* Thu May 17 2018 jreidinger@suse.com
- Extend fix for BIOS RAIDs to work with more complex setup when
  system contain also physical partitions (bsc#1092417)
- 4.0.34
* Mon May 14 2018 jreidinger@suse.com
- Propose fips boot parameter if it is used for installation
  on s390 (bsc#1043029)
- 4.0.33
* Thu May 10 2018 jreidinger@suse.com
- Fix installation on BIOS Raid like Intel RSTe (bsc#1091283)
- 4.0.32
* Tue May  8 2018 knut.anderssen@suse.com
- Use "none" bootloader when the boot filesystem is nfs
  (bsc#1090752).
- 4.0.31
* Tue May  8 2018 jreidinger@suse.com
- Make unit tests architecture agnostic (related to bsc#1091284).
- 4.0.30
* Fri May  4 2018 jreidinger@suse.com
- Inform user when an unsupported bootloader is defined in the
  AutoYaST profile, display the valid values (bsc#1091284)
- 4.0.29
* Wed May  2 2018 jreidinger@suse.com
- Fix test failure on s390 (no functionality change)(bsc#1091631)
- 4.0.28
* Tue Apr 24 2018 jreidinger@suse.com
- Do not crash when clicking on booting during upgrade
  (bsc#1070233)
- 4.0.27
* Tue Apr 24 2018 jreidinger@suse.com
- Propose net.ifnames boot parameter if it is used for installation
  on s390 (bsc#1086665)
- 4.0.26
* Tue Apr 24 2018 jreidinger@suse.com
- Show understandable popup when grub2 terminal option contain
  complex string that is not yet supported (bsc#1053559)
- 4.0.25
* Wed Mar 21 2018 mfilka@suse.com
- bnc#1083938
  - missing translation
- 4.0.24
* Tue Mar 20 2018 jlopez@suse.com
- Fix tests to not create zero size partitions
  (part of bsc#1083887).
- 4.0.23
* Wed Mar 14 2018 jreidinger@suse.com
- fix detection of kernel name for alternative raid names (it
  ensures that fix for bsc#944041 works)
- 4.0.22
* Mon Mar 12 2018 jreidinger@suse.com
- Respect if custom boot is logical volume and display it
  correctly (bsc#1084815)
- 4.0.21
* Wed Mar  7 2018 jreidinger@suse.com
- do not repropose configuration in autoyast confirm mode
  (bsc#1081967)
- fix setting pmbr flag in autoyast (bsc#1081967)
- 4.0.20
* Fri Feb 23 2018 igonzalezsosa@suse.com
- Remove calls to the old yast2-storage layer (bsc#1071978)
- 4.0.19
* Thu Feb 15 2018 jreidinger@suse.com
- fix nil exception for device with filesystem that is not mounted
  (bsc#1081018)
- 4.0.18
* Mon Feb 12 2018 jreidinger@suse.com
- Detect properly that unknown device is used in bootloader
  configuration (bsc#1078713)
- 4.0.17
* Fri Feb  9 2018 jlopez@suse.com
- Adapt to new MountPoint API (part of fate#318196).
- 4.0.16
* Tue Feb  6 2018 jreidinger@suse.com
- Fix activating partition by UUID or label (bsc#1077427,
  bsc#1076424)
- 4.0.15
* Tue Jan 30 2018 jreidinger@suse.com
- fix crash when clicking link in proposal (bsc#1078227)
- 4.0.14
* Tue Jan 16 2018 jreidinger@suse.com
- fix crash for getting partition to activate when stage1 device
  is disk (bsc#1076121)
- 4.0.13
* Fri Jan 12 2018 jsrain@suse.cz
- fix typo in function name (bsc#1075725)
- 4.0.12
* Tue Jan  9 2018 ancor@suse.com
- Rely on the new Y2Storage::Devicegraph#find_by_any_name when
  matching udev names to their corresponding kernel device names
  (bsc#1073254).
- 4.0.11
* Wed Jan  3 2018 jreidinger@suse.com
- Legacy (non-EFI) x86: Fixed multi-device booting problems
  (mostly RAID, also LVM and multipath). Now the boot loader is
  written to ALL physical devices that host the boot partition
  (or the MBR). Before, only one of them was picked and the BIOS
  could pick a different one to boot from. (bsc#1072908)
- Related UI change: "Boot Loader Location" has been simplified. We
  kept the option "Boot from Master Boot Record", but the remaining
  three options, for booting from the Boot, Root, or
  Extended partitions, have been unified to a single option
  "Boot from Partition".
- 4.0.10
* Mon Dec 11 2017 jreidinger@suse.com
- fix invalidation of cache causing crash (bsc#1071931)
- 4.0.9
* Tue Dec  5 2017 jreidinger@suse.com
- improve detection of md raids devices (bsc#1063957)
- 4.0.8
* Wed Nov 29 2017 jreidinger@suse.com
- Prevent crash when doing backup of boot sector (bsc#1067131)
- 4.0.7
* Tue Nov 28 2017 jreidinger@suse.com
- Do not propose boot from partition for md raids (bsc#1063957)
- 4.0.6
* Tue Nov 21 2017 gsouza@suse.com
- use correct function to detect devices (bsc#1059757)
- improve dialog to add devices in bootloader order (bsc#1060172)
- 4.0.5
* Tue Nov  7 2017 jreidinger@suse.com
- merge SLE12 SP3 fixes:
- Fix detection of upgrade of grub2 (bsc#1059603)
- Fallback to default when default section does not exists. It can
  happen during upgrade, when sections are renamed.(bsc#1059603)
- Find correct mbr device to  install grub (bsc#1039712,
  bsc#1052006)
- 4.0.4
* Fri Nov  3 2017 schubi@suse.de
- AutoYaST: Do not export stage1 settings anymore (boot_boot,
  boot_custom,...) (bnc#1063975)
- 4.0.3
* Fri Sep 15 2017 jreidinger@suse.com
- Use always kernel name for underlaying devices detection
  (caused by fix for bsc#1057604)
- 4.0.2
* Thu Sep 14 2017 jreidinger@suse.com
- fix regression to udev mapping introduced by new storage-ng
  (bsc#1057604)
- 4.0.1
* Fri Sep  8 2017 jreidinger@suse.com
- make disk order dialog wider to improve readability (bsc#1055647)
- 4.0.0
* Mon Sep  4 2017 jreidinger@suse.com
- Do not propose to stage1 to be installed to encrypted partition
  (bsc#1056862)
- 3.3.3
* Mon Aug 14 2017 gsouza@suse.com
- Allow installation of system without grub if it will not be
  used (bsc#1014167)
- 3.3.2
* Fri Aug 11 2017 snwint@suse.com
- merge storage-ng branch to master
- note: all changes below with this date belong to the merge
- 3.3.1
* Fri Aug 11 2017 snwint@suse.de
- not everything is a disk, use libstorage's partitionable instead
* Fri Aug 11 2017 ancor@suse.com
- storage-ng: adapted calls to temporary y2storage_* methods, since
  they were finally removed from Y2Storage::StorageManager.
* Fri Aug 11 2017 jlopez@suse.com
- storage-ng: adapt detection of PReP partition
* Fri Aug 11 2017 shundhammer@suse.de
- Merged master to storage-ng branch
* Fri Aug 11 2017 igonzalezsosa@suse.com
- Adapt the module to use the new storage-ng during system cloning
  (bsc#1047245)
* Fri Aug 11 2017 jreidinger@suse.com
- storage-ng:
- implement detection of encrypted boot
* Fri Aug 11 2017 jreidinger@suse.com
- storage-ng: use new wrapper API
* Fri Aug 11 2017 jreidinger@suse.com
- storage-ng: fixed proposal to not try to install to LVM
  partition
* Fri Aug 11 2017 snwint@suse.de
- storage-ng: avoid call to old libstorage
* Fri Aug 11 2017 ancor@suse.com
- storage-ng: fixed proposal to work with LVM and encrypted LVM
* Fri Aug 11 2017 ancor@suse.com
- storage-ng: simplify code by using a new query function in
  yast2-storage-ng (#with_name_or_partition)
* Fri Aug 11 2017 ancor@suse.com
- storage-ng: fixed minimal legacy proposal to work with GPT
* Fri Aug 11 2017 ancor@suse.com
- storage-ng: fixed minimal EFI proposal
- storage-ng: made minimal legacy proposal work
* Fri Aug 11 2017 aschnell@suse.com
- make simple EFI proposal work with storage-ng
* Fri Aug 11 2017 aschnell@suse.com
- storage-ng: removed dependency from (old) yast2-storage, even
  if it breaks some functionality.
* Fri Jun 23 2017 schubi@suse.de
- AutoYaST configuration: Set StorageDevices flag disks_valid
  to true. So libstorage can scan valid disks and "/" partition
  can be found. (bnc#1046738, bnc#1043132)
- 3.3.0
* Wed Jun 14 2017 jreidinger@suse.com
- Use udev device for prep partition if it is available
  (bsc#1041692)
- 3.2.22
* Mon Jun 12 2017 jreidinger@suse.com
- Do not crash if all devices have defined bios_id, but none is
  the first one (bsc#1043759)
- 3.2.21
* Tue May 30 2017 jreidinger@suse.com
- Repropose bootloader configuration when storage proposal is
  modified (bsc#1035746)
- 3.2.20
* Thu Apr 13 2017 jreidinger@suse.com
- Add possibility to use trusted boot for EFI (FATE#315831)
- 3.2.19
* Fri Mar 24 2017 jreidinger@suse.com
- Report user friendly message when no root partition is detected
  instead of internal error. (bsc#1029293)
- 3.2.18
* Wed Mar  1 2017 jreidinger@suse.com
- provide more helpful error message when invalid arguments for
  serial console are provided (bsc#1012383)
- 3.2.17
* Wed Mar  1 2017 jreidinger@suse.com
- propose for xen hypervisor vga parameter if framebuffer is used
  ( should fix issue with text only environment when fbdev driver
  is used )
  (FATE#322200)
- 3.2.16
* Wed Jan 25 2017 mvidner@suse.com
- Implement simple_mode -> label_proposal (FATE#322328)
- 3.2.15
* Fri Jan  6 2017 jreidinger@suse.com
- do not crash when switching from no bootloader to grub2 when
  grub2 package is not installed (bsc#1018280)
- 3.2.14
* Tue Jan  3 2017 jreidinger@suse.com
- do not try to write legacy_boot flag for msdos partition table
  in more disks scenario when there is also GPT disk (bsc#1017776)
- 3.2.13
* Mon Dec  5 2016 jreidinger@suse.com
- stop failing with new cfa ( caused by deleting nil, change
  in cfa needed for bsc#983486 )
- 3.2.12
* Wed Nov 30 2016 jreidinger@suse.com
- Recommends syslinux as it is often used by generic_mbr, but it
  is not hard requirement (bsc#1004229)
- 3.2.11
* Tue Nov 22 2016 jreidinger@suse.com
- Do not crash in bootloader when default mount by is set to label
  (bsc#1009493)
- 3.2.10
* Tue Nov 22 2016 jreidinger@suse.com
- use proper sources when doing kexec (bsc#981434)
- 3.2.9
* Wed Nov 16 2016 jreidinger@suse.com
- when protecting modification of kernel parameters by password,
  add also rd.shell=0 parameter to avoid getting into initrd shell
  (bsc#1009220)
- 3.2.8
* Mon Nov 14 2016 lslezak@suse.cz
- Revert the package deselection check (from 3.2.3), there is
  a new generic solution in yast2-packager-3.2.6 for all YaST
  modules (bsc#885496)
- 3.2.7
* Wed Nov  2 2016 jreidinger@suse.com
- set pmbr flag only on GPT disks (bsc#1008092)
- 3.2.6
* Tue Nov  1 2016 jreidinger@suse.com
- Use the system-wide locale (/etc/sysconfig/language:RC_LANG) when
  generating the GRUB2 menu (bsc#998152)
- 3.2.5
* Thu Oct 13 2016 jreidinger@suse.com
- Do not require syslinux on target system during installation
  (bsc#1004229)
- fix installation on dm raids to not use mapper device and instead
  use underlaying device (bsc#1004921)
- 3.2.4
* Fri Oct  7 2016 jreidinger@suse.com
- Warn user if the packages needed for booting are deselected
  (bsc#885496)
- 3.2.3
* Thu Oct  6 2016 jreidinger@suse.com
- allow user to repropose configuration if unknown udev link found
  (bnc#931291)
- 3.2.2
* Tue Oct  4 2016 ancor@suse.com
- Do not crash when the user tries to enable serial console with
  blank arguments (bsc#1000629)
- 3.2.1
* Fri Sep 30 2016 jreidinger@suse.com
- show popup when unsupported bootloader used on system, allowing
  user to exit yast2-bootloader or propose supported bootloader
  there (bnc#923458)
- Version bumped to 3.2.X to ease coordination of Tumbleweed,
  Leap 42.2 and SLE-12-SP2 development.
- 3.2.0
* Tue Aug 30 2016 jreidinger@suse.com
- import properly device map in autoyast profile (found during
  debugging bnc#995627)
- log device map entries before written them, to allow easier
  debugging of augeas lenses failure (bnc#995627)
- 3.1.203
* Tue Aug 30 2016 jreidinger@suse.com
- fix crash when activating partition on md raid (bnc#995627)
- 3.1.202
* Fri Aug 26 2016 jsrain@suse.cz
- warn user if enabling TPM when not available (bsc#994556)
- 3.1.201
* Tue Aug 23 2016 jreidinger@suse.com
- fix proposing generic mbr if proposed to boot from MBR
  ( found during debugging bnc#994348 )
- 3.1.200
* Mon Jul 18 2016 jreidinger@suse.com
- do not fail tests when run in environment connected by serial
  console (bnc#989405)
- 3.1.199
* Wed Jul 13 2016 jreidinger@suse.com
- fix writing default boot entry when it is located in grub2
  submenu (bnc#986005)
- 3.1.198
* Mon Jul 11 2016 jreidinger@suse.com
- do not crash after configuration in autoyast bootloader section
  without previous cloning (bnc#985007)
- 3.1.197
* Thu Jul  7 2016 jreidinger@suse.com
- set by default SECURE_BOOT to false on architectures that do not
  support it to avoid call of shim there (bnc#984895)
- 3.1.196
* Fri Jul  1 2016 jreidinger@suse.com
- Optimize code for quicker run (bnc#986649)
- 3.1.195
* Wed Jun 15 2016 jreidinger@suse.com
- do not activate partition on gpt disks on ppc (bnc#983194)
- 3.1.194
* Mon Jun 13 2016 jreidinger@suse.com
- fix unknown method extended_partition (bnc#983062)
- 3.1.193
* Wed Jun  1 2016 igonzalezsosa@suse.com
- Drop yast2-bootloader-devel-doc package (fate#320356)
- 3.1.192
* Mon May 30 2016 jreidinger@suse.com
- fix unknown method error ( caused by fix for bnc#980529)
- 3.1.191
* Fri May 27 2016 jreidinger@suse.com
- use proper device to setup pmbr for grub2efi (bnc#981997)
- 3.1.190
* Wed May 25 2016 jreidinger@suse.com
- do not try to install grub2 on lvm on partition-less disk
  (bnc#980529)
- 3.1.189
* Tue May 24 2016 jreidinger@suse.com
- run mkinitrd at the end of installation to ensure proper initrd
  even for image based installation or live install
  (bnc#977656,bnc#979719)
- 3.1.188
* Tue May 17 2016 jreidinger@suse.com
- do not skip grub2 install during installation on s390
  (bnc#980250)
- 3.1.187
* Mon May 16 2016 jreidinger@suse.com
- Fix storing default boot section (bnc#978366)
- Fix showing default boot section name with spaces inside
  (found during testing fix for bnc#978366)
- 3.1.186
* Mon May 16 2016 jreidinger@suse.com
- do not install grub2 with --no-nvram on non-EFI systems
  (bnc#980108)
- 3.1.185
* Mon May 16 2016 mvidner@suse.com
- Reintroduce Trusted Boot (FATE#316553).
- 3.1.184
* Thu May 12 2016 snwint@suse.de
- fix grub2 settings for lvm encrypted boot partition (bsc#976315)
- 3.1.183
* Wed May 11 2016 jreidinger@suse.com
- do not crash when stage1 is set to extended partition (thanks to
  mvidner for catch, also fix bnc#978284)
- 3.1.182
* Tue May 10 2016 jreidinger@suse.com
- do not crash with uninitialized variable 'extended' (bnc#978284)
- 3.1.181
* Mon May  9 2016 agraf@suse.com
- Disable secure boot on AArch64 (bsc#978157)
- Generate grub2 as removable on non-nvram efi systems (bsc#978593)
- 3.1.180
* Mon May  2 2016 schubi@suse.de
- Fixed nil in custom_devices. Compact! is returning nil if no
  changes were made.
  Removed empty reject, because it is not needed anymore.
  (bnc#977945)
- 3.1.179
* Wed Apr 27 2016 schubi@suse.de
- Adapted new version of bootloader to the AutoYaST configuration
  module.
  (related to FATE#317701)
- 3.1.178
* Tue Apr 26 2016 schubi@suse.de
- Added requirement in proposal. (bnc#977004)
- 3.1.177
* Fri Apr 22 2016 jreidinger@suse.com
- smarter prep partition proposal (bnc#970152)
- fix exception when grub.cfg is not yet generated (bnc#976534)
- 3.1.176
* Wed Apr 20 2016 jreidinger@suse.com
- fix installing grub2 to underlaying devices (bnc#976315)
- 3.1.175
* Tue Apr 19 2016 jreidinger@suse.com
- Improve misleading label for GRUB2 password (bnc#952633)
- 3.1.174
* Mon Apr 18 2016 jreidinger@suse.com
- fix regression in installation on md raid
  (related to FATE#317701 found by openqa)
- 3.1.173
* Mon Apr 18 2016 jreidinger@suse.com
- fix regression in serial console handling and cover it with
  automatic tests
  (bnc#870514 appears again)
- 3.1.172
* Thu Apr 14 2016 igonzalezsosa@suse.com
- Fix error when showing order of hard disks (bsc#975514)
- 3.1.171
* Thu Apr 14 2016 schubi@suse.de
- Fix: Taking modulename "Bootloader" instead of class.
  (related to FATE#317701)
- 3.1.170
* Wed Apr 13 2016 jreidinger@suse.com
- Clean pending TODOs and implement bootloader API calls with new
  architecture (related to FATE#317701)
- 3.1.169
* Wed Apr 13 2016 jreidinger@suse.com
- Drop preparing storage data for perl-Bootloader as it is no
  longer needed (related to FATE#317701)
- 3.1.168
* Wed Apr 13 2016 jreidinger@suse.com
- Fix import of integer timeout and export of terminal symbol
  (found during testing of FATE#317701)
- 3.1.167
* Tue Apr 12 2016 jreidinger@suse.com
- do not propose nor running grub2-install on bare metal POWER
  (bnc#970582)
- do not use perl-Bootloader in yast2-bootloader (FATE#317701)
- 3.1.166
* Wed Mar 23 2016 dvaleev@suse.com
- Set gfxterm to console on POWER
  (bsc#911682)
- 3.1.165
* Fri Mar 11 2016 dvaleev@suse.com
- include quiet in default kernel boot parameters for POWER
  (bsc#965347)
- 3.1.164
* Thu Feb 25 2016 dmueller@suse.com
- include quiet in default kernel boot parameters for aarch64
- 3.1.163
* Fri Nov 27 2015 snwint@suse.de
- updated boot doc for prep partitions
- 3.1.162
* Fri Nov 20 2015 igonzalezsosa@suse.com
- Fix AutoYaST schema to allow specification of 'vgamode',
  'xen_kernel_append' and 'failsafe_disabled' in globals section
  (bsc#954412)
* Wed Nov 18 2015 mvidner@suse.com
- Fix validation of AutoYaST profiles (bsc#954412)
* Tue Nov 17 2015 shundhammer@suse.de
- Fixed crash in bootloader proposal if previous installation was
  on software RAID (bsc#955216)
- 3.1.161
* Wed Nov 11 2015 jreidinger@suse.com
- Do not show raid0 warning for /boot on s390 and ppc architectures
  (bnc#952823)
- 3.1.160
* Fri Oct 23 2015 jreidinger@suse.com
- respect original grub2 configuration when upgrade from grub2
  to grub2 (bnc#951731)
- 3.1.159
* Mon Oct 19 2015 jreidinger@suse.com
- do not modify bootloader configuration during offline upgrade
  from grub2 to grub2 (bnc#950695,bnc#950162)
- 3.1.158
* Fri Oct 16 2015 schubi@suse.de
- Set StorageDevices flag disks_valid to true while cloning system
  in AutoYaST. (bnc#950105)
- 3.1.157
* Thu Oct  1 2015 jreidinger@suse.com
- Fix proposing stage1 location in autoyast (bnc#948258)
- 3.1.156
* Tue Sep 29 2015 jreidinger@suse.com
- fix device map handling if there's no 'hd0' entry in it
  (bsc#947730) by snwint
- 3.1.155
* Mon Sep 28 2015 schubi@suse.de
- Including a needed file. This is an additional fix for
  bnc#930341.
- 3.1.154
* Fri Sep 25 2015 jreidinger@suse.com
- fix booting on ppc with /boot on software raid (bnc#940542)
- 3.1.153
* Thu Sep 24 2015 jreidinger@suse.com
- fix one click proposal change to behave reasonable
- add warnings for missing generic_mbr or activate when really
  missing (bnc#930341)
- 3.1.152
* Wed Sep 16 2015 jreidinger@suse.com
- support custom names for raids (bnc#944041)
- 3.1.151
* Tue Sep 15 2015 jreidinger@suse.com
- make default distributor value empty to use default one in grub2
  (bnc#942519)
- remove distributor entry from ui. Support only changes in text
  file
- 3.1.150
* Tue Sep 15 2015 jreidinger@suse.com
- fix typo when invalid architecture is used (bnc#945764)
- Do not propose bootloader stage1 location for grub2 on EFI
  (bnc#945764)
- 3.1.149
* Fri Sep 11 2015 ancor@suse.com
- Empty kernel command lines are now properly written (bnc#945479)
- 3.1.148
* Thu Sep 10 2015 schubi@suse.de
- AutoYaST configuration: Initialize libstorage and do not regard
  the installed system.
  (bnc#942360)
- 3.1.147
* Fri Sep  4 2015 snwint@suse.de
- ensure device map has really been proposed (bsc#943749)
- when we switch to custom boot, turn off the other boot locations
  (bsc#943749)
- 3.1.146
* Thu Aug 27 2015 jreidinger@suse.com
- use extended partition to boot even for non software raids
  (bnc#940765)
- for separate boot partition with btrfs prefer MBR bootloader
  location (bnc#940797)
- 3.1.145
* Tue Aug 25 2015 igonzalezsosa@suse.com
- Add support for kernel parameter with multiple values
  (bsc#882082)
- 3.1.144
* Mon Aug 24 2015 jreidinger@suse.com
- fix removing password protection (bnc#942867)
- 3.1.143
* Wed Aug 19 2015 jreidinger@suse.com
- do not require parted on target system (bnc#937066)
- 3.1.142
* Mon Aug 17 2015 jreidinger@suse.com
- avoid bootloader module stuck caused by parted prompt
  (bnc#941510)
- 3.1.141
* Fri Aug 14 2015 snwint@suse.de
- as SCR hasn't been setup yet, use some trickery to read boot config (bsc #940486)
- 3.1.140
* Wed Aug  5 2015 jsrain@suse.cz
- always run mkinitrd at the end of S/390 installation (bsc#933177)
- 3.1.139
* Thu Jul  9 2015 jreidinger@suse.com
- fix crash when aborting during initial screen (bnc#910343)
- 3.1.138
* Tue Jul  7 2015 jreidinger@suse.com
- skip MBR update on s390 (bnc#937015)
- 3.1.137
* Mon Jun 29 2015 jreidinger@suse.com
- set only proper boot flags ("boot" for DOS partition table and
  legacy_boot for GPT partition table), otherwise it can confuse
  some firmware and cause booting problems (bnc#930903)
- 3.1.136
* Mon Jun 22 2015 jreidinger@suse.com
- Let password protection be configurable between a restricted mode
  (cannot boot at all without password, default GRUB2 behavior)
  and an unrestricted mode (can boot but cannot edit entries, GRUB1
  behavior) (FATE#318574).
- 3.1.135
* Tue Jun 16 2015 jreidinger@suse.com
- Stop adding 'Failsafe' entry to bootloader menu unless user
  manually add it (fate#317016)
- 3.1.134
* Wed Jun  3 2015 jreidinger@suse.com
- do not crash in offline update in bootloader proposal(bnc#931021)
- 3.1.133
* Wed Jun  3 2015 jreidinger@suse.com
- Fix cleaning of tmp file for init bootloader (bnc#926843)
- 3.1.132
* Wed Jun  3 2015 jreidinger@suse.com
- Fix ignoring bootloader settings after changing them in proposal
  screen (bnc#925987)
- 3.1.131
* Tue Jun  2 2015 jreidinger@suse.com
- Do not crash if system contain unpartitioned disk (bnc#930091)
- allow negative timeout to cancel automatic boot (bnc#812618)
- fix typo in help text (bnc#702664)
- 3.1.130
* Mon Jun  1 2015 jreidinger@suse.com
- Don't crash when reconfiguring from grub1 to grub2 (bnc#923458)
- 3.1.129
* Wed May 20 2015 dvaleev@suse.com
- Disable os-prober for Power boo#931653
- 3.1.128
* Tue Apr 14 2015 schubi@suse.de
- While calling AutoYaST clone_system libStorage has to be set
  to "normal" mode in order to read mountpoints correctly.
- 3.1.127
* Thu Apr  9 2015 jreidinger@suse.com
- fix abort when importing bootloader values in autoyast
  (bnc#914812)
- 3.1.126
* Wed Mar 25 2015 schwab@suse.de
- Propose secure_boot by default only on x86, aarch64 is not ready yet
- 3.1.125
* Wed Feb 25 2015 jreidinger@suse.com
- Fixed creation of a multipath device map
- 3.1.124
* Wed Feb 18 2015 jreidinger@suse.com
- fix crash on ppc(bnc#917833)
- 3.1.123
* Tue Feb 17 2015 jreidinger@suse.com
- reset flags before set new ones(bnc#848609)
- 3.1.122
* Mon Feb 16 2015 jreidinger@suse.com
- ensure that there is only limited amount of disks in device map
  (bnc#917640)
- 3.1.121
* Thu Feb 12 2015 jreidinger@suse.com
- fix redundancy boot proposal if there are more devices
  (bnc#917025)
- 3.1.120
* Tue Feb 10 2015 ancor@suse.com
- Fixed detection for encrypted partitions (bnc#913540)
- 3.1.119
* Fri Feb  6 2015 ancor@suse.com
- The unit tests are now compatible with RSpec 3 (bnc#916364)
- 3.1.118
* Wed Feb  4 2015 jsrain@suse.cz
- initialize bootloader during update if proposed from scratch
  (bnc#899743)
- 3.1.117
* Tue Feb  3 2015 schwab@suse.de
- Use ttyAMA instead of ttyS on aarch64
- 3.1.116
* Tue Jan 20 2015 schwab@suse.de
- Use grub2-efi on aarch64
- 3.1.115
* Tue Jan 13 2015 jreidinger@suse.com
- Do not crash with unsupported bootloader when resetting
  bootloader to repropose during update (bnc#912595)
- 3.1.113
* Thu Dec  4 2014 jreidinger@suse.com
- remove X-KDE-Library from desktop file (bnc#899104)
* Tue Dec  2 2014 jreidinger@suse.com
- fix crash when not using separate boot (found by openqa)
- 3.1.112
* Fri Nov 21 2014 jsrain@suse.cz
- detect EFI directly from sysfs during live installation
  (bnc#829256)
* Tue Nov 18 2014 jreidinger@suse.com
- run password encryption always locally to ensure that
  grub2-mkpasswd is there (bnc#900039)
- 3.1.111
* Tue Nov 11 2014 jreidinger@suse.com
- properly align checkboxes and improve spacing (bnc#900023)
- 3.1.110
* Fri Oct 31 2014 jreidinger@suse.com
- do not show useless widgets when user decided to not install
  bootloader (bnc#901060)
- 3.1.109
* Wed Oct 29 2014 jreidinger@suse.com
- do not return /dev/null if cannot detect bootloader devices as it
  cause errors later
* Wed Oct 29 2014 jreidinger@suse.com
- do not show warning if boot from extended partition (bnc#898023)
- 3.1.108
* Wed Oct 29 2014 jreidinger@suse.com
- fix branding activation on live CD and also with kexec enabled
  (bnc#897847)
- 3.1.107
* Fri Oct 24 2014 jreidinger@suse.com
- fix crash during installation if kernel parameter is not
  pre-proposed (bnc#902397)
- 3.1.106
* Wed Oct 15 2014 jreidinger@suse.com
- improve usability of device map editor (bnc#900807)
- 3.1.105
* Wed Oct 15 2014 jreidinger@suse.com
- ensure branding is used also during common install (bnc#901003)
- 3.1.104
* Wed Oct 15 2014 jreidinger@suse.com
- fix missing widgets log entries(bnc#889169)
- 3.1.103
* Wed Oct 15 2014 jreidinger@suse.com
- do not refer to info page of grub1 (bnc#878796)
- fixed an Internal Error when using password for grub2 with
  non-english locale (bnc#900358)
- 3.1.102
* Tue Oct  7 2014 jreidinger@suse.com
- keep user selection for password (bnc#900026)
- fix build on ppc
- 3.1.101
* Tue Sep 30 2014 jreidinger@suse.com
- use short product name to avoid truncated text on small
  resolution (bnc#873675)
- Avoid crash in clone_system on s390 (bnc#897399)
- propose missing attributes also during automatic upgrade which
  propose grub2 configuratin (bnc#897058)
- 3.1.100
* Tue Sep 30 2014 jreidinger@suse.com
- move boot record backup functionality to own class to make code
  easier to understand and better tested
- 3.1.99
* Mon Sep 29 2014 jreidinger@suse.com
- fix crash in lib_iface caused by typo (found by openQA and
  bnc#898878)
- fix crash when using tmpfs
- fix crash when device have explicit mount by device name
- 3.1.98
* Thu Sep 18 2014 jreidinger@suse.com
- move udev mapping functionality to own class to make code easier
  to understand and better tested
- 3.1.97
* Wed Sep 17 2014 jreidinger@suse.com
- pass vga mode if specified during installation
  (bnc#896300,bnc#891060)
* Mon Sep 15 2014 jreidinger@suse.com
- Fix API to remove or add kernel parameter for bootloader
  (bnc#894603)
* Tue Sep  9 2014 jreidinger@suse.com
- cleaning of section related code because we no longer support
  any bootloader which allows direct write of sections
* Mon Sep  8 2014 jreidinger@suse.com
- switch build tool from autotools to rake
- 3.1.96
* Mon Sep  8 2014 jreidinger@suse.com
- Drop remaining support for GRUB1 (fate#317700)
- 3.1.95
* Mon Sep  8 2014 jreidinger@suse.com
- Avoid configuration where to MBR we want grub2 and also
  generic_mbr which can lead to unbootable configuration
  (bnc#893626)
- 3.1.94
* Thu Sep  4 2014 mvidner@suse.com
- Use a more flexible rubygem requirement syntax (bnc#895069)
- 3.1.93
* Thu Sep  4 2014 jreidinger@suse.com
- Do not overwrite bios_boot partition flag by boot flag leading
  to error in writing boot code (Bnc#894040)
- 3.1.92
* Wed Aug 27 2014 jreidinger@suse.com
- do not reset secure boot to false at the end of installation in
  case of incapable device (bnc#892032)
- 3.1.91
* Tue Aug 26 2014 jreidinger@suse.com
- fix partition activation on LVM (bnc#893449)
- fix activation device when md raid devices do not have
  recognizable bios id
- 3.1.90
* Fri Aug 15 2014 snwint@suse.de
- remove nonsense check (bnc #768538)
- 3.1.89
* Fri Aug 15 2014 jreidinger@suse.com
- read properly secure boot status when used from other modules
  like yast2-vm, so it adds new entry as secure boot (bnc#892032)
- 3.1.88
* Thu Aug 14 2014 schubi@suse.de
- AutoYaST clone_system: Not using "next" in a ruby "reduce" call.
  (bnc#891079)
- 3.1.87
* Tue Aug 12 2014 jreidinger@suse.com
- Fixed adding a crashkernel parameter to xen_append if the latter
  is missing. kdump.service would fail then (bnc#886843)
- 3.1.86
* Fri Aug  8 2014 jreidinger@suse.com
- do not crash in some condition in combination of LVM and GPT
  (bnc#891070)
- 3.1.85
* Thu Aug  7 2014 jreidinger@suse.com
- fix assigning priority disks to device map for LVM (bnc#890364)
- 3.1.84
* Thu Aug  7 2014 jreidinger@suse.com
- workaround initrd recreation if some packages forgot during
  upgrade (bnc#889616)
- 3.1.83
* Wed Aug  6 2014 jreidinger@suse.com
- ignore unknown priority device to avoid problems in corner case
  scenarios (bnc#890364)
- 3.1.82
* Tue Aug  5 2014 jreidinger@suse.com
- fix assigning priority disks to device map for md raid
  (bnc#890246)
- fix choosing priority device causing bootloader crash
  (bnc#890204)
- 3.1.81
* Fri Aug  1 2014 jsrain@suse.cz
- fixed bootloader installation (bnc#889770)
- 3.1.80
* Thu Jul 31 2014 jreidinger@suse.com
- Disk order dialog:
  - fix non-working up button (bnc#885867)
  - fix enabling/disabling up/down buttons in various situations
  - when adding new device set focus to input field to better UX
- 3.1.79
* Thu Jul 31 2014 jreidinger@suse.com
- reinit branding in upgrade of SLE-12 as it is overwritten
  (bnc#879686)
- 3.1.78
* Thu Jul 31 2014 jreidinger@suse.com
- fix crash in bootloader caused by wrong device in device map
  (bnc#889670)
- 3.1.77
* Wed Jul 30 2014 schubi@suse.de
- Fixed error popup for unsupported bootloader in autoyast.
  (bnc#889538)
- 3.1.76
* Wed Jul 30 2014 ancor@suse.com
- Added a missing call to i18n for a string (bnc#887553)
- 3.1.75
* Wed Jul 30 2014 jreidinger@suse.com
- Fix crash if during proposal some device map value is nil
  ( found by openQA )
- 3.1.74
* Tue Jul 29 2014 jreidinger@suse.com
- Always use device with /boot as first device in device map to
  avoid problems with other MBRs (bnc#887808, bnc#880439)
- 3.1.73
* Mon Jul 28 2014 jreidinger@suse.com
- fix proposing disabledos prober on certain products (SLES is
  affected) (bnc#884007)
- 3.1.72
* Mon Jul 28 2014 snwint@suse.de
- enable secure boot by default (bnc #879486)
- 3.1.71
* Fri Jul 25 2014 jreidinger@suse.com
- allow change of bootloader proposal during upgrade (bnc#887015)
- 3.1.70
* Fri Jul 25 2014 jsrain@suse.cz
- code de-duplication of recent AUtoYaST fixes (bnc#885634)
- 3.1.69
* Tue Jul 22 2014 jsrain@suse.cz
- initialize bootloader location configuration on AutoYaST ugprade
  (bnc#885634)
- 3.1.68
* Wed Jul 16 2014 jsrain@suse.cz
- don't check dedicated /boot/zipl partition on upgrade
  (bnc#886604)
- 3.1.67
* Fri Jul 11 2014 jreidinger@suse.com
- fix writing sysconfig for grub1 (bnc#885634)
- 3.1.66
* Fri Jul 11 2014 mchang@suse.com
- fix secure boot widget did not function from installed system
  because bootloader not get re-installed (bnc#882124)
- 3.1.65
* Wed Jul  9 2014 jreidinger@suse.com
- add check for combination of MBR, GPT, btrfs and missing
  bios_grub partitition (bnc#886143)
- 3.1.64
* Tue Jul  8 2014 jreidinger@suse.com
- warn user if no location chosen for stage 1 (bnc#885208)
- 3.1.63
* Mon Jul  7 2014 jreidinger@suse.com
- use only simple device map on s390 (bnc#884798, bnc#885984)
- 3.1.62
* Thu Jul  3 2014 jreidinger@suse.com
- add perl-Bootloader-YAML to needed packages (BNC#885496)
- 3.1.61
* Fri Jun 27 2014 jreidinger@suse.com
- do not allow to install to partition with xfs otherwise fs can be
  broken due to missing reserved space in xfs(bnc#884255)
- 3.1.60
* Fri Jun 27 2014 jreidinger@suse.com
- properly install needed packages in autoinstallation
- 3.1.59
* Thu Jun 26 2014 jreidinger@suse.com
- add help and translation for grub2 distributor description and
  other small localization improvements (bnc#884344)
- fix crash during propose of EFI during upgrade (bnc#884397)
- 3.1.58
* Tue Jun 24 2014 jreidinger@suse.com
- respect product default configuration for os-prober enablement
  (bnc#884007)
- 3.1.57
* Wed Jun 18 2014 schubi@suse.de
- Initialize variable correctly for supported bootloaders
  (bnc#883040)
- 3.1.56
* Mon Jun 16 2014 jreidinger@suse.com
- Allow in autoyast only supported bootloaders (bnc#882210)
- 3.1.55
* Fri Jun 13 2014 jreidinger@suse.com
- fix crash with invalid partition to activate (bnc#882592)
- 3.1.54
* Fri Jun 13 2014 jsrain@suse.cz
- don't prevent installation because of BIOS IDs not detected if
  disks order reviewed by user (bnc#880439)
- 3.1.53
* Wed Jun 11 2014 jreidinger@suse.com
- do not crash in autoyast (bnc#882210)
- 3.1.52
* Mon Jun  9 2014 jreidinger@suse.com
- Fix reinstallation of secure boot stage 1 (bnc#875235)
- 3.1.51
* Thu Jun  5 2014 jsrain@suse.cz
- adjusted wording if disk order could not be detected (bnc#880439)
- 3.1.50
* Wed Jun  4 2014 jreidinger@suse.com
- remove translation of section as it is generated in GRUB2 and
  never work reliably fro GRUB1 (bnc#875819)
- 3.1.49
* Tue Jun  3 2014 dvaleev@suse.com
- Setting boot flag on GPT PReP resets prep flag which leads to
  grub2-install unable to install a bootloader (bnc#880094)
- 3.1.48
* Mon Jun  2 2014 jreidinger@suse.com
-  fix typo causing crash when writing pmbr flag (bnc#880893)
- 3.1.47
* Thu May 29 2014 jreidinger@suse.com
- Fix crash in upgrade from SLE11
- 3.1.46
* Wed May 28 2014 jreidinger@suse.com
- Remove check for iscsi boot partition (bnc#880328)
- 3.1.45
* Wed May 28 2014 jreidinger@suse.com
- fix crash in summary page of installation for grub2 (bnc#880324)
- 3.1.44
* Tue May 27 2014 jreidinger@suse.com
- fix crash in summary page of installation
- 3.1.43
* Tue May 27 2014 mchang@suse.com
- reinstall bootloader if the settings requires it
- 3.1.42
* Tue May 27 2014 jreidinger@suse.com
- Fix detection if bootloader installation failed (bnc#879883)
- 3.1.41
* Mon May 26 2014 jreidinger@suse.com
- add support to set Protective MBR and use reasonable proposal
  (bnc#872054)
- 3.1.40
* Fri May 23 2014 jreidinger@suse.com
- Installation Summary: do not allow change location for grub2
  on ppc and s390 (bnc#879107)
- 3.1.39
* Thu May 22 2014 jreidinger@suse.com
- Report if grub2-install failed so user see quickly, that he
  cannot boot(bnc#878664)
- 3.1.38
* Fri May 16 2014 snwint@suse.de
- get rid of grub in loader type selection
- 3.1.37
* Fri May 16 2014 jreidinger@suse.com
- fix progress report to not show 100%% and waiting to write
  bootloader (bnc#878007)
- 3.1.36
* Wed May 14 2014 jreidinger@suse.com
- add new API call to work nice with grub2 kernel parameter
  configuration (bnc#869608)
- 3.1.35
* Mon May 12 2014 jreidinger@suse.com
- extended sysconfig options only for grub1 to prevent confusion
  (bnc#870890)
- 3.1.34
* Tue May  6 2014 jreidinger@suse.com
- reinit perl-bootloader library in update mode to force write
  configuration (bnc#876359,876355)
- 3.1.33
* Fri May  2 2014 jreidinger@suse.com
- fix activating partitions with number bigger then 4 on GPT disks
  with legacy x86 boot (bnc#875757)
- 3.1.32
* Wed Apr 30 2014 jreidinger@suse.com
- handle diskless nfs setup for ppc (bnc#874466)
- 3.1.31
* Tue Apr 29 2014 jreidinger@suse.com
- fix reading of previous bootloader (bnc#874646)
- 3.1.30
* Tue Apr 22 2014 jreidinger@suse.com
- Use correct check for partition setup for grub2 on s390
  (bnc#873951)
- 3.1.29
* Thu Apr 17 2014 jreidinger@suse.com
- do not complain for missing bios order on s390(bnc#874106)
- 3.1.28
* Thu Apr 17 2014 jreidinger@suse.com
- improve logging if setting kernel paramater failed to help with
  bnc#873996
- remove graphic adapter configuration on s390 (bnc#874010)
- 3.1.27
* Wed Apr 16 2014 jreidinger@suse.com
- allow switching to grub2 also on ppc
- Do not raise exception for grub2efi on non-pc architectures
  (bnc#873861)
- 3.1.26
* Wed Apr 16 2014 jreidinger@suse.com
- fix crash on s390 due to missing loader widget(bnc#873911)
- 3.1.25
* Tue Apr 15 2014 jreidinger@suse.com
- fix proposing when proposal do not change (bnc#873620)
- 3.1.24
* Tue Apr 15 2014 jreidinger@suse.com
- cleaning up deprecated code to improve stability and maintenance
  of code
- 3.1.23
* Tue Apr 15 2014 mchang@suse.com
- remove error if boot directory on xfs file system (bnc#864370)
- 3.1.22
* Thu Apr 10 2014 jreidinger@suse.com
- drop not-supported bootloaders except grub1
- 3.1.21
* Tue Apr  8 2014 jreidinger@suse.com
- modify proposal to work also during upgrade and propose upgrade
  to grub2 (bnc#872081)
- 3.1.20
* Mon Apr  7 2014 jreidinger@suse.com
- return back installation details for tweaking device map
  (bnc#872300)
- 3.1.19
* Fri Apr  4 2014 snwint@suse.de
- install mokutil along with shim (bnc #808852)
- fix regular expessions (ported from bnc #743805)
- 3.1.18
* Wed Apr  2 2014 jreidinger@suse.com
- fix crash on s390 (bnc#871597)
- 3.1.17
* Wed Apr  2 2014 jreidinger@suse.com
- fix autoyast location proposal (bnc#869083)
- 3.1.16
* Wed Apr  2 2014 snwint@suse.de
- don't question device mapping passed to us explicitly by autoyast
  (bnc #717978, bnc #870494)
* Fri Mar 28 2014 jreidinger@suse.com
- improve support grub2 on non-pc architectures
  (bnc#866912,bnc#868909)
- 3.1.15
* Fri Mar 28 2014 mchang@suse.com
- fix wrong console regexp match (bnc#870514)
- 3.1.14
* Fri Mar 21 2014 snwint@suse.de
- fix minor typo (bnc #869324)
* Wed Mar 12 2014 mchang@suse.com
- fix grub2-*-efi package not installed (bnc#867380)
- 3.1.13
* Mon Mar 10 2014 jreidinger@suse.com
- do not crash if there is no swap partition (bnc#867435)
- 3.1.12
* Mon Mar 10 2014 mchang@suse.com
- fix some serial console issues (bnc#862388) (bnc#866710)
- 3.1.11
* Wed Mar  5 2014 snwint@suse.de
- always allow grub2 (bnc #866863)
- 3.1.10
* Tue Mar  4 2014 snwint@suse.de
- switch to grub2 on s390x
- support both grub2 & zipl
- drop grub & elilo support from x86
- 3.1.9
* Tue Mar  4 2014 jreidinger@suse.com
- fix typo in proposal screen(bnc#866607)
- 3.1.8
* Mon Mar  3 2014 jreidinger@suse.com
- fix permissions on file which contain encrypted password to be
  readable only by root(BNC#864544)(CVE#2013-4577)
- 3.1.7
* Thu Feb 27 2014 jreidinger@suse.com
- Add support for password in GRUB2 (FATE#315404)
- restructure details dialog in GRUB2 to have better UX
- fix crash of GRUB2 module
- 3.1.6
* Wed Feb 12 2014 jreidinger@suse.com
- rephrase bootloader proposal on summary screen (BNC#853058)
- 3.1.5
* Mon Feb 10 2014 snwint@suse.de
- don't ask to run yast.ssh in second stage as there's no second stage
  anymore (bnc 861537)
* Tue Jan 28 2014 jreidinger@suse.com
- Fix examining MBR
- 3.1.4
* Tue Jan 14 2014 jreidinger@suse.com
- handle problematic conversion of perl undef in perl-json
  (bnc#858461)
- fix "undefined method `split' for true:TrueClass" with grub2-efi
  (bnc#855568) ( thanks lpechacek )
- always use local parted. It allows to have target system without parted.
- 3.1.3
* Tue Nov  5 2013 locilka@suse.com
- Using 'Kernel' Yast library for handling modules loaded on boot
  (bnc#838185)
- 3.1.2
* Tue Nov  5 2013 snwint@suse.de
- use pbl-yaml script to communicate with perl-Bootloader
- 3.1.1
* Wed Sep 18 2013 lslezak@suse.cz
- do not use *.spec.in template, use *.spec file with RPM macros
  instead
- 3.1.0
* Fri Aug 23 2013 snwint@suse.de
- desktop files now also for s390
- 3.0.3
* Tue Aug  6 2013 lslezak@suse.cz
- removed obsolete BuildRequires: yast2 and yast2-core
- 3.0.2
* Thu Aug  1 2013 lslezak@suse.cz
- move the development documentation to devel-doc subpackage
- removed obsolete BuildRequires, not needed anymore:
  docbook-xsl-stylesheets doxygen gcc-c++ libxslt perl-Bootloader
  perl-gettext perl-XML-Writer sgml-skel swig update-alternatives
  libtool yast2-installation yast2-packager yast2-perl-bindings
  yast2-pkg-bindings yast2-storage yast2-testsuite
- 3.0.1
* Wed Jul 31 2013 yast-devel@opensuse.org
- converted from YCP to Ruby by YCP Killer
  (https://github.com/yast/ycp-killer)
- version 3.0.0
* Fri Jun 14 2013 snwint@suse.de
- remove limal reference
- 2.24.1
* Wed Mar  6 2013 snwint@suse.de
- set secureboot default to firmware status
- 2.23.12
* Mon Feb 25 2013 snwint@suse.de
- support uefi secureboot
- Propose grub2 theme path
- 2.23.11
* Mon Feb  4 2013 snwint@suse.de
- write gpt bootcode on gpt disks (fate #313880)
- fix initrd selection due to initrd-*-kdump in our new kernel packages
- take boot code from syslinux instead of master-boot-code package
- 2.23.10
* Mon Feb  4 2013 snwint@suse.de
- fix automake file
- 2.23.9
* Fri Jan 11 2013 snwint@suse.de
- jsuchome: /sbin/SuSEconfig call removed
- mchang: some bug fixing and improve grub2's summary
- 2.23.8
* Thu Aug 30 2012 mchang@suse.com
- remove vga=ask
- add option to disable os-prober
* Fri Jul 13 2012 mchang@suse.com
- support failsafe kernel parameters
- use product name in distributor
- rearrange widgets in dialog
- fix redundant kernel append
- 2.23.7
* Mon Jul  9 2012 ug@suse.de
- fixed rnc schema file (bnc#752450)
- 2.23.6
* Wed Jul  4 2012 mchang@suse.de
- set leagcy grub as default for xen pv guest
- use 'auto' for default gfxmode
- replace background with theme
- support editing GRUB_DISTRIBUTOR
- make vgamode widget wider
- 2.23.5
* Mon Jun  4 2012 mchang@suse.com
- support console related global options gfxterm, serial, gfxbackground
  and gfxmode
- 2.23.4
* Tue Apr 24 2012 snwint@suse.de
- don't do kexec on hyper-v (bnc#732693)
- 2.23.3
* Mon Apr 23 2012 mchang@suse.com
- add "Boot Loader Options" dialog for grub2-efi that provides widgets for
  manipulating global options. These options include timeout, vgamode,
  append and default.
- add widgets for enabling serial console and specify it's arguments on
  "Boot Loader Options" dialog.
- add "Boot Loader Options" dialog for grub2 that provides widgets for
  manipulating global options. These options include activate, generic_mbr,
  timeout, vgamode, append and default.
- 2.23.2
* Mon Apr 23 2012 snwint@suse.de
- adapted ssh command for 2nd stage ssh installation (bnc#745340)
* Thu Mar 22 2012 mchang@suse.com
- add kernel parameters (detected necessary and user specfied one during
  installation) to grub2's config file (bnc#752939)
- 2.23.1
* Thu Mar 22 2012 mchang@suse.com
- add new grub2-efi module to support booting on UEFI firmware.
* Wed Mar 14 2012 aschnell@suse.de
- adapted ssh command for 2nd stage ssh installation (bnc#745340)
* Mon Mar  5 2012 mchang@suse.com
- add basic grub2 support that only handles installs
- 2.23.0
* Fri Jan 13 2012 jsuchome@suse.cz
- added GfxMenu::Update to the client, so calling does not require
  package dependency (bnc#730391)
- 2.22.0
* Fri Nov 25 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Fri Oct 21 2011 snwint@suse.de
- yast2-storage uses fake uuids for btrfs handling; adjust our
  code (bnc #707450)
- 2.21.2
* Tue Oct 18 2011 snwint@suse.de
- fix bootloader package handling (bnc #716404)
- 2.21.1
* Tue Oct  4 2011 cfarrell@suse.com
- license update: GPL-2.0+
  SPDX format
* Mon Sep 26 2011 visnov@suse.cz
- set dialog title
- 2.21.0
* Wed Sep 21 2011 snwint@suse.de
- revert kernel-*-base change
- 2.20.5
* Wed Sep 21 2011 snwint@suse.de
- enable resume for s390x (bnc #692606)
- kernel images are in kernel-*-base package
- 2.20.4
* Mon Sep 19 2011 snwint@suse.de
- s390x: add hvc_iucv=8 to boot options (bnc #718089)
- 2.20.3
* Fri Sep 16 2011 snwint@suse.de
- fix typo
- 2.20.2
* Fri Aug  5 2011 tgoettlicher@suse.de
- fixed .desktop file (bnc #681249)
* Mon Mar 21 2011 jreidinger@suse.de
- fix detection of other linux partitions (BNC#675224)
* Tue Feb 22 2011 jreidinger@novell.com
- during probe of partitions don't try to mount encrypted one
  (bnc#673906)
- 2.20.1
* Mon Jan 10 2011 jreidinger@novell.com
- add missing file to tarball
* Thu Dec 30 2010 jreidinger@novell.com
- allow to not specify vga mode for boot (bnc#643984)
- improve help text for menu section (bnc#621290)
- explicitelly  mention variables to compare to avoid problems with nil
  value (consider nil as false)
- number of partition can be integer so always convert it to string
- more explanation for warning messages with hint how to solve it
- 2.19.16
* Wed Jun  2 2010 juhliarik@suse.cz
- added update of fix for (bnc#604401)
- 2.19.15
* Wed May 19 2010 juhliarik@suse.cz
- added xen boot section as default during installation on
  PV guest (bnc#604401)
- 2.19.14
* Thu May  6 2010 juhliarik@suse.cz
- added patch for (bug#448883)
- 2.19.13
* Tue Apr 13 2010 juhliarik@suse.cz
- added fix for troubles with using uuid names (bnc#594482)
- 2.19.12
* Thu Apr  8 2010 juhliarik@suse.cz
- added patch for enable/disable SELinux (fate#309275)
- 2.19.11
* Wed Mar 31 2010 juhliarik@suse.cz
- added fix for sending empty "boot_custom" (bnc#589433)
- 2.19.10
* Tue Mar 23 2010 juhliarik@suse.cz
- added fix for checking custom boot partition (bnc#588770)
- 2.19.9
* Tue Mar 16 2010 juhliarik@suse.cz
- added fix for adding XEN section on IA64 (bnc#588609)
* Tue Mar  9 2010 juhliarik@suse.cz
- added fix for using device map in autoyast profile (bnc#585824)
- 2.19.8
* Fri Feb 26 2010 juhliarik@suse.cz
- added fix for creating sysconfig directory file (bnc#583088)
- 2.19.7
* Mon Feb 22 2010 juhliarik@suse.cz
- added fix for detection of UEFI (bnc#581213)
- 2.19.6
* Thu Feb 11 2010 juhliarik@suse.cz
- added fix for calling mkinitrd if vga is "normal" (bnc#292013)
- 2.19.5
* Thu Feb 11 2010 juhliarik@suse.cz
- added fix for using persistent device names (bnc#533782)
* Thu Feb 11 2010 juhliarik@suse.cz
- added fix for using encrypted swap partition (bnc#577127)
- 2.19.4
* Thu Feb 11 2010 juhliarik@suse.cz
- added fix for detection of QEMU (bnc#571850)
- 2.19.3
* Wed Feb 10 2010 juhliarik@suse.cz
- added fix for adding crashkernel option to XEN kernel
  (bnc#578545)
* Tue Feb  9 2010 juhliarik@suse.cz
- solved problem with wrtting to floppy (bnc#539774)
* Tue Feb  9 2010 juhliarik@suse.cz
- added fix for deleting Custom Boot Partition (bnc#544809)
- 2.19.2
* Thu Jan 28 2010 juhliarik@suse.cz
- added commnets for using options in /etc/sysconfig/bootloader
  (bnc#511319)
- 2.19.1
* Wed Jan 13 2010 kmachalkova@suse.cz
- Adjusted .desktop file(s) to wrap /sbin/yast2/ calls in xdg-su
  where root privileges are needed, removed X-KDE-SubstituteUID key
  (bnc#540627)
* Tue Jan 12 2010 juhliarik@suse.cz
- added fix for data in device.map if MD RAID from Intel is used
  (bnc#568837)
- 2.19.0
* Wed Dec  9 2009 juhliarik@suse.cz
- added patch for KMS (bnc#561566)
* Mon Dec  7 2009 juhliarik@suse.cz
- added fix for problem with characters in name (bnc#558542)
* Fri Dec  4 2009 juhliarik@suse.cz
- added fix for section name mismatch in lilo.conf for PPC
  (bnc#441051)
* Tue Oct 13 2009 juhliarik@suse.cz
- deleted handling of luks_root and updating initrd for encrypted
  "/" (bnc#528474)
- 2.18.17
* Mon Sep 21 2009 juhliarik@suse.cz
- added fix for missing persistent device names in mapping for
  perl-Bootloader (bnc#534905A)
- 2.18.16
* Thu Sep 17 2009 juhliarik@suse.cz
- added fix for typy in help (bnc#532904)
* Fri Sep  4 2009 juhliarik@suse.cz
- fixed type (bnc#535442)
* Thu Sep  3 2009 juhliarik@suse.cz
- added fixed in help text convert "XEN" to "Xen" (bnc#532512)
* Thu Sep  3 2009 juhliarik@suse.cz
- added fix for editing boot section (bnc#535739)
- 2.18.15
* Thu Aug  6 2009 juhliarik@suse.cz
- added support for enable SELinux (fate#305557)
- 2.18.14
* Tue Aug  4 2009 juhliarik@suse.cz
- added support for redundancy md array (fate#305008)
- 2.18.13
* Fri Jul 31 2009 aschnell@suse.de
- adapted to changes in yast2-storage
- 2.18.12
* Tue Jul 28 2009 juhliarik@suse.cz
- added support for luks_root also to xen sections with kernel-xen
* Tue Jul 28 2009 juhliarik@suse.cz
- reorganize UI widgets in GRUB global options
* Mon Jul 27 2009 juhliarik@suse.cz
- added support for enable/disable acoustinc signals (fate#305403)
- 2.18.11
* Fri Jul 24 2009 juhliarik@suse.cz
- added support for encrypted disk (fate#305633)
- 2.18.10
* Mon Jul 20 2009 juhliarik@suse.cz
- added client bootloader_preupdate it takes care about calling
  Storage::Update() (bnc#414490)
- added fix for using iscsi disk (bnc#393928)
- updated help text (bnc#511007)
- enabled change bootloader settings via one-click in installation
  summary (fate#303643)
- deleted warning message about using ext4
- updated proposal and using checkboxes Boot from Boot Partition
  and Boot from Extended Partition
- 2.18.9
* Mon Jun  8 2009 jsrain@suse.cz
- do not add 'ide=nodma' to failsafe kernel parameter (bnc#510784)
* Mon May 25 2009 jreidinger@suse.cz
- refactor Update code (update between products)
* Wed May 20 2009 juhliarik@suse.cz
- fixed additional options for memory test section (bnc#396150)
- fixed problems with empty settings in autoyast profile for
  memory test section (bnc#390659)
- fixed problem with custom (disable) gfxmenu option in autoyast
  profile (bnc#380509)
- fixed deleting gfxmenu option if there is defined serial console
  (bnc#346576)
- added support check for ext4 (fate#305691)
- 2.18.8
* Mon May 18 2009 juhliarik@suse.cz
- added fix for changing device map in y2-bootloader (bnc#497944)
- added warning message if there is not valid configuration for
  soft-raid (bnc#501043)
* Thu May  7 2009 juhliarik@suse.cz
- added fix for checking soft-raid devices in device.map
  (bnc#494630)
- added fix for changing device map in y2-bootloader (bnc#497944)
- 2.18.7
* Tue Apr 28 2009 juhliarik@suse.cz
- added updated patch from IBM and reipl (bnc#471522)
* Tue Apr 28 2009 juhliarik@suse.cz
- disable checking thinkpad sequence in MBR also save content of
  MBR (bnc#464485)
* Wed Apr 22 2009 jreidinger@suse.cz
- code clean
- add interface for new perl-Bootloader MBR tools
- add missing short-cuts for widgets
* Thu Apr 16 2009 juhliarik@suse.cz
- added fix for commandline interface (bnc#479069)
* Wed Apr 15 2009 juhliarik@suse.cz
- added back function setKernelParam (bnc#495048)
- 2.18.6
* Tue Apr 14 2009 juhliarik@suse.cz
- updated timeout for ppc and elilo both to seconds
- 2.18.5
* Tue Apr 14 2009 juhliarik@suse.cz
- added fix for troubles with analyse of MBR on soft riad
  (bnc#483797)
* Fri Apr 10 2009 juhliarik@suse.cz
- added fix for problem with special chars in menu.lst (bnc#456362)
* Fri Apr 10 2009 juhliarik@suse.cz
- added fix for troubles with help in boot menu (bnc#384768)
* Tue Apr  7 2009 juhliarik@suse.cz
- refactoring UI is done (fate#305268)
- fixed problem with providing vga modes list in grub(bnc#362517)
- fixed troubles with short input field for devices (bnc#396387)
- fixed problem with setup of password for grub
  (bnc#407887,#433854,#450470)
- fixed problem with keyboard shortcuts (bnc#414989)
- setup for console in grub was rewritten (bnc#431515)
- 2.18.4
* Mon Feb 16 2009 juhliarik@suse.de
- added fix for problem with wrong init for storage library
  (bnc#464090)
- updated fix for increase performance on huge machine (bnc#468922)
- added fix for checking GPT and using the 4th partition for
  booting (bnc#474854)
- added quit booting "splash=silent quiet" (bnc#475194)
- updated change log for using convention (bnc#no,fate#no etc.)
- 2.18.3
* Mon Feb  9 2009 juhliarik@suse.de
- added fix for using buttons (bnc#440553)
- added fix for checking boot device on mac machines (bnc#343670)
- 2.18.2
* Wed Feb  4 2009 juhliarik@suse.cz
- added fix for problem with unnecessary popup mesage for writting
  bootloader to floppy (bnc#333459)
- added fix meesage about writting bootloader to floppy includes
  "Cancel" button (bnc#433348)
- changed text about using XFS there is used "may not" insted of
  "will not" (bug#449823)
- updated help text
- 2.18.1
* Wed Feb  4 2009 juhliarik@suse.cz
- added fix for finding the smallest partition on pmac machine
  (bnc#459860)
- updated function Dev2MountByDev() which can run long time if
  machine included huge number of disks (bnc#468922)
- added fix for problem with adding boot entry to EFI if
  installation run on different disk but with same boot partition
  (bnc#450682)
- added fix for using translated text in bootloader e.g. Image,
  Other (bug#445999)
- 2.18.0
* Tue Jan 20 2009 juhliarik@suse.cz
- added fix for problem with calling parted each time when
  yast2-bootloader is called (bnc#461613,#357290)
* Thu Jan 15 2009 juhliarik@suse.cz
- added fix for problem with lines_cache_id == "" -it is cause of
  error output from perl-Bootloader (bnc#464098)
* Wed Jan 14 2009 juhliarik@suse.cz
- added fix for changing EFI label in running system (bnc#269198)
- added fix for problem with primary language in GRUB (bnc#447053)
* Thu Dec 11 2008 juhliarik@suse.cz
- added fix for problem with autoinstallation and powerlilo
  (bnc#439674)
- added fix for (bnc#450506) root=kernelname
- added fix for problem with adding kernel to proposal (SLERT)
  (bnc#450153)
- 2.17.46
* Mon Dec  8 2008 juhliarik@suse.cz
- added fix for problem with installation if boot device is NFS
  (bnc#440183)
* Sun Dec  7 2008 juhliarik@suse.cz
- deleted support of detail settings for trustedgrub because it is
  not supporeted by trustedgrub package
* Thu Dec  4 2008 juhliarik@suse.cz
- 2.17.45
* Tue Dec  2 2008 juhliarik@suse.cz
- added fix for onetime boot if default is windows (bnc#339024)
* Tue Dec  2 2008 juhliarik@suse.cz
- updated heuristic for adding other OS to menu.lst for GRUB
  (bnc#448010)
* Mon Dec  1 2008 juhliarik@suse.cz
- added fix for proposal if MBR include Vista code and "/" is on
  logical partition (bnc#450137)
- added update of handling serial console (bnc#449726)
- 2.17.44
* Mon Dec  1 2008 juhliarik@suse.cz
- added fix for problem with multipath (bnc#448110)
- added fix for problem with cloning boot sections (bnc#450190)
* Thu Nov 27 2008 juhliarik@suse.cz
- added fix for problem with missing "console" (bnc#449726)
- 2.17.43
* Thu Nov 27 2008 juhliarik@suse.cz
- deleted fix for (bnc#439674) - it fix problem with proposal of
  globals on PPC (bnc#449747)
- 2.17.42
* Wed Nov 26 2008 juhliarik@suse.cz
- 2.17.41
* Wed Nov 26 2008 juhliarik@suse.cz
- added fix for problem with "boot" in lilo.conf (bnc#449062)
* Tue Nov 25 2008 juhliarik@suse.cz
- added fix for problem with changed default section (bnc#446555)
* Tue Nov 25 2008 jsrain@suse.cz
- write correct language list in /boot/message (bnc#447053)
* Tue Nov 25 2008 juhliarik@suse.cz
- added fix for recreating device map (bnc#438243)
- updated proposal if boot device is on logical partition
  (bnc#279837#c53)
* Mon Nov 24 2008 juhliarik@suse.cz
- updated proposal of bootloader (bnc#279837#c53)
- added fix for recreating device map if storage change settings
  (bnc#438243)
* Fri Nov 21 2008 juhliarik@suse.cz
- updated fix for checking if boot entry exist in EFI (bnc#438215)
- 2.17.40
* Wed Nov 19 2008 juhliarik@suse.cz
- added fix for problem with writing default kernel args to
  /etc/sysconfig/bootloader (bnc#440125)
-2.17.39
* Wed Nov 12 2008 juhliarik@suse.cz
- deleted adding beep for booting (bnc#439328)
- 2.17.38
* Wed Nov 12 2008 juhliarik@suse.cz
- added fix for problem with missing boot_* in globals (bnc#439674)
* Mon Nov 10 2008 juhliarik@suse.cz
- added fix for problem with disabled button for detail settings of
  trusted GRUB (bnc#442706)
- added calling function Pkg::SourceProvideFile() (bnc#409927)
- 2.17.37
* Fri Nov  7 2008 juhliarik@suse.cz
- added fix for writing crashkernel to bootloader from kdump on ppc
  (bnc#441547)
- added fix for double boot entry twice by efibootmgr (bnc#438215)
- added fix for using fix_chs (bnc#367304)
- 2.17.36
* Fri Oct 31 2008 juhliarik@suse.cz
- added better proposal checking elilo ,lilo
- added fix for typo (bnc#439030)
- added fix for selectinf "none" bootloader (bnc#438976)
- 2.17.35
* Mon Oct 27 2008 juhliarik@suse.cz
- updated checking of boot device s not on XFS (bnc#438757)
- added fix for problem with generic boot code (bnc#438752)
- 2.17.34
* Mon Oct 27 2008 jsrain@suse.cz
- updated method of ThinkPad MBR detection
- 2.17.33
* Mon Oct 27 2008 juhliarik@suse.cz
- added fix for using persistent device name in lilo (bnc#437764)
- 2.17.32
* Fri Oct 24 2008 juhliarik@suse.cz
- added fix for problem with converting lilo to grub during update
  system
- added fix - deleting read-only option for elilo (bnc#438276)
* Thu Oct 23 2008 juhliarik@suse.cz
- added fix for broken titles in lilo (bnc#437693)
* Tue Oct 21 2008 juhliarik@suse.cz
- update for bug with deleting boot section (bnc#436890)
- 2.17.31
* Tue Oct 21 2008 juhliarik@suse.cz
- added fix for problem with deleting all boot section for elilo
  (bnc#436890)
- added fox for problem with XEN boot section in domU (bnc#436899)
- 2.17.30
* Fri Oct 17 2008 juhliarik@suse.cz
- added fix for adding language to GRUB (bnc#429287)
- 2.17.29
* Thu Oct 16 2008 juhliarik@suse.cz
- added fix for using autoyast profil from SLES9 (bnc#344659)
* Thu Oct 16 2008 juhliarik@suse.cz
- added fix for handling mounpoints (bnc#431977)
* Wed Oct 15 2008 juhliarik@suse.cz
- added fix to proposal with "/" on logical partition (bnc#259050)
* Wed Oct 15 2008 jsrain@suse.cz
- handle multipath devices properly when creating device map
  (bnc#433092)
- 2.17.28
* Mon Oct 13 2008 juhliarik@suse.cz
- added fix for translation labes for ELILO (bnc#151486)
- added fix for typo in help text (bnc#433424)
- added fix for problem with device names in live CD installation
  (bnc#432699)
- 2.17.27
* Fri Oct 10 2008 jsrain@suse.cz
- fixed bootloader proposal in mixed standalone disk and BIOS-RAID
  environments (bnc#433092)
- issue a warning if /boot directory is on XFS on x86 boot
  architecture (bnc#429042)
* Wed Oct  8 2008 juhliarik@suse.cz
- added fix for handling nil from function InitializeBootloader()
* Wed Oct  8 2008 juhliarik@suse.cz
- added fix for adding crashkernel from y2-kdump (bnc#432651)
- added fix for writing proposal (bnc#433344)
- added fix for checking if boot device is on raid0 (bnc#156800)
- 2.17.26
* Fri Oct  3 2008 juhliarik@suse.cz
- added fix for installing packages (bnc#431580)
- added fix for 2 identical section in powerLILO (bnc#427730)
- added fix for mapping disk by label for powerLILO (bnc#41497)
- 2.17.25
* Tue Sep 30 2008 juhliarik@suse.cz
- updated fix for converting LILO to GRUB (bnc#430579)
- 2.17.24
* Mon Sep 29 2008 juhliarik@suse.cz
- added new dialog for updating from lilo to grub (bnc#430579)
- 2.17.23
* Mon Sep 29 2008 jsrain@suse.cz
- fixed no scrren contents after changing loader type (bnc#427622)
- avoid mixing options of different bootloader after loaded type
  change
* Thu Sep 25 2008 juhliarik@suse.cz
- added fix for problem with changed default name (bnc#169062)
- added fix for problem with editing custom boot  (bnc#395009)
- added fix for problem with timeout update (bnc#395851)
- 2.17.22
* Thu Sep 18 2008 juhliarik@suse.cz
- added fix for initialise yast2-stroage (bnc#419197)
- help update (bnc#220283)
- 2.17.21
* Tue Sep 16 2008 juhliarik@suse.cz
- added fix for deleting fake xen boot section (bnc#408346)
- added fix for failsafe options for kernel (bnc#419464)
- 2.17.20
* Tue Sep 16 2008 juhliarik@suse.cz
- added fix for getDefaultSection() for zipl (bnc#364904)
- added fix for deleting gfxmenu from menu.lst (bnc#398806)
- 2.17.19
* Tue Sep 16 2008 juhliarik@suse.cz
- added fix for problem with rnc file - syntax error (bnc#426522)
- 2.17.18
* Fri Sep 12 2008 juhliarik@suse.cz
- added support of trusted grub (fate#303784), (fate#303672),
  (fate#303891), (fate#303983)
- added warning that lilo is not supported (fate#305006)
- 2.17.17
* Thu Sep 11 2008 locilka@suse.cz
- Calling new reipl_bootloader_finish client from yast2-reipl
  in bootloader_finish (fate#304960).
- 2.17.16
* Thu Sep 11 2008 jsrain@suse.cz
- merged texts from proofread
* Wed Sep  3 2008 jsrain@suse.cz
- added detection of EFI, proposing ELILO in that case
  (fate#301882)
- 2.17.15
* Wed Aug 20 2008 jsrain@suse.cz
- added skeleton for checking whether scenario is supported, not
  yet actually used (fate#304499)
* Mon Aug 18 2008 jsrain@suse.cz
- store bootloader type before installing packages, fixed check
  for undefined product name (bnc#417383)
- 2.17.14
* Thu Aug 14 2008 juhliarik@suse.cz
- added support for creating console for kernel args (fate#110038)
- 2.17.13
* Wed Aug 13 2008 juhliarik@suse.cz
- added changes for pesistent device names (fate#302219)
- 2.17.12
* Wed Aug  6 2008 juhliarik@suse.cz
- added better detection of NFS boot device (bnc#408912)
- added better detection of EVMS - do not install bootloader
  (fate#305007)
- 2.17.11
* Wed Aug  6 2008 juhliarik@suse.cz
- added support for acoustic signals (fate#303481)
- added checkbox for enabling remapping in chainloader section
- 2.17.10
* Tue Aug  5 2008 juhliarik@suse.cz
- added/enabled support for ordering disks in device.map for GRUB
  (fate#303964)
- 2.17.9
* Mon Aug  4 2008 juhliarik@suse.cz
- added support for reducing devices from device.map to 8 devices
  (fate#303548)
- 2.17.8
* Thu Jul 31 2008 juhliarik@suse.cz
- added support for remaping windows chainloader boot section
  (fate#301994)
- 2.17.7
* Tue Jul 29 2008 juhliarik@suse.cz
- update solution for saving kernel args to
  /etc/sysconfig/bootloader (fate#302245)
- 2.17.6
* Sun Jul 27 2008 juhliarik@suse.cz
- added powersaved=off to boot section for failsave (bnc#153345)
* Wed Jul 23 2008 juhliarik@suse.cz
- added support for persistent device names (fate#302219)
- 2.17.5
* Mon Jul 21 2008 juhliarik@suse.cz
- 2.17.4
* Wed Jul 16 2008 jsrain@suse.cz
- store kernel parameters to sysconfig during installation
  (fate#302245)
* Fri Jul 11 2008 ug@suse.de
- rnc file fixed (bnc#407615)
* Thu Jul 10 2008 juhliarik@suse.cz
- enable installing GRUB to XEN  (bnc#380982)
- 2.17.3
* Fri Jun 27 2008 juhliarik@suse.cz
- correct labels for buttons  (bnc#398492)
* Thu Jun 26 2008 juhliarik@suse.cz
- deleted support xenpae (bnc#400526)
- 2.17.2
* Thu Jun 26 2008 juhliarik@suse.cz
- added support for better detection Vista in MBR
- added fix for installing generic code if MBR is uknown (bnc#400062)
- added fix for detection MBR if sw-raid is used (bnc#398356)
- 2.17.1
* Mon Jun  9 2008 juhliarik@suse.cz
- added fix for problem with booting Vista bnc #396444
- 2.16.20
* Wed Jun  4 2008 juhliarik@suse.cz
- added fix for problem with deleting boot sections bnc #396810
- 2.16.19
* Wed Jun  4 2008 juhliarik@suse.cz
- added fix for problem with liveCD and simlinks for initrd and
  kernel (bnc# 393030)
- 2.16.18
* Mon May 26 2008 juhliarik@suse.cz
- added fix for problem with editing boot section for LILO
  (bnc# 340732)
- added fix for cloning boot section (bnc# 390719)
- 2.16.17
* Fri May 16 2008 jsrain@suse.cz
- added categories Settings and System into desktop file
  (bnc #382778)
* Thu May 15 2008 juhliarik@suse.cz
- added fix for bnc# 164884 - disabled Back button during
  installation
- added missing strings bnc# 386527
- 2.16.16
* Wed May  7 2008 juhliarik@suse.cz
- added fix for bnc#335526 - problem with adding "resume" into
  boot section for memtest
- 2.16.15
* Mon Apr 28 2008 juhliarik@suse.cz
- added fix for bnc#232424 - problem with propose new config.
- 2.16.14
* Tue Apr 22 2008 juhliarik@suse.cz
- added fix for bnc#363254
- added fix for UI problem with ComboBoxes and "Browse..." button
- 2.16.13
* Fri Apr 18 2008 juhliarik@suse.cz
- added fix for (bnc#381192) bootloader uses grubonce _and_ kexec
- added detecting VirtualBox - cancel using kexec
- 2.16.12
* Thu Apr 17 2008 juhliarik@suse.cz
- new version
- 2.16.11
* Thu Apr 17 2008 locilka@suse.cz, juhliarik@suse.cz
- fixed initializing of combo-box widgets in dialogs, ComboBox
  in Qt does not accept `Value, using `Items instead (bnc #380781).
- using `InputField as a replacement for obsolete `TextEntry.
* Wed Apr 16 2008 juhliarik@suse.cz
- added fix for activating DM-RAID boot partition (bnc #337742)
- added fix for lilo and raid version (bnc #357897)
- 2.16.10
* Fri Apr 11 2008 juhliarik@suse.cz
- added handling of option for calling kexec instead of reboot
  (fate#303395)
- 2.16.9
* Tue Apr  1 2008 jsrain@suse.cz
- adapted to changed handling of inst_finish steps during live
  installation
* Thu Mar 27 2008 juhliarik@suse.cz
- added deleting of duplicated sections after installation
- 2.16.8
* Thu Mar 20 2008 jsrain@suse.cz
- updated the way section list is displayed in the installation
  proposal (fate#120376)
- 2.16.7
* Tue Mar 18 2008 jsrain@suse.cz
- keep the 'linux' section name if product name is empty
  (bnc#371741)
* Mon Mar 17 2008 jsrain@suse.cz
- added 'StartupNotify=true' to the desktop file (bnc #304964)
* Fri Mar 14 2008 juhliarik@suse.cz
- added inst_bootloader for saving config file before installing
  kernel (F #302660)
- 2.16.6
* Thu Jan 31 2008 locilka@suse.cz
- Update::*version were moved to Installation::*version.
- 2.16.5
* Thu Jan 24 2008 juhliarik@suse.cz
- added patch for Bug#352020 - Graphical failsafe mode
- added support for Fate#300779: Install diskless client (NFS-root)
- 2.16.4
* Tue Dec 11 2007 jsrain@suse.cz
- do not translate boot menu to unsupported language (#310459)
- 2.16.3
* Wed Dec  5 2007 jsrain@suse.cz
- fixed the device map proposal if USB stick is present (F#302075)
* Wed Oct 31 2007 dfiser@suse.cz
- Adapted to change of StorageDevices API.
- v2.16.2
* Wed Oct 31 2007 locilka@suse.cz
- installedVersion and updateVersion moved from 'Update' to
  'Installation' YCP module to remove dependencies.
* Thu Oct 11 2007 od@suse.de
- migrate SLES9 persistent device ("...p1") names to SLES10
  persistent device names ("...-part1") (#162216)
- 2.16.1
* Wed Sep 26 2007 od@suse.de
- added flag avoid_reading_device_map to blRead(), all internal
  Read()s and ReadSettings() interface to perl-Bootloader: used by
  BootLILO and BootGRUB during update to migrate device names in
  the device_map and then re-read the config files with correct
  device name translation (#328448)
- do not install bootloader in XEN paravirtualized DomU (#308451)
- 2.15.29
* Tue Sep 25 2007 od@suse.de
- re-read bootloader config from system after the delayed run of
  perl-Bootloader updates, then call FlagOnetimeBoot() based on
  current setup (#328078)
- 2.15.28
* Tue Sep 25 2007 od@suse.de
- added logging to find problem in #328078
- minor addition of whitespace
- 2.15.27
* Mon Sep 24 2007 od@suse.de
- Storage::GetTranslatedDevices() called often and uneccesarily
  (related to #304269):
  - added more logging to UpdateSections()
  - added comments and FIXMEs
  - disabled calling device name update again for "linux",
    "failsafe" and "initrd" sections: this is not needed and would
    reverse device name updates when forwards and backwards device
    name update mappings exist
  - enabled device name updates for "other" sections (booting other
    installations)
- (related to #326372, see comment #12)
  - fix "Interpreter" error: also activates persistent device
    translation for device.map in yast2-bootloader (but no disk
    device mappings are defined in yast2-storage, so devices remain
    untranslated as of now)
- 2.15.26
* Fri Sep 21 2007 od@suse.de
- run delayed bootloader_entry at the very end of the update, when
  the migrated bootloader configuration (including device mapping)
  has already been written (#309837)
- added some comments
- 2.15.25
* Thu Sep 20 2007 od@suse.de
- log the contents of the perl-BL_delayed_exec script (#309837)
- 2.15.24
* Thu Sep 20 2007 od@suse.de
- ckornacker@suse.de: added PREFIX to Makefile.cvs
- when bootloader_entry saved (during kernel postuninstall) a
  command in /boot/perl-BL_delayed_exec for delayed execution in
  the target system, run that script to remove old sections
  (#309837)
- 2.15.23
* Tue Sep 18 2007 od@suse.de
- update the default entry during update when the comment with the
  former default exists, even if the current default is valid
  (#309837)
- 2.15.22
* Mon Sep 17 2007 od@suse.de
- #309837:
  - fix setting the default section at the end of an update,
    according to saved previous default kernel image flavor
  - use fallback flavors if previous flavor is unavailable
- 2.15.21
* Thu Sep 13 2007 od@suse.de
- specify blockoffset as string, rather than number
- added a FIXME comment
- fixed conversion of obsolete filenames in kernel and initrd keys
- fixed conversion of device names in root and chainloader keys
  (#309837)
- 2.15.20
* Tue Aug 28 2007 pth@suse.de
- Fix the code in bootloader_finish so that the one-time-boot code
  is actually called.
- Redo the logic and structure of the one-time booting code.
  * Global Write uses Bootloader::getDefaultSection() to determine the
    section name.
  * New function BootCommon::Section2Index that determines the
    index # for a given section, currently only used by
    BootGRUB::FlagOnetimeBoot.
* Wed Aug 15 2007 od@suse.de
- forgot to use changed sections (feature #302302)
- added logging with y2milestone()s for last change
- 2.15.17
* Mon Aug 13 2007 od@suse.de
- grub: feature #302302:
  - added code to UpdateSections() to update old sections for
    "other" installations to chainloader/configfile sections
  - moved PBR-examination code to function IsPartitionBootable(),
    used by BootGRUB::CreateSections() and
    BootCommon::UpdateSections() now
  - always use a "root" command for "other" installations: added
    a "root" command to chainloader entries
  - also use "noverifyroot" and "blockoffset" in chainloader
    entries
  - added a FIXME comment
- 2.15.16
* Fri Aug 10 2007 od@suse.de
- part of feature #301313:
  - added front-end function and infrastructure in switcher.ycp for
    FlagOnetimeBoot()
  - added FlagOnetimeBoot() implementation for POWERLILO
- fixed return codes of examine_mbr.pl: do not overlap error codes
  with "bootloader stage1 needs to be (re)-installed here" return
  code
- evaluate new return code in yast2-bootloader
- added documentation comment to examine_mbr.pl
- changed documentation comments where yast2-bootloader calls
  examine_mbr.pl
- fixed error in autoinstall client that prevented importing legacy
  global keys
- added/fixed some comments
- added documentation comments to BootGRUB::CreateSections()
- changed two y2debug() into y2milestone()
- fixed: a chainloader entry may have been produced that pointed to
  the boot partition of our current installation
- grub: implemented booting other Linux installations on the system
  via chainloader/configfile entries (feature #302302)
- fixed: if-block contained no statement, uncommented y2debug() in
  there
- 2.15.15
* Thu Jul 26 2007 jsrain@suse.cz
- removed unneeded yast2-devel from BuildRequires
- 2.15.14
* Fri Jul 20 2007 od@suse.de
- preventing cyclic dependency in autobuild with a BuildIgnore on
  autoyast2-installation
- 2.15.13
* Fri Jul 13 2007 od@suse.de
- converting old key "kernel" to new key "image" when converting
  autoyast configuration to export map (#285790)
- re-added lost y2milestone() to BootELILO.ycp
- creating "image" section instead of "kernel" section now in
  CreateLinuxSection()
- 2.15.11
* Tue Jul 10 2007 od@suse.de
- Merge from SLES10-SP1 branch:
- let "SLES 9 style" autoyast xml files configure bootloader
  timeout (#214468, #183051)
- added help texts and widget descriptions to grub and elilo
  (#221737)
- Fixed type of passed arguments in function Import() (in
  modules/Bootloader.ycp & modules/BootELILO.ycp) (#236163)
- bootloader.rnc fixed for autoyast schema check
- set __auto key to false when user clones sections (#241158)
- added log message when FixSections() silently discards a section
  (#241158)
- fixed some whitespace
- fixed myToInteger(): return 0 if string cannot be converted to
  integer
- bootloader.rnc fixed for autoyast schema check (#211014)
- always log the target map when Propose() is called (not only when
  we debug)
- convert custom boot device names to the names indicated by the
  mountby setting; this is one part of a change to use persistent
  device names for the bootloader boot device, the rest requires
  simultaneously changing perl-Bootloader because of an
  incompatible interface change
  (#248162)
- #214468:
  - fixed autoyast schema
  - fixed import of autoyast data: do not remove the "default" option
- GRUB only: integrated the new boot_*, generic_mbr and activate
  keys (found in the "globals" map) from the new
  widget/perl-Bootloader interface into the internal workings of
  the grub code
  - for grub, this obsoletes the global variables loader_device,
    selected_location (aka loader_location), repl_mbr and activate
  - fixes loosing the information of multiple selected bootloader
    installation devices (#245680)
  - fixes faulty detection of user-changes to the "/boot" and "/"
    devices from yast2-storage (#247852)
  - decided that boot_mbr_md key is unneeded, because the decision
    to write to the MBRs of all underlying devices of a soft-RAID
    is automatic (kept commented-out sample code for boot_mbr_md)
  - decided that boot_extended is unneeded, because the decision to
    write the bootloader to the extended partition instead of to an
    un-activatable "/boot" or "/" partition is automatic (kept
    commented-out sample code for boot_extended)
  - removed wrapper code for variable translation from
    BootGRUB::Propose()
  - made private copies of functions in grub/misc.ycp and changed
    the code to use the new interface variables only (this is also
    wanted for better code separation between bootloaders, to
    reduce amount of special-case handling (to be worked on)):
  * from routines/misc.ycp:
    grub_getPartitionToActivate ()
    grub_getPartitionsToActivate ()
    grub_getMbrsToRewrite ()
    grub_getFileChangeDate ()
    grub_saveMBR ()
    grub_updateMBR ()
    grub_DetectDisks ()
  * from routines/lilolike.ycp:
    grub_ProposeDeviceMap ()
    ( ^^ really needed? no changes here, it just "belongs"
    to grub...)
    grub_ConfigureLocation()
    grub_DetectDisks ()
    grub_DisksChanged ()
    grub_LocationProposal ()
  - added helper functions:
    grub/misc.ycp:          SetBootloaderDevice()
    routines/misc.ycp:      GetBootloaderDevices()
  - added note to to-be-phased-out functions:
    routines/misc.ycp:      GetBootloaderDevice()
  - made some functions globally accessible:
    routines/popup.ycp:     askLocationResetPopup ()
    routines/misc.ycp:      myToInteger ()
    routines/lilolike.ycp:  FindMBRDisk ()
  - fixed bug with the detection of MD-RAID devices (both in
    grub_getPartitionToActivate and getPartitionToActivate): BIOS
    ID was assumed to be less than 128, but it starts at 128
  - commented out some obsolete and broken code that would activate
    the "/boot" device on installation of the bootloader to MBR;
    the code was cancelled out by program logic ("activate" flag)
    though;
    this also simplified the interface to getPartitionToActivate ()
  - added conditionals to Bootloader.ycp and BootCommon.ycp: do not
    handle obsolete variables for grub
  - commented out probably obsolete code in BootGRUB::Read() to
    determine old_style loader_device from read devices (including
    old-style "mbr_md")
  - added several FIXME:s
  - changed a fixed FIXME to FIXED
- when reading settings from the system: convert custom boot device
  names in globals to the kernel device names (#248162)
- corrected whitespace in grub/helps.ycp and ppc/helps.ycp
- fix faulty detection of user-changes to the "/boot" and "/"
  devices from yast2-storage: rewrote grub_DisksChanged() to work
  properly with boot_* variables (previous fix did not work
  correctly) (#247852)
- grub_DisksChanged() now returns a message summarizing all changes
  for selected bootloader devices; this message is now used in the
  popup that ask the user if he wants to repropose after a
  partitioning change (in askLocationResetPopup()) (#247852)
- rewrote check for disk changes to work with multiple selected
  bootloader locations in grub_DetectDisks() and
  grub_LocationProposal() (#247852)
- the summary message for GRUB now includes a short string ("/",
  "/boot", MBR) that gives the reason why each device has been
  selected for bootloader stage 1 installation
- changed comment for GetBootloaderDevices()
- GRUB only: accept old-style autoyast keys "repl_mbr" "activate" and
  "location" when importing an autoyast profile; "loader_device" is
  ignored (which may be fixable if we can make sure a target map is
  available) (#245680)
- grub:
  - if autoyast profile does not specify a bootloader location,
    propose one (#263305)
  - if autoyast profile does not specify a key for the default keys
    set by a yast-bootloader proposal, add these missing
    keys/values
- enabled translation of the kernel image name from the symlink to
  the real kernel file for the "failsafe" section; perl-Bootloader
  can handle this now
- convert device names in the grub device map to and from the
  "mount_by" device names as well (#248162)
- Changed location of EFI Bootloader Label widget in YaST2 gui (#242985)
- make installation of bootloader to the extended partition work
  with new design (#246161, #259050)
- enabled extended device handling in GetBootloaderDevices as well
- make persistent device names work with boot= directive for i386
  lilo (#248162)
- log conversion of old-style global keys from autoyast profile to
  new-style keys
- during update, update value of "default" directive for lilo and grub
  (#266534)
- do not show popup for changed MBR position when it did not
  change: use correct function for MBR detection (#267276)
- fixed autoyast logging change
- Fix for removal of wrong efiboot entries (#269130)
- fix for update-mode: fix updating of kernel-image and initrd
  filenames to the resolved symlinks (image-version and
  initrd-version) (#268731, helps not to trigger #267582 and
  [#244033])
- #270202:
  - grub: fix erroneously added section "Hard Disk" on systems
    without a floppy drive: use new style variables for detecting
    that we install stage1 to a floppy disk
  - for bootloaders that still use the old style variables, check
    for undefined loader_device before comparing to floppy device
- 2.15.10
* Fri Jul  6 2007 od@suse.de
- Remove limal-devel from BuildRequires again
- 2.15.9
* Wed Jul  4 2007 aj@suse.de
- Add limal-perl to Requires as well.
* Wed Jul  4 2007 aj@suse.de
- Fix BuildRequires so that package builds again.
* Tue Jul  3 2007 od@suse.de
- re-added limal-devel to BuildRequires
* Tue Jul  3 2007 od@suse.de
- moved Bootloader_API.pm from limal-bootloader to yast2-bootloader
* Thu Jun 21 2007 adrian@suse.de
- fix changelog entry order
* Fri May 25 2007 jsrain@suse.cz
- removed outdated translations from .desktop-files (#271209)
* Wed Apr 11 2007 aosthof@suse.de
- Fixed erroneous EFI Bootloader Label (#242985) in BootELILO.ycp
- Fixed removal of obsolete entries in EFI Boot Menu in
  BootELILO.ycp (#237873)
- 2.15.8
* Thu Mar  1 2007 aosthof@suse.de
- Reverted to make Xen kernel default boot kernel if Xen pattern
  or Xen RPMs are installed. (Fate #301384)
- 2.15.7
* Tue Feb 27 2007 od@suse.de
- include yast2-storage in BuildRequires
- 2.15.6
* Mon Feb 26 2007 od@suse.de
- safeguard against mount-by device that does not exist (yet): fall
  back to kernel name (#239473, #223608)
- fix entry for memtest86, it is named memtest86+ meanwhile
- collecting device information for perl-Bootloader now works with
  persistent device names; this caused a bug in the grub
  configuration where the gfxmenu entry was discarded because the
  device name could not be translated, as well as unbootable system
  (#244566, #247775)
- 2.15.5
* Tue Jan 23 2007 aosthof@suse.de
- Forgot to delete "src/clients/bootfloppy.ycp" and
  "src/config/bootfloppy.desktop" from SVN (#218437)
* Tue Jan 23 2007 aosthof@suse.de
- Removed bootfloppy module due to malfunction (#218437)
- 2.15.4
* Wed Jan 17 2007 jplack@suse.de
- revise efi boot manager entry handling (#233537)
* Tue Jan 16 2007 jplack@suse.de
- fix various zipl configuration problems (#235486)
* Mon Jan 15 2007 jplack@suse.de
- more stream lining in help messages
* Mon Jan 15 2007 jplack@suse.de
- handle efi boot manager entries properly (#233537)
* Mon Jan 15 2007 jplack@suse.de
- add label text snippets for grub so that they can get translated
* Thu Jan 11 2007 jplack@suse.de
- make xen section the first entry which will get the default
  though (FATE#301384)
* Wed Jan 10 2007 jplack@suse.de
- mostly complete fix for #228833, wrong elilo configurator
* Fri Jan  5 2007 jplack@suse.de
- fixed message handling, proposal, dialog handling for zipl, etc.
  (#228841, Fate#300732)
* Fri Dec 22 2006 jplack@suse.de
- do map "kernel" tag to "image" tag for now, so that proposal gets
  interpreted right.
* Fri Dec 22 2006 aosthof@suse.de
- Fixed "Propose New Configuration" in Bootloader Settings in YaST
  - Part 1 (#230230)
- Fixed "Propose New Configuration" in Bootloader Settings in YaST
  - Part 2 (#230230)
- 2.15.2
* Thu Dec 14 2006 jplack@suse.de
- code review and cleanup: eliminate dead code, eliminate simple
  functions used once, keep local functions local (part2)
* Mon Dec 11 2006 jplack@suse.de
- code review and cleanup: eliminate dead code, eliminate simple
  functions used once, keep local functions local (part1)
* Mon Dec 11 2006 jplack@suse.de
- replace Kernel::GetFinalKernel function which is broken by design
  by Kernel::ComputePackage.
* Mon Dec 11 2006 jplack@suse.de
- move CheckAdditionalKernels from misc to Grub and fix that crappy
  stuff
* Fri Dec  8 2006 od@suse.de
- related to help_messages and descriptions:
  - added comments to generic_Description() and the descriptions
    variable
  - corrected one warning and one debug message
  - renamed arch_widget_name to loader_widget_name, matching new
    functionality
- 2.15.1
* Fri Dec  8 2006 jplack@suse.de
- basic implementation for generic bootloader widgets for ELILO
  (Fate#300732)
* Fri Dec  8 2006 jplack@suse.de
- more zipl changes for Fate#300732
- merge elilo/misc into basic module
* Fri Dec  8 2006 jplack@suse.de
- basic implementation for generic bootloader widgets for ZIPL
  (Fate#300732)
* Fri Dec  1 2006 od@suse.de
- use kernel and initrd softlinks in Failsafe entry again, thus
  preventing the removal of the Failsafe entry when the kernel is
  updated (#224481)
- 2.14.15
* Fri Dec  1 2006 jplack@suse.de
- signal change of boot loader location so that the boot loader can
  be rewritten if needed (#225023)
- 2.14.14
* Fri Nov 24 2006 aosthof@suse.de
- fixed usage of function remove()
- added FIXME
- fixed typo in comment
- actually use sorted DMTargetMap by adding bios_ids (#223473)
- 2.14.13
* Fri Nov 24 2006 od@suse.de
- fixed typo in a comment
- added a FIXME in BootCommon
- added kernel and image file link resolve code to
  BootPOWERLILO.ycp (adapted from BootCommon.ycp)
- Fix broken bootloader configuration on ppc: initialize library
  at the appropriate point again (#210535)
- 2.14.12
* Fri Nov 24 2006 aosthof@suse.de
- Sorted DMTargetMap in lilolike.ycp to match the BIOS order
  (#223473)
- Fixed typos in lilolike.ycp
- 2.14.11
* Wed Nov 22 2006 ug@suse.de
- schema file fixes (#215263)
* Wed Nov 22 2006 aosthof@suse.de
- Fixed typo in lilolike.ycp (#223145)
- 2.14.10
* Tue Nov 21 2006 aosthof@suse.de
- Fixed target map for dmraids (aka FakeRAIDs) in lilolike.ycp
  (#222471)
- 2.14.9
* Tue Nov 21 2006 od@suse.de
- have a current target map available in the log when we debug
- added y2milestone()s around remapping
- fix forgetting to rewrite some kernel/image entries (ycp really
  should have a for loop, so resetting variables is not forgotten)
  (#214935)
- 2.14.8
* Tue Nov 21 2006 jplack@suse.de
- UpdateInitrdLine function is old, broken, rotten and completely
  useless now
* Tue Nov 21 2006 jplack@suse.de
- suppress newline from readlink command, breaks config files
- 2.14.7
* Tue Nov 21 2006 jplack@suse.de
- "activate" and "generic_mbr" do now get set if newly proposed
* Mon Nov 20 2006 od@suse.de
- #214935:
  - added more comments
  - only resolve symlinks for linux, xen and failsafe sections,
    type image and xen
  - do not resolve symlinks for files that are not on the default
    boot partition (because they have a grub device name prefix)
  - added more logging
  - actually use the resolved symlinks for kernel and initrd
- moved some comments to the right position in the code
- 2.14.6
* Mon Nov 20 2006 jplack@suse.de
- quick fix for problems with Xen pattern selection (#208380):
  never use cached_proposal for now
* Mon Nov 20 2006 od@suse.de
- reverted initrd and kernel names to links for everything but
  Mode::normal() (#214935)
- resolve symlinks for kernel and initrd during inst_finish, so
  that the "real names" are put into the bootloader configuration
  - - this is the plan B solution, plan A (which shows correct
  filenames instead of link names in the proposal) does not
  currently work (#214935)
- 2.14.4
* Mon Nov 20 2006 jplack@suse.de
- fix format for DefaultKernelParams
* Mon Nov 20 2006 jplack@suse.de
- fix boot loader location mapping: check boot_root before
  boot_boot (#219409)
* Mon Nov 20 2006 jplack@suse.de
- fix full adoption to new grub name sceme ((#214935, FATE#300732)
* Fri Nov 17 2006 od@suse.de
- added comments
- fix finding the correct names for kernel image and initrd (not
  yet fixed for powerlilo) (#214935)
- first part of fix for resetting user changes when going to expert
  settings
- 2.14.3
* Thu Nov 16 2006 jplack@suse.de
- section type of 'xen' is now handled (FATE#300732)
* Wed Nov 15 2006 jplack@suse.de
- fixed Summary generation for Grub (#220285), did still consider
  old-style variable loader-device
* Wed Nov 15 2006 jplack@suse.de
- widget for type selectdevice did not get initialized (#221180)
* Mon Nov 13 2006 od@suse.de
- add more variables for the new perl-Bootloader interface to the
  autoyast DTD for yast2-bootloader: currently, the user needs to
  specify them if he wants to specify any global variable (which
  probably is the right interface for him)
- reverted BootGRUB to use FixGlobals(), this functionality is not
  a bug
- added comments to FixGlobals() and the call from BootGRUB to it
- move setting of boot_* and activate keys in globals for new
  perl-Bootloader interface from BootCommon::i386LocationProposal()
  in lilolike to the end of BootGRUB::Propose(), so that the need
  to set defaults for the other values in globals is detected and
  these are proposed as well (#219409)
- 2.14.1
* Mon Nov 13 2006 jplack@suse.de
- remove in ycp has bogus semantics (#220365)
* Mon Nov 13 2006 jplack@suse.de
- generic MBR not written/activate flag not set due to incomplete
  impl. of FATE#300732
* Mon Nov 13 2006 ug@suse.de
- schema file for autyast fixed
* Mon Nov 13 2006 jplack@suse.de
- fix missing proposal of global values during installation
  (#219409), function FixGlobals was inappropriate
* Thu Nov  9 2006 od@suse.de
- added a few comments to the new code
- fix trashing globals in grub et al.: use remove() to remove
  values from a map (#219409)
- 2.13.86
* Wed Nov  8 2006 od@suse.de
- moved change_widget_default_value() to BootCommon.ycp
- use change_widget_default_value() to work around "select" widget
  default value bug
- logging variables filled by grub proposal
- using correct variable (globals) for new perl-Bootloader
  interface (#213256)
- 2.13.85
* Wed Nov  8 2006 od@suse.de
- changed some comments
- move global_options, section_options and exports (new
  perl-Bootloader interface) to BootCommon.ycp
- pass proposal for grub to new perl-Bootloader interface (#213256)
- 2.13.84
* Tue Nov  7 2006 od@suse.de
- removed unused variable
- changed and added some documentation in comments
- fixed global options filtering for global options widget
  (#213256)
- 2.13.83
* Tue Oct 31 2006 od@suse.de
- autoyast Relax-NG Compact schema file added (#215263)
- 2.13.82
* Tue Oct 31 2006 od@suse.de
- fixed exporting the device map to autoyast (#211908)
* Mon Oct 16 2006 od@suse.de
- packaged missing grub/help.ycp and generic/help.ycp
- added comments to UpdateGfxMenuContents()
- 2.13.80
* Fri Oct 13 2006 sf@suse.de
- Bug #173486: do not display ssh message when installed with ssh
  and vnc
* Thu Oct 12 2006 jplack@suse.de
- implementation of generic password widget (FATE#300732)
* Mon Oct  9 2006 jplack@suse.de
- implement generic widget functionality for Grub (FATE#300732)
- 2.13.79
* Tue Sep 26 2006 jplack@suse.de
- part of new interface for FATE#300732
- 2.13.78
* Tue Sep 26 2006 jplack@suse.de
- implementation for FATE#120026: button to initialize bootloader
* Thu Sep 21 2006 od@suse.de
- jplack@suse.de: basic implementation for 'selectdevice' entry
  type which will act as a hook for more sophisticated UI handling
  for device-by-id selection and such.
- 2.13.77
* Fri Sep 15 2006 od@suse.de
- added caching of bootloader proposal patch by lslezak@suse.de,
  with some changed variable names and added comments (feature
  [#300709])
- 2.13.76
* Wed Sep 13 2006 od@suse.de
- reverted last change (in SVN) to bootfloppy.ycp, so the final
  correction to include this change of aosthof again:
  A few corrections had to be done related to wrong pathes (Bug
  [#180240])
- using parted for activation of boot partition again (instead of
  /sbin/activate from the lilo package) -- extended partition
  handling was fixed (#167602)
- 2.13.75
* Mon Sep 11 2006 mvidner@suse.cz
- Fixed autodocs.
* Mon Sep  4 2006 jplack@suse.de
- support new options no_os_chooser and optional (#202069, #202072)
* Tue Aug 22 2006 od@suse.de
- jplack: use new device_map format (#198244)
- 2.13.74
* Wed Jun 21 2006 uli@suse.de
- zipl: add "TERM=linux console=..." to proposal if booted with
  TERM=linux (bug #186970)
* Mon Jun 19 2006 aosthof@suse.de
- Fixed erroneous pathes in function createFloppyImage() in
  bootfloppy.ycp (#180240)
* Fri Jun  9 2006 od@suse.de
- when a change somewhere in the proposal causes a new section to
  be created (e.g. for a xen kernel), if the section does not yet
  exist and has not explicitly been deleted, add it to our proposal
  (#170469)
- added lots of commentary to FixSections()
- revert patch that added "powersaved=off" to append line in
  failsafe section - more testing needed (#153345)
- 2.13.73
* Thu Jun  8 2006 od@suse.de
- ppc: always initialize board type when making a proposal in an
  autoyast installation (#178831)
- 2.13.72
* Wed Jun  7 2006 od@suse.de
- add "powersaved=off" to append line in failsafe section for i386,
  x86_64 and ia64 (#153345)
- filter virtual mountpoints such as swap etc. (#182375)
- use full path to MD device (was broken since ever according to
  documentation)
- 2.13.71
* Fri Jun  2 2006 jplack@suse.de
- fixed raid 1 detection in lib_iface.ycp (#178802)
* Wed May 31 2006 od@suse.de
- check for RAID1 md arrays as all others will break on reboot
  (#178802)
- 2.13.69
* Wed May 31 2006 od@suse.de
- replace occurences of a-z and A-Z with character lists to prevent
  problems in some locales (#177560)
- 2.13.68
* Mon May 29 2006 od@suse.de
- iseries: fix proposal for NWSSTG boot device (#167390)
- 2.13.67
* Mon May 22 2006 jplack@suse.de
- add initial support for xenpae (#177051)
- 2.13.66
* Fri May 19 2006 od@suse.de
- added FIXME note to Bootloader.ycp
- send partitioning info always when Initializer called (#161755)
- 2.13.65
* Fri May 19 2006 od@suse.de
- fixed installation of installation kernel (ISERIES64) into slot A
  on iSeries (#165497)
- 2.13.64
* Wed May 17 2006 od@suse.de
- fix backwards mapping of "mount by" device names when bl
  configuration is read (#176201)
- revert last change in MountByDev2Dev() and use y2milestone()
  again
- 2.13.63
* Wed May 17 2006 od@suse.de
- added bootloader device conversion for mount by ID, UUID etc. to
  BootPOWERLILO (#174349)
- added debug messages to Dev2MountByDev()
- changed 2x y2milestone() -> y2debug() in MountByDev2Dev()
- 2.13.62
* Fri May 12 2006 od@suse.de
- during installation/update on ppc iseries, unconditionally
  install the ISERIES64 file from the installation media as rescue
  kernel into slot A (#165497)
- fixed some whitespace
- 2.13.61
* Fri May 12 2006 od@suse.de
- adapted to ppc/BootPOWERLILO.ycp: fixed mangled section titles
  after update (#170579)
- 2.13.60
* Wed May 10 2006 od@suse.de
- added comments to update code
- fixed mangled section titles after update (#170579)
- 2.13.59
* Wed May 10 2006 od@suse.de
- fix broken consistency check for legacy iSeries with DASD only
  (#166378)
- make it possible to manually add a value to selection list
  (needed for work arounds #166378 et. al.)
- fix error typo in lib_iface.ycp
- 2.13.58
* Thu May  4 2006 locilka@suse.cz
- merged texts from proofread
- 2.13.57
* Thu May  4 2006 jsrain@suse.cz
- change the message before reboot if performing an SSH
  installation (#160301)
* Tue May  2 2006 od@suse.de
- on ppc, never create a "failsafe" section (#170565)
- 2.13.56
* Tue May  2 2006 od@suse.de
- in UI, show explanatory message instead of missing UUID (before
  partition is formatted)
- added code readability comment
- 2.13.55
* Fri Apr 28 2006 od@suse.de
- fixed elilo section name fix from #170129:
  - getLoaderType() cannot be called from GfxMenu.ycp, so changed
    internal Interface of GfxMenu::translateSectionTitle() to
    accept "loader" parameter instead of "allow_blanks" parameter
  - updated other functions to use/pass through the "loader"
    parameter now:
    GfxMenu::UpdateGfxMenuContents()
    GfxMenu::getTranslationsToDiacritics()
    BootCommon::translateSectionTitle()
    BootCommon::UpdateGfxMenuContents()
- changed some y2milestone() messages: do not mention "lilo" when
  it can be any bootloader type other than "grub"
- added me as co-author to BootCommon.ycp
- 2.13.54
* Thu Apr 27 2006 od@suse.de
- examine_mbr.pl needs perl-Compress-Zlib
- 2.13.53
* Thu Apr 27 2006 od@suse.de
- on ia64, do not use the short product name in the "second
  level" bootloader elilo -- use "linux" again instead (also
  sidesteps bug #170129)
- added a comment for a future feature that may introduce two "menu
  levels" for grub as well
- 2.13.52
* Mon Apr 24 2006 sf@suse.de
- fixed regexp (Bug #168594)
* Fri Apr 21 2006 od@suse.de
- (#148931, #164950), fixes features #300383, #300160, #300358:
  - for root partitions in bootloader config: automatically use mount
    by id, path, uuid and label as set up in yast2-storage
  - also display these as "hints" in the UI
- fixed some comments
- added a y2milestone in getPartitionList()
- fixed some whitespace
- 2.13.50
* Thu Apr 20 2006 od@suse.de
- using /sbin/activate again (#167602)
- do not accept fsid 257 (on pmac) anymore, Apple_Bootstrap is now
  reported as fsid 258 (#167934)
- 2.13.49
* Wed Apr 12 2006 od@suse.de
- accept fsid 257 (Apple_Bootstrap) as pmac boot partition
  (#165518)
- 2.13.48
* Wed Apr 12 2006 od@suse.de
- print-product.ycp:
  - return short name for bootloaders other than grub (#163702)
  - do not attach version to product name (#165466)
- use short product name instead of "linux" as section name for
  bootloaders other than grub (#163702)
- 2.13.47
* Wed Apr 12 2006 od@suse.de
- long name uses LABEL from content file everywhere now, so do not
  attach version anymore (#163702)
- fixed typo in message
- 2.13.46
* Tue Apr 11 2006 od@suse.de
- on pmac: propose only partitions smaller than 20 cylinders
  (#158543)
- 2.13.45
* Tue Apr 11 2006 od@suse.de
- propose bootloader location on pmac systems (#158543)
- changed comment
- 2.13.44
* Tue Apr 11 2006 od@suse.de
- clone activate flag and loader_device for AutoYaST (#151501)
- 2.13.43
* Mon Apr 10 2006 jplack@suse.de
- write config even if no create_efi_entry has been requested
  (#163260)
* Mon Apr 10 2006 od@suse.de
- fixed invalid error on bootloader initialization (#164925)
- 2.13.41
* Mon Apr 10 2006 od@suse.de
- fix BootPOWERLILO to return proposal again (introduced with dead
  code elimination a few days ago)
- changed some comments for code around "activate"
- 2.13.40
* Fri Apr  7 2006 od@suse.de
- update_gfxmenu: added -f to rm to avoid error message on English
  installs (#163693)
- commented out dead code
- jplack/od: stop work flow for an illegal boot= selection
- 2.13.39
* Tue Apr  4 2006 od@suse.de
- changed more prep_boot_partition from "/dev/null" to "" (#163387)
- 2.13.38
* Tue Apr  4 2006 od@suse.de
- use empty string when no prep boot or FAT partition is found
  (#163387)
- 2.13.37
* Tue Apr  4 2006 jplack@suse.de
- update list of possible selections, each time a generic widget is
  "called" (#161755)
* Mon Apr  3 2006 od@suse.de
- do not add kernel option "selinux=0" on any architecture (#155856)
- fixed compilation errors in lib_iface.ycp
- 2.13.36
* Mon Apr  3 2006 jplack@suse.de
- ppc: update default name if denoted section has been updated
- ppc: update global clone entry, too, if device names changed
- fix for #161755, send partition/disk info where neccessary
- reorder code so that new function SetDiskInfo is formed and can
  be used in various places to fix #161755
- add proposed code change for virtual 'boot' mountpoints (#162242)
* Sat Apr  1 2006 od@suse.de
- added TESTME comment: test parted partition activation with BSD
  slices
- remove more old-style backticks
- add needed comments
- added parted to Requires (#161316)
- changed a y2internal -> y2milestone
- fixed harmless typos
- 2.13.35
* Wed Mar 29 2006 od@suse.de
- using parted for activation of boot partition now (instead of
  /sbin/activate from the lilo package) (#161316)
- fixed a typo
- fixed some whitespace
- added update-alternatives to BuildRequires
- 2.13.34
* Mon Mar 27 2006 uli@suse.de
- changed s390* reboot message (bug #160045)
* Sun Mar 26 2006 od@suse.de
- removed yast2-devel-packages from BuildRequires
- add replacements for yast2-devel-packages to BuildRequires
- 2.13.33
* Tue Mar 21 2006 jplack@suse.de
- fix console= handling on update, and some more update fixes (#155397)
- 2.13.32
* Tue Mar 21 2006 od@suse.de
- cleanup: move UpdateSections function into Update()'s body
- fixed #157939: iseries can boot even if no prep boot partition
  exists and/or is configured
- 2.13.31
* Mon Mar 20 2006 od@suse.de
- package clients/print-product.ycp
- 2.13.30
* Mon Mar 20 2006 od@suse.de
- fixes for #155397:
  - major cleanup of Update() code to be able to fix #155397
  - added "return ret" to CreateImageSection()
  - fixed parameters in call to UpdateSections()
  - fixed list element removal: remove() -> filter()
  - also removed translation of section title (GfxMenu) for ppc
    (perl-Bootloader will take care of this)
- print-product.ycp: remove " -- " from arguments to
  CommandLine::Print()
- 2.13.29
* Mon Mar 20 2006 od@suse.de
- doing the right thing for InitializeLibrary
- fix indentation/code style
- print-product.ycp was wrong in modules, moved to clients
- 2.13.28
* Fri Mar 17 2006 od@suse.de
- made text widget in error log message popup higher (#159264)
- fix indentation
- 2.13.27
* Fri Mar 17 2006 od@suse.de
- removed bootloader-theme from Requires: (#158588)
- 2.13.26
* Fri Mar 17 2006 od@suse.de
- moved CreateLinuxSection() to BootPOWERLILO.ycp and adapted for
  ppc (#144553):
  - kernel -> image
  - removed code that is not used on ppc
  - added comments
- moved CreateLinuxSection up and using it for installation as well
- 2.13.25
* Wed Mar 15 2006 od@suse.de
- added debug output for (#156993)
- changed my_sections -> updated_sections
- 2.13.24
* Mon Mar 13 2006 od@suse.de
- jplack:
  - remove dead/unused code
  - add some FIXME comments
  - more cleanups
- 2.13.23
* Mon Mar 13 2006 od@suse.de
- changed some whitespace
- corrected fallback kernel to "/boot/vmlinux"
- copied UpdateSections() from lilolike.ycp to BootPOWERLILO.ycp
  and adapted to new interfaces (#144553)
- made read_default_section_name global in BootCommon.ycp (#144553)
- syntax cleanups
- proofread
- 2.13.21
* Tue Mar  7 2006 od@suse.de
- added proposal for prep and iseries (pmac still missing)
- created new function change_widget_default_value() and moved code
  from Propose() into this function
- proposal for prep and iseries set the default values for their
  widgets using change_widget_default_value()
- added FIXME: for improving the summary function
- fixed comment in chrp.ycp explaining the use of
  prep_same_disk_as_root
- 2.13.20
* Tue Mar  7 2006 od@suse.de
- #145597:
  - use old working proposal code from BootPPC in BootPOWERLILO
  - add comments where needed to understand the code
  - change lookup, lookup_value and modifySection and use []: instead
  - use search instead of find(string, string)
  - fixed header of BootPOWERLILO
  - fixed LocationProposal to use old BootPPC code
  - fixed some whitespace
  - call old currentBoardInit() from new Propose()
  - set proposed boot partition as default in widget
- add "global void" to jplack's bootloaderError()
- fix y2error format string
- fixed an obsolete FlushCache() -> CommitSettings()
- give an error popoup with log like in SLES9 (#145106)
- use only one log file for all bootloaders (#145106)
- cleanups, mostly indentation to make code readable
- fixed: activate on i386 did not work when p_dev["nr"] == "" (mean
  whole disk) was one of loader_device or boot_partition
- unify confusing interface names: FlushCache -> CommitSettings
- give an error popoup with log like in SLES9 (#145106)
- fix one update problem on POWER
- use correct path to mkzimage for iSeries bootfile
- 2.13.19
* Fri Mar  3 2006 jplack@suse.de
- give an error popoup with log like in SLES9 (#145106)
- use only one log file for all bootloaders (#145106)
- fix one update problem on POWER
* Fri Mar  3 2006 jplack@suse.de
- fixed: activate on i386 did not work when p_dev["nr"] == "" (mean
  whole disk) was one of loader_device or boot_partition
* Wed Mar  1 2006 olh@suse.de
- use correct path to mkzimage for iSeries bootfile
* Tue Feb 28 2006 od@suse.de
- olh also fixed a typo in Bootloader.ycp
- 2.13.18
* Wed Feb 22 2006 olh@suse.de
- do a mount --bind /dev /mnt/dev in bootloader_finish.ycp (#144773)
* Thu Feb 16 2006 od@suse.de
- translateSectionTitle():
  - handle results properly when regexpsub() is called with a non-matching
    regex
  - fixed comment for ReplaceRegexMatch()
  - fixed execess -> excess in y2milestone()
  - added another y2milestone() for cutting off words
- 2.13.17
* Thu Feb 16 2006 od@suse.de
- wrote ReplaceRegexMatch() to globally replace matching regexes
- fix filtering of lilo bootloader section name with
  ReplaceRegexMatch()
- 2.13.16
* Thu Feb 16 2006 od@suse.de
- fixed typo in filtering of forbidden chars for lilo section titles
- added logging for lilo section title adaptation
- 2.13.15
* Wed Feb 15 2006 od@suse.de
- olh:
  - setting svn:keyword property to 'Author Date Id Revision'
  - typo s/instalaltion/installation/
- od:
  - restrict LILO section names to 11 chars -- use same algorithm
    as in perl-Bootloader, LILO.pm, sub FixSectionName()
- 2.13.14
* Tue Feb 14 2006 olh@suse.de
- fix typo in board_type_names
* Tue Feb 14 2006 olh@suse.de
- remove nubus support
* Wed Feb  1 2006 od@suse.de
- added to package: src/modules/print-product.ycp
- 2.13.13
* Fri Jan 27 2006 locilka@suse.cz
- merged texts from proofread
* Wed Jan 25 2006 od@suse.de
- added print-product.ycp, used by update-bootloader from
  perl-Bootloader
- 2.13.12
* Fri Jan 20 2006 od@suse.de
- moved BootPOWERLILO initialization code out of constructor again
  - - this unconditionally initialized lib_iface for ppc
- 2.13.11
* Wed Jan 18 2006 od@suse.de
- remove __exports__ from globals in extract_exports_from_globals()
- delete obsolete function GoodPrepOrFatPartition()
- consider globals empty even if lines_cache_id is present
- fix merging of __exports__ in BootPOWERLILO constructor
- 2.13.10
* Tue Jan 17 2006 od@suse.de
- actually find and propose root and boot devices
* Tue Jan 17 2006 od@suse.de
- added comments in bootloader_proposal
- added GoodPrepOrFatPartition() in BootPOWERLILO
- a lot of FIXMEs added
- initial proposal for PPC
* Mon Jan 16 2006 jplack@suse.de
- moved widget descriptions (labels) to yast2-bootloader
- handle unified type descriptions: now <type>:<desc>:<default>:...
- add arch-specific Summary function
* Thu Dec 22 2005 uli@suse.de
- declare Write method implemented in BootZIPL.ycp
* Wed Dec 21 2005 visnov@suse.cz
- merged proofread texts
* Mon Dec 19 2005 jplack@suse.de
- always read the config from perl-Bootloader (#140127)
- activate generic help system
- give help messages that make sense
- avoid this i386 LILO bootloader config on ppc (#140127)
- 2.13.6
* Fri Dec 16 2005 jsrain@suse.cz
- moved bootloader background picture to separate package
- moved /boot/message handling to separate module
- 2.13.5
* Thu Dec 15 2005 uli@suse.de
- s390: dumped obsolete dump sections and dead code
- 2.13.4
* Tue Dec 13 2005 mvidner@suse.cz
- Fixed a type mismatch, hopefully fixing the installation (#138328).
- 2.13.3
* Thu Dec  8 2005 od@suse.de
- changes by jplack@suse.de:
  - use generic dialogs in PowerPC boot loader code
  - new files to build widgets from type information
  - changes for support of all options on POWER - generic stuff
- 2.13.2
* Mon Oct 31 2005 jsrain@suse.cz
- fixed losing GRUB sections in some cases (#130236)
- 2.13.1
* Wed Oct 26 2005 jsrain@suse.cz
- do not create section for XEN if ungrading other bootloader than
  GRUB (#130474)
- fixed clonning a section, it changed also the original one
  (#129511)
* Fri Oct 21 2005 jsrain@suse.cz
- do not set dom0_mem option for XEN (#121947)
- fixed selecting the swap partition for suspend to disk in other
  situations than installation (#128702)
* Tue Oct  4 2005 jsrain@suse.cz
- fixed password setting help (#119591)
* Mon Oct  3 2005 jsrain@suse.cz
- change selected radio button for loader location if loader
  location specified in combo box (#114193)
* Fri Sep 30 2005 jsrain@suse.cz
- fixed reproposing configuration in installed system (#119428)
- fixed disappearing initrd lines from configuratiln file (#104048)
* Thu Sep 29 2005 jsrain@suse.cz
- fixed importing the global bootloader settings from AutoYaST
  profiles (#118595)
* Tue Sep 27 2005 jsrain@suse.cz
- export/import the loader location variable for AutoYaST (#116947)
* Mon Sep 26 2005 jsrain@suse.cz
- added bootloader background picture for Alpha1
- do not install bootloader to MBR by default
- 2.13.0
* Fri Sep  9 2005 jsrain@suse.cz
- activate the /boot partition if installing to ThinkPad (#116129)
- 2.12.32
* Fri Sep  9 2005 jsrain@suse.cz
- propose GRUB's device map if the one which was read from the
  system is empty (#115936)
- 2.12.31
* Thu Sep  8 2005 jsrain@suse.cz
- fixed reading GRUB location from configuration file (#115581)
- 2.12.30
* Wed Sep  7 2005 jsrain@suse.cz
- load EDD module during proposal (and not during inst_finish, as
  it doesn't work if other than default kernel is used) (#115592)
- 2.12.29
* Wed Sep  7 2005 jsrain@suse.cz
- install bootloader to MBR by default (except ThinkPads)
- load EDD module before running fix_chs script (#103031)
- import device map correctly during autoinstallation (#115327)
- 2.12.28
* Tue Sep  6 2005 jsrain@suse.cz
- changed the count of boot floppies (#114959)
- run fix_chs on each partition which is marked active (#103031)
- update MBR on ThinkPads correctly (#114429)
- 2.12.27
* Tue Sep  6 2005 jsrain@suse.cz
- changed the bootloader background (#115331)
- 2.12.26
* Fri Sep  2 2005 jsrain@suse.cz
- added RC1 bootloader background
- 2.12.25
* Wed Aug 31 2005 jsrain@suse.cz
- added ELILO support (for IA64)
- added basic ZIPL support (for S/390)
- 2.12.24
* Mon Aug 29 2005 jsrain@suse.cz
- updated failsafe kernel parameters for i386/x86_64 (#113600)
- avoid reinitializing limal-bootloader before writing settings
  during update and in installed system (#113683)
- added support for booting on PPC
- 2.12.23
* Thu Aug 25 2005 jsrain@suse.cz
- fixed setting the resume kernel parameter during update (#112794)
- do not add 'barrier=off' to failsafe kernel parameters (#112891)
- do not propose to install bootloader on XFS partition (#112810)
- 2.12.22
* Tue Aug 23 2005 jsrain@suse.cz
- keep bootloader location during update (#105988)
- moved FixCHS to master-boot-code (#103031)
* Mon Aug 22 2005 jsrain@suse.cz
- fixed creating new boot loader sections (#105668)
- 2.12.21
* Fri Aug 19 2005 jsrain@suse.cz
- enhanced checking whether merged section is still valid (#74252)
- fix information about disk geometry in MBR if needed (#103031)
- 2.12.20
* Thu Aug 18 2005 jsrain@suse.cz
- fixed new created XEN sections (#105171)
- do not install backup of stage1 if /boot is on XFS (#105483)
- 2.12.19
* Wed Aug 17 2005 jsrain@suse.cz
- fixed detection whether bootloader can be installed if /boot is
  on MD (#104908)
- fixed comments for ycpdoc
- fixed proposing configuration if /boot is on MD (#104908)
- set correct initrd image for XEN (#105171)
- fixed errors in log while proposing loader type (#105152)
- don't remove initrd from merged loader sections (#104048)
* Mon Aug 15 2005 jsrain@suse.cz
- merged texts from proofread
- 2.12.18
* Mon Aug 15 2005 jsrain@suse.cz
- fixed section updates durng system update (#103868)
- 2.12.17
* Fri Aug 12 2005 jsrain@suse.cz
- fixed several errors in code, added missign shortcuts
* Thu Aug 11 2005 jsrain@suse.cz
- set correct parameters to failsafe kernel (#103865)
- fixed removing obsolete sections during update (#104039)
* Wed Aug 10 2005 jsrain@suse.cz
- fixed changing the order of disks (#102964)
* Tue Aug  9 2005 jsrain@suse.cz
- don't put 'splash=silent' twice to kernel command line (#102706)
- install bootloader to boot sector by default only if /boot
  partition is on the first disk (#100728)
- fixed modification of bootloader sections during installation
  (#102626)
- do not offer to edit sections if user selected not to install
  any bootloader (#102613)
- updated help text for bootloader location (#102626)
- fixed syntax of created lilo.conf (vga= cannot be in append)
  (#102942)
- displaying meaningful information for chainloader sections
  (#103008)
- 2.12.16
* Mon Aug  8 2005 jsrain@suse.cz
- fixed importing settings during autoinstallation, avoiding crash
  (#102535)
* Thu Aug  4 2005 jsrain@suse.cz
- fixed crash during autoinstallation
- do not offer GRUB and LILO on all architectures (#100219)
- 2.12.15
* Wed Aug  3 2005 jsrain@suse.cz
- do not display additional kernel parameters in summary if no boot
  loader is selected to be installed (#100409)
- propose not to install bootloader if the available one is not
  supported (#100406)
- fixed widgets allignment
* Mon Aug  1 2005 jsrain@suse.cz
- fixed capitalization in module summary
- added master-boot-code to RPM dependencies on i386/x86_64, as it
  is needed for the default installation
- 2.12.14
* Mon Aug  1 2005 jsrain@suse.cz
- do not propose installing bootloader to MBR by default
- 2.12.13
* Thu Jul 28 2005 jsrain@suse.cz
- merged texts from proofread
- 2.12.12
* Wed Jul 27 2005 jsrain@suse.cz
- added option to enable/disable boot timeout
- fixed boot password setting
- location widget not shown if no loader is to be installed (#97888)
- 2.12.11
* Tue Jul 26 2005 jsrain@suse.cz
- fixed GRUB menus merging
- 2.12.10
* Fri Jul 22 2005 jsrain@suse.cz
- set correct root device to kernel command line (#97574)
- fixed installation on ThinkPad laptops (select the partition
  correctly) (#86762)
- 2.12.9
* Fri Jul 22 2005 jsrain@suse.cz
- added last missing help texts
- several minor fixes
- updated to run correctly in Mode::config
- added autoinstallation support
- 2.12.8
* Thu Jul 21 2005 jsrain@suse.cz
- added missing file to package
- added missing helps
- fixed retranslating boot menu during installation
- 2.12.7
* Mon Jul 18 2005 jsrain@suse.cz
- fixed proposing and handling device map
- 2.12.6
* Mon Jul 18 2005 jsrain@suse.cz
- fixed makefiles in order to pack all needed files
- added some help texts
- 2.12.5
* Fri Jul 15 2005 jsrain@suse.cz
- adapted to new partitioner using storage-lib (arvin)
- fixed makefiles and nfb to build against limal-bootloader
- 2.12.4
* Tue Jul 12 2005 jsrain@suse.cz
- more code cleanup
* Mon Jul 11 2005 jsrain@suse.cz
- merged texts from proofread
* Fri Jul  1 2005 jsrain@suse.cz
- created new UI
- accessing perl-Bootloader library through LiMaL instead of SCR
* Tue Jun 14 2005 jsrain@suse.cz
- don't change MBR on IBM ThinkPad laptops in order to keep their
  rescue functionality working (#86762)
- 2.12.3
* Tue Jun  7 2005 jsrain@suse.cz
- display info of additional kernel parameters from installation
  kernel command line (#83837)
* Mon May 23 2005 jsrain@suse.cz
- fixed detection fo PReP partition on CHRP (PPC) (#80204)
- block proposal if bootloader noc configured correctly on PPC
  (#82893)
* Wed May  4 2005 jsrain@suse.cz
- more "default" variable renames
- 2.12.2
* Tue May  3 2005 jsrain@suse.cz
- select PReP boot partition on CHRP (PPC) if root on LVM (#80204)
* Wed Apr 27 2005 jsrain@suse.cz
- allow to remap devices in GRUB section (#77119)
- don not report void error in installation proposal
- added bootloader-related part of inst_finish to extra client
- 2.12.1
* Fri Apr 22 2005 mvidner@suse.cz
- Do not use "default" as an identifier.
* Mon Apr 18 2005 jsrain@suse.cz
- updated for new interface of ProductFeatures.ycp
- 2.12.0
* Wed Mar 30 2005 jsrain@suse.cz
- inform user in proposal if it is not possible to install
  bootloader due to partitioning (#71949)
* Thu Mar 24 2005 jsrain@suse.cz
- fixed bootfloppy icon description (#71084)
* Tue Mar 15 2005 jsrain@suse.cz
- fixed modification of bootloader configuration if installation
  fails during update (#72814)
* Mon Mar 14 2005 jsrain@suse.cz
- fixed manual configuration files editation (#72389)
- recreate grub.conf during update (#72361)
* Mon Mar  7 2005 jsrain@suse.cz
- added ZIPL installation via perl-Bootloader
- fixed the order of icons in bootfloppy creator
* Fri Mar  4 2005 jsrain@suse.cz
- propose XEN section if XEN and XEN kernels are installed/selected
* Thu Mar  3 2005 jsrain@suse.cz
- reverted to older version update_gfxmenu due to recent problems
  (#67288)
* Wed Mar  2 2005 jsrain@suse.cz
- merged texts from proofread
* Wed Mar  2 2005 jsrain@suse.cz
- fixed neverending loop in update_gfxmenu
* Tue Mar  1 2005 jsrain@suse.cz
- provide info about grub.conf to repair module if embedding
  GRUB stage1.5
- display proper list of bootloaders (#66933)
- limit the size of the /boot/message archive (#66878)
* Mon Feb 28 2005 jsrain@suse.cz
- fixed aborting during inst_finish (was crashing YaST)
* Fri Feb 25 2005 jsrain@suse.cz
- fixed identifying bootloader sections while reading (#66612)
* Fri Feb 25 2005 jsrain@suse.cz
- added missed translation mark (#8402)
- fixed testsuites
- enabled the bootfloppy icon also on AMD64
- disabled rescue floppy creation on other archs than i386
- 2.11.15
* Mon Feb 21 2005 jsrain@suse.cz
- use the new scripts for creating boot floppy (images are no
  longer on installation media)
- 2.11.14
* Thu Feb 17 2005 jsrain@suse.cz
- prevent from inserting language to the offer of boot menu twice
  (#50930)
* Wed Feb 16 2005 jsrain@suse.cz
- added support for embedding GRUB's stage 1.5
- 2.11.13
* Mon Feb 14 2005 jsrain@suse.cz
- by default don't merge whole GRUB menus, but only the default
  entry (#50688)
- fixed errors of the bootloader library if using LVM
- 2.11.12
* Thu Feb 10 2005 jsrain@suse.cz
- fixed errors when merging GRUB menus (#50643)
* Wed Feb  9 2005 jsrain@suse.cz
- stopped using multiple variables from ProductFeatures for
  creating kernel command line (#50369)
- 2.11.11
* Tue Feb  8 2005 jsrain@suse.cz
- fixed warning when removed memtest package after modifying
  memtest section in bootloader menu (#50498)
* Mon Feb  7 2005 jsrain@suse.cz
- merged texts from proofread
- 2.11.10
* Fri Feb  4 2005 jsrain@suse.cz
- getting additional kernel parameters as one string (#50369)
* Wed Feb  2 2005 jsrain@suse.cz
- fixed support for localized boot menu, allowed multiple languages
  to be used at once
* Tue Feb  1 2005 nashif@suse.de
- Disabled @YAST2-CHECKS-PROGRAM@ to fix build
- 2.11.9
* Mon Jan 31 2005 jsrain@suse.cz
- removed code obsolete after using the bootloader library
  (including the LILO agent)
- adapted to new filenames in GFX menu
- fixed handling of YaSTi's data in comments in configuration files
- by default merging all found GRUB menus
- clean-up of obsolete code
- 2.11.8
* Fri Jan 28 2005 jsrain@suse.cz
- export GRUB device map information to AutoYaST profile (#49730)
* Tue Jan 25 2005 jsrain@suse.cz
- adaptations to install properly on MD arrays
- 2.11.7
* Mon Jan 24 2005 jsrain@suse.cz
- added agent to interface for the bootloader library
- using the now bootloader library for GRUB and LILO configuration
- 2.11.6
* Tue Jan 11 2005 jsrain@suse.cz
- do not append 'maxcpus=0' to failsafe kernel command line on
  AMD64 (#49059)
* Thu Jan  6 2005 jsrain@suse.cz
- propose all present kernels for GRUB
* Wed Jan  5 2005 jsrain@suse.cz
- adapted to interface change of Kernel.ycp
- 2.11.5
* Wed Dec 15 2004 jsrain@suse.cz
- using new interface of Progress.ycp
- 2.11.4
* Mon Dec 13 2004 jsrain@suse.cz
- fixed setting GRUB password (#48999)
* Fri Nov 19 2004 jsrain@suse.cz
- removed the generic MBR code from the package (moved to
  master-boot-code package) (#46406)
- if user selects MBR of other than booting disk as location for
  GRUB, offer changing the order of the disks (#48051)
- 2.11.3
* Tue Nov  9 2004 jsrain@suse.cz
- fixed automatical boot partition activating during installation
  (#20329)
* Tue Nov  9 2004 jsrain@suse.cz
- enhanced memtest handling during installation (#46796)
* Mon Nov  8 2004 jsrain@suse.cz
- better fix of kernel image name update (#46750)
* Thu Nov  4 2004 jsrain@suse.cz
- removed select () and lookup () builtins usage
- fixed types for CWM
- 2.11.2
* Wed Oct 27 2004 jsrain@suse.cz
- adapted to new Mode/Stage interface
- 2.11.1
* Tue Oct 19 2004 jsrain@suse.cz
- use unified messages from Label.ycp
- changed boot floppy creator according to new layout of boot
  floppy disks (#43634)
- 2.11.0
* Wed Oct 13 2004 jsrain@suse.cz
- add "thash_entries=2097152" to kernel command line on Altix
  Scalable Node (#44174)
* Mon Oct 11 2004 jsrain@suse.cz
- adapted to new Arch:: interface
* Wed Oct  6 2004 jsrain@suse.cz
- fixed summary if GRUB section name contains HTML tag (#46792)
* Tue Oct  5 2004 jsrain@suse.cz
- replace blank spaces in LILO section name with underscores,
  shorten it if it is longer than 15 chars (#46778)
- 2.10.17
* Mon Oct  4 2004 jsrain@suse.cz
- if serial parameter is present in menu.lst, don't add gfxboot
  during update (#46680)
- fixed update if root device name contained 'suse' or 'shipped'
  (#46750)
- 2.10.16
* Wed Sep 29 2004 jsrain@suse.cz
- do not show the disks order if there is only one disk (#46346)
- 2.10.15
* Thu Sep 23 2004 jsrain@suse.cz
- avoid initalizing GRUB structures earlier than needed data is
  known (#45119)
- fixed redrawing the main dialog if loader type changed (#45877)
- 2.10.14
* Mon Sep 20 2004 jsrain@suse.cz
- fixes update if SATA devices are used (#44286)
- 2.10.13
* Mon Sep 13 2004 jsrain@suse.cz
- allowed to add wildcard entry to GRUB and LILO boot menu (#44742)
- removed dead code (related to items in GRUB section reordering,
  now it is fully handled by Table/Popup
- initialize package manager callbacks before getting boot floppy
  image (in order to ask for media) (#45049)
- prevent from displaying the target device in the summary
  multiple times (#45119)
- 2.10.12
* Tue Sep  7 2004 jsrain@suse.cz
- update the default boot section mark properly if a section was
  removed (eg. because of missing kernel) (#44752)
* Mon Sep  6 2004 jsrain@suse.cz
- do not use obsolete include commandline/commandline.ycp
* Mon Sep  6 2004 jsrain@suse.cz
- avoid calling constructor of Product:: in testsuite (in order to
  build properly)
- save splash type from installation kernel command line to created
  bootloader configuration files (#44683)
- 2.10.11
* Fri Sep  3 2004 jsrain@suse.cz
- update devices in bootloader configuration files (SATA devices
  changed from /dev/hd* to /dev/sd*) (#44286)
- provide general Bootloader::Update function that processes all
  needed tasks
- added SetModified to _auto client
- 2.10.10
* Thu Sep  2 2004 jsrain@suse.cz
- check dependencies of bootloader-related packages when selecting
  them for installation (#44615)
* Wed Sep  1 2004 jsrain@suse.cz
- fixed proposing /etc/grub.conf if /boot is on /dev/md*
* Tue Aug 31 2004 jsrain@suse.cz
- fixed building on other archs than i386
- 2.10.9
* Tue Aug 31 2004 jsrain@suse.cz
- branched yast2-bootfloppy package (so that the bootfloppy
  functionality is not present in personal as floppy images are
  not present on the media (#44163)
- 2.10.8
* Mon Aug 30 2004 nashif@suse.de
- Added GetModified function to _auto client
* Thu Aug 19 2004 jsrain@suse.cz
- translate the "Vendor Diagnostic" section in bootloader menu
- removed some unneeded impmorts
- 2.10.7
* Tue Aug 17 2004 jsrain@suse.cz
- fixed signatures of handler functions of Table/Popup options
- call efibootmgr with '-v' instead of '-q' (in order to have more
  verbose output in log) (#43625)
* Mon Aug 16 2004 jsrain@suse.cz
- fixed printing of summary if location set to all MBRs of disks
  holding the /boot partition on /dev/md*
- fixed activating partitions and writing generic code to MBR if
  installing on /dev/md*
- work correctly with kernel image names also on other archs than
  i386 when creating the previous kernel section
- 2.10.5
* Fri Aug 13 2004 jsrain@suse.cz
- log the output of devmap_mknod.sh and /sbin/vgscan (#43758)
* Wed Aug 11 2004 jsrain@suse.cz
- prevent from adding trailing blank space to section name on PPC
  (#43599)
* Tue Aug 10 2004 jsrain@suse.cz
- merged texts from proofread
* Mon Aug  9 2004 jsrain@suse.cz
- fixed crippling of sections of other distros in case of multiboot
  (#43491)
- add 'd' to GRUB installation command only if 1st and 2nd stage
  are on different disks (#43198)
- 2.10.4
* Fri Aug  6 2004 jsrain@suse.cz
- minor fixes that made autoinstallation work
* Wed Aug  4 2004 jsrain@suse.cz
- more type information for CWM structures
- fixed testsuite
- 2.10.3
* Mon Jul 26 2004 jsrain@suse.cz
- fixed routine of merging detected modules for initrd with those
  present in the AI profile during autoinstallation (#43103)
* Mon Jul 19 2004 jsrain@suse.cz
- use PackageSystem.ycp modules instead of Require.ycp
- import "Product.ycp" when it is really needed (in order to build)
- 2.10.2
* Fri Jul 16 2004 jsrain@suse.cz
- fixed displaying and changing order of disks for GRUB (#42454)
- displaying GRUB's disks order in the summary
* Mon Jul 12 2004 jsrain@suse.cz
- writing product name and version as section label to bootloader
  menu (GRUB both text and graphical, lilo graphical) (#31250)
- fixed error messages of the script for /boot/message recreating
- added general function to recreate /boot/message file on
  relevant architectures
- 2.10.1
* Tue Jun 29 2004 jsrain@suse.cz
- added possibility to install GRUB on MD device (the way that if
  any of the disks building MD is removed system still boots)
- update zipl.conf before packages update on S390 (#40629)
- added "barrier=off" to failsafe kernel command line on i386, IA64
  and AMD64 (#42526)
* Fri Jun 25 2004 jsrain@suse.cz
- added functionality to add section with previous kernel (#36624)
- fixed confusing labels for the boot floppies (#37094)
- fixed confusing code in Bootloader::Write (#40445)
* Thu Jun 24 2004 jsrain@suse.cz
- fixed autoinstallation with empty bootloader-related part of the
  AI profile on PPC and IA64 (#41805)
* Thu Jun 17 2004 jsrain@suse.cz
- 2.10.0
* Wed Jun 16 2004 jsrain@suse.cz
- prevent the "desktop" parameter from being added to kernel
  command line for server products (#41916)
- 2.9.31
* Thu Jun 10 2004 jsrain@suse.cz
- change /dev/hd* to /dev/iseries/vd* in the 'boot' option of
  lilo.conf during update of iSeries (#41545)
- fixed creating a new section on PPC and IA64 (#41550)
- 2.9.30
* Sat Jun  5 2004 nashif@suse.de
- in autoinst mode, keep initrd modules list (#41681)
* Thu May 27 2004 jsrain@suse.cz
- don't display device name if user selected to activate boot
  loader partition ot replace MBR with generic code when preparing
  AutoYaST  profile, as the device names aren't known (#41258)
- allow to install LILO to MD so that if any of disks bulding MD
  array is removed, system still boots (#34122)
- 2.9.29
* Thu May 27 2004 nashif@suse.de
- move conversion functions from bootloader_auto to external
  file (#41227)
- Also parse kernel parameters, moved from autoyast2 (#41227)
* Wed May 26 2004 jsrain@suse.cz
- fix autoinstallation on all PPC boards (#38991)
- prefer proposed PReP boot partition to already existing (#41213)
* Tue May 25 2004 jsrain@suse.cz
- set the I/O scheduler on the kernel command line (#40688)
- fixed bootloader installation on iSeries (jplack) (#41143)
- 2.9.28
* Mon May 24 2004 jsrain@suse.cz
- avoid setting vga kernel parameter on PPC and S390 (#40998)
- fixed messing of /etc/lilo.conf when setting the vga parameter
  (#40998)
* Wed May 19 2004 jsrain@suse.cz
- fixed filter for possible PReP boot partitions on iSeries - allow
  /dev/iseries/vd* instead of /dev/hd* (#40825)
- 2.9.27
* Tue May 18 2004 jsrain@suse.cz
- init board type during autoinstallation on PPC properly (#38991)
* Thu May 13 2004 jsrain@suse.cz
- fixed installation on PPC (#34556)
- 2.9.26
* Wed May 12 2004 jsrain@suse.cz
- use ELILO-specific entry for the EFI entry label in the
  autoinstallation profile (#36061)
- fix handling of multiple occurences of a kernel parameter in the
  command line (used eg. for console) (#38177)
- fix lilo.conf update on PPC (#39379)
* Tue May  4 2004 jsrain@suse.cz
- merged texts from proofread
* Tue May  4 2004 jsrain@suse.cz
- add 'selinux=0' kernel parameter for all archs (#39811)
- add 'TERM=dumb' kernel parameter for S390 (#39386)
- 2.9.25
* Tue Apr 27 2004 jsrain@suse.cz
- fixed script for updating /boot layout on IPF (#21644)
- fixed the /boot layout update procedure (#21644)
- do not change the EFI nvram on update (#21644)
- fixed testsuite
- 2.9.24
* Thu Apr  8 2004 jsrain@suse.cz
- use 'desktop' kernel parameter on desktop products only
- fixed blank spaces in section name after conversion from GRUB to
  LILO (#38017)
- fixed installing rescue kernel to slot A on iSeries (PPC) during
  installation (#35566)
* Wed Apr  7 2004 sh@suse.de
- Fixed excessive whitespace after Module:: - bug #38327
* Tue Apr  6 2004 schwab@suse.de
- Add nohalt to failsafe kernel command line on ia64.
* Tue Apr  6 2004 jsrain@suse.de
- updating graphical boot menu to contain proper languages (and
  be small enough to fit in memory) also when running update from
  YaST control center (#38339)
- added 'noresume' parameter to failsafe kernel command line
  (#38400)
- 2.9.22
* Mon Apr  5 2004 jsrain@suse.de
- fixed installation if root is on LVM (initializing device mapper
  and LVM properly) (#37290)
- 2.9.21
* Fri Apr  2 2004 jsrain@suse.de
- changed license to GPL
- 2.9.20
* Fri Apr  2 2004 jsrain@suse.de
- fixed reading and writing of the 'map' option of sections in the
  GRUB's menu.lst (#37971)
- again fixed PPC post-install script (#37262)
- 2.9.19
* Tue Mar 30 2004 schwab@suse.de
- Use dev2majminIfNonStandard instead of dev2majmin in BootELILO.
- 2.9.18
* Mon Mar 29 2004 jsrain@suse.de
- do not propose to install any bootloader if installing user-mode
  Linux (#37382)
* Mon Mar 29 2004 jsrain@suse.de
- fixed errors in log if root on LVM (#37290)
- adapted to changes in CWM
- include desktop file for boot floppy disk creator on i386 only
  (#37209)
- write "lilo" as bootloader type to sysconfig on PPC (#37263)
- do not report incorrect error of PPC bootloader post-install
  script (#37262)
- label the bootloader section on PPC 'linux' (lowercase 'l')
  (#37264)
- do not ask about aborting if just entered and left (#37099)
- write correct kernel to slot A on iSeries (PPC) when configuring
  installed system (#35566)
- 2.9.17
* Fri Mar 26 2004 jsrain@suse.de
- check for nil output of runnign bootloader installer (#36927)
- avoid displaying reading progress while updating configuraiton
- 2.9.16
* Thu Mar 25 2004 jsrain@suse.de
- fixed behavior if installing bootloader to boot sector of
  MD device (#34122)
- do not update graphical boot menu if it is not installed (#36893)
- 2.9.15
* Wed Mar 24 2004 jsrain@suse.cz
- fixed installation when root is on LVM device
- prepared for EVMS (handle it the same way as LVM)
* Tue Mar 23 2004 jsrain@suse.cz
- warn user before installing on XFS partition (boot sector doesn't
  have enough free space for containing boot loader) (#36708)
* Mon Mar 22 2004 jsrain@suse.cz
- logging output of PPC postinstall script (#35833)
- fixed handling of NoPCMCIA kernel parameter (#35674)
- check if language is supported by gfxmenu before setting it as
  default (#36487)
- 2.9.14
* Fri Mar 19 2004 mvidner@suse.cz
- added AGENT_LIBADD so that agents work from standalone Perl
* Thu Mar 18 2004 jsrain@suse.cz
- mark settings as changed after bootloader switch (#36269)
- avoid putting /dev/evms to GRUB's device map and allowing it as
  device to install bootloader to
- create only one entry in the language selection in graphical
  boot menu if English selected
* Wed Mar 17 2004 jsrain@suse.cz
- allowed to select PPC board type when preparing autoinstallation
  (#36109)
- not reading settings from disk in Mode::config if not explicitly
  asked
- correctly assigning default radio button when asking how to
  switch bootloader
- zipl (S390 loader) switched to Table/Popup interface with just
  one entry (loader type) because of autoinstallation
* Tue Mar 16 2004 jsrain@suse.cz
- allow selecting all boot loaders in autoinstallation
  configuration (#36109)
- correctly display in summary that no EFI entry will be created
  on IA64 (#35346)
- export global settings of the bootloader properly (#32384,
  [#36012])
- support for having both /boot/initrd and (hdx,y)/initrd in
  autoinstallation profile (#32384)
- fixed storing of the gfxmenu option
* Mon Mar 15 2004 jsrain@suse.cz
- correctly check for swap partitions (filter out the partitions
  that are marked for getting deleted) (#35953)
- avoid writing LILO to /dev/md? (use one of devices building the
  array instead) (#33565)
- prevent kernel options from being added multiple times (#32362)
- 2.9.13
* Fri Mar 12 2004 jsrain@suse.de
- setting the default language of graphical boot loader, adding
  localized texts
- added support for boot loader entries with diacritics in
  graphical bootloader menu
- creating /boot/zipl directory on S390 (#35662)
- 2.9.12
* Wed Mar 10 2004 jsrain@suse.de
- adapted boot disks creator to new floppy image names (#33675)
* Wed Mar 10 2004 sh@suse.de
- V 2.9.11
- Migration to new wizard
* Tue Mar  9 2004 jsrain@suse.de
- fixed creating floppy from image with size smaller than the disk
  size (#33675)
* Mon Mar  8 2004 jsrain@suse.de
- fixed post install script on PPC (#35436)
- fixed testsuite
- ask user before aborting
- setting icon
- 2.9.10
* Thu Mar  4 2004 jsrain@suse.de
- storing vga value determined during installation, using it when
  proposing new configuration in installed system (#33368)
- preserving user's choce not to create EFI entry while running
  through installation proposal (#35346)
* Wed Mar  3 2004 jsrain@suse.de
- appending text '(MBR)' to bootloader location description if it
  is MBR of a hard disk (#35255)
- fixed exporting settings for autoinstallation (#35232)
- log exit code of command used to install bootloaer in case of
  failure
- fixed incorrectly reported error when installing LILO (#33905)
- made md-only installation of GRUB possible (#34122)
* Tue Mar  2 2004 jsrain@suse.de
- finished making data types more strictly
- fixed default section name in lilo.conf on PPC (#35229)
* Mon Mar  1 2004 jsrain@suse.de
- merged texts from proofread
- more strictly data types (still WIP)
- 2.9.8
* Tue Feb 24 2004 jsrain@suse.de
- removing ide-scsi emulation parameters from kernel command line
  (#34694)
- use PReP boot partition on the same disk as root partition on
  chrp (PPC) (#34891)
- updated ELILO installation, change partitioning layout during
  ELILO update in order to match Intel's EFI specification (#21644)
* Mon Feb 23 2004 jsrain@suse.de
- fixed used kernel image name on S390 (now using the one from
  Kernel.ycp) (#34735)
- fixed kernel command line on S390 (#34734)
- 2.9.7
* Thu Feb 19 2004 jsrain@suse.de
- removed yast2-country from neededforbuild
- writing hardware configuration to sysconfig on S390 instead of
  /etc/chandev
* Tue Feb 17 2004 jsrain@suse.de
- enabled and fixed command line interface
- properly updating proposed sections of LILO after disk
  repartitioning
* Mon Feb 16 2004 jsrain@suse.de
- fixed behavior during autoinstalation preparation
- fixed selectin PReP boot partition for installation on PPC (#34570)
- fixed return value of Import function
- fixed text of MBR radio button in AI configuration mode
- keeping corrupted sections in lilo.conf on PPC (#34588)
- 2.9.6
* Tue Feb 10 2004 arvin@suse.de
- fixed testsuite
* Sat Feb  7 2004 arvin@suse.de
- removed config files (*.y2cc)
- 2.9.4
* Fri Jan 30 2004 jsrain@suse.de
- dropped SILO support (SILO was dropped as SPARC is dead)
- reenabled (and fixed) testsuite
- 2.9.3
* Fri Jan 16 2004 jsrain@suse.de
- merged NI changes from branch
- 2.9.2
* Mon Jan  5 2004 jsrain@suse.de
- adding resume= kernel parameter for GRUB and LILO (#33640)
- writing kernel append parameters to global section of elilo.conf
  (IA64) (#31736)
* Wed Dec 10 2003 jsrain@suse.de
- translating also section label in the "default" entry in
  elilo.conf (IA64)
* Tue Dec  9 2003 jsrain@suse.de
- added command line interface support
* Thu Nov 27 2003 jsrain@suse.de
- fixes for the new interpreter
- 2.9.1
* Mon Nov 24 2003 jsrain@suse.de
- fixed changing of GRUB location (#33297)
- updated support of ELILO, several fixes
* Tue Nov 18 2003 jsrain@suse.de
- switched from kdoc to doxygen
* Thu Oct 30 2003 jsrain@suse.de
- fixed handling of disks reorder dialog for GRUB configuration
- fixed modifying configuration data according to changed GRUB's
  device map (#32667)
* Wed Oct 29 2003 jsrain@suse.de
- fixed ensuring that required packages are installed when
  switching bootloader
- fixed sorting of lines in table
- 2.9.0
* Thu Oct 23 2003 schwab@suse.de
- Fix quoting in efibootmgr command line.
* Thu Oct 23 2003 jsrain@suse.de
- fixed routines used to modify parameters of specified kernel
* Fri Oct 17 2003 jsrain@suse.de
- not proceeding with creating boot floppy if image not found
  (#32428)
* Wed Oct 15 2003 jsrain@suse.de
- fixed option type for relocatable in elilo.conf (IA64) (#32210)
- fixed option type of "activate" option on PPC
- fixed handling of doublieclick on sections list table
- updated support of IA64 bootloader
* Tue Oct 14 2003 jsrain@suse.de
- updated support of S390 bootloader
* Mon Oct 13 2003 jsrain@suse.de
- updated support of PPC bootloader
* Mon Oct  6 2003 jsrain@suse.de
- added separate fillup templates for different architectures
* Fri Oct  3 2003 jsrain@suse.de
- changed internals so that bootloader module now uses CWM
* Mon Sep 22 2003 jsrain@suse.de
- fixed assigning of default section when changed default secion's
  label in LILO (#30122)
- 2.8.22
* Fri Sep 19 2003 jsrain@suse.de
- fixed testsuite (again)
- 2.8.21
* Thu Sep 18 2003 nashif@suse.de
- Fixed testsuite
- 2.8.20
* Thu Sep 18 2003 jsrain@suse.de
- again adding maxcpus=0 to failsafe bootloader entry on AMD64
  (#30519)
- fixed possibily missing "splash=silent" in default kernel's
  command line (#31256)
- 2.8.19
* Tue Sep 16 2003 jsrain@suse.de
- fixed merging of other GRUB menus (#30757)
- fixed translating of menubutton entry during installation (#31054)
- 2.8.18
* Mon Sep 15 2003 jsrain@suse.de
- fixed popup reporting error when creating initrd (#30714)
- fixed detection if root kernel parameter is specified via major
  and minor number (#30842)
- adding only one "splash=silent" to kernel command line (#30860)
- adding "splash=silent desktop" to kernel command line during
  update (#28780)
- propose "floppy" entry to bootloader menu only if floppy drive
  is present (#30772)
- don't install bootloader packages in repair mode (#30272)
- 2.8.17
* Sun Sep 14 2003 adrian@suse.de
- make it working in kcontrol
* Fri Sep 12 2003 jsrain@suse.de
- not adding maxcpus=0 to failsafe kernel parameters on AMD64
  (#30519)
- fixed updating of kernel image name in bootloader configuration
  files (#30627)
- fixed original bootloader configuration reading during update
  (#30625)
* Thu Sep 11 2003 jsrain@suse.de
- removed forgotten debug code (#30396)
* Wed Sep 10 2003 jsrain@suse.de
- fixed update of metadata for sysconfig variable LOADER_TYPE
  (#30352)
* Mon Sep  8 2003 jsrain@suse.de
- fixed bootloader menu entry - windows -> Windows (like other
  entries) (#29600)
- use device file name when specifying root device for LVM and MD
  instead of using major and minor number (#28028)
- prefix 0x should be added to major/minor number identifying root
  device only for LILO (#29776)
- 2.8.15
* Fri Sep  5 2003 jsrain@suse.de
- merged texts from proofread
- fixed configuration proposal when root or boot partition is on md
  (#30122)
- 2.8.14
* Thu Sep  4 2003 jsrain@suse.de
- if variable with list of initrd modules in sysconfig doesn't
  exist, set default value to empty (#30020)
* Wed Sep  3 2003 jsrain@suse.de
- don't write 'single' to slot A kernel command line on IBM iSeries
  (arch. PPC) (#27984) (olh@suse.de)
* Mon Sep  1 2003 jsrain@suse.de
- fixed bootloader installation with numeric (major-minor) root
  device specification (#29776)
- not proposing booting from floppy if /boot is beyond 1024 cylinder
  as it doesn't solve anything (#29524)
- 2.8.13
* Thu Aug 28 2003 jsrain@suse.de
- fixed displayed section type in sections summary dialog for
  "other" sections (#29472)
- don't ask for abort confirmation during installation if settings
  were changed in previous run of component from proposal (#29496)
- 2.8.12
* Mon Aug 25 2003 jsrain@suse.de
- fixed inconsistence of floppy size (1440kB -> 1.44 MB) (#29142)
- reporting segmentation fault when running bootloader binary
  (#29199)
- added correct help for configuration writing dialog
- improved help text for rescue floppy (#29143)
- 2.8.11
* Mon Aug 18 2003 jsrain@suse.de
- fixed creating of boot floppy (#28994)
- updated comments in susconfig fillup (#28845)
- moved dir for backup MBR to /var/lib/YaST2, in /boot leaving just
  last MBR (this way it can be inserted to GRUB menu) (#28802)
- backup-ing areas really affected when saving bootloader
  configuration (MBR of first disk and sector bootloader is
  installed to) (#28803)
- 2.8.10
* Wed Aug 13 2003 jsrain@suse.de
- fixed bootloader update
- better comments around YaST2 metadata in generated cfg. files
- 2.8.9
* Tue Aug 12 2003 jsrain@suse.de
- added support for not installing any bootloader
- recreate reset menubutton after bootloader switch
- updated update functionality (replace vmlinuz.shipped images with
  vmlinuz, dtto for initrd)
* Mon Aug 11 2003 jsrain@suse.de
- not using .shipped image any more (kernel package doesn't contain
  it)
- merged texts from proofread
- added more verbose logging of proposing configuration
- 2.8.8
* Thu Aug  7 2003 jsrain@suse.de
- fixed lost sections when changhing bootloader location (#28552)
- not offering to replace partition booting from HDD with partition
  for booting from floppy when changed GRUB location to other disk
  partition if entry for booting from HDD doesn't exist
- fixed proposing of LILO configuration (put multiple times into
  quotes, some options weren't displayed correctly in summary table)
- fixed lost sections in many other cases
- removed popup informing about changed disk partitioning although
  it was unchanged during installation proposal
- 2.8.7
* Mon Aug  4 2003 jsrain@suse.de
- added .desktop files
- 2.8.6
* Thu Jul 31 2003 jsrain@suse.de
- don't offer extra /boot and / partition as bootloader location
  if they are the same
* Tue Jul 29 2003 jsrain@suse.de
- added possibility to clone selected bootloader section (#26458)
- fixed creation of lilo.conf - quotes were missing
- entries to bootloader are to be translated (#26800)
* Wed Jul 23 2003 jsrain@suse.de
- Using major/minor number for unusual devices instead of device
  node name in root kernel parameter (#28028)
* Mon Jul 21 2003 jsrain@suse.de
- double click on tables now triggers Edit (#25156)
- fixed testuite and building
- 2.8.5
* Tue Jul  8 2003 jsrain@suse.de
- fixed question popup if canceling configuration (#27479)
- installing additional copy of bootloader bootsector to bootsector
  of /boot partition for LILO and GRUB (#27389)
- not activating any partition by default if some already active
  (#26278)
- 2.8.4
* Wed Jun 25 2003 jsrain@suse.de
- fixed several minor bugs
- 2.8.3
* Mon Jun 23 2003 jsrain@suse.de
- fixed common_popups, common_messages -> YCP modules
- fixed missing imports
- 2.8.2
* Thu Jun 12 2003 jsrain@suse.de
- fixed file list
- fixed user interface
- 2.8.1
* Wed May 28 2003 jsrain@suse.de
- updated PPC bootloader support
* Fri May 16 2003 jsrain@suse.de
- fixed collision with driver update (#26717)
* Thu May 15 2003 jsrain@suse.de
- updated ELILO (IA64 bootloader) support
* Mon May  5 2003 jsrain@suse.de
- updated and optimized some internal structures and related
  functions
* Thu Apr 24 2003 jsrain@suse.de
- updated doaboot script (ro@suse.de)
* Wed Apr 23 2003 jsrain@suse.de
- updated widget handling functions interface
- updated documentation
* Tue Apr 22 2003 jsrain@suse.de
- added possibility to download boot floppy image via FTP/HTTP
  (#26175)
- added possibility to restore last MBR saved during isntallation
  or bootloader configuration (#16338)
* Fri Apr 18 2003 jsrain@suse.de
- no more retaking current kernel parameters to bootloader
  configuration file when configuring installed system (#26304)
- fixed devices for MBR/boot partition/root/partition when
  installing on md (#26287)
- not activating any partition during update (#26323)
- better checkign of bootloader-on-floppy installation (#26323)
- in case of inconsistence between sysconfig and bootlaoder cfg.
  file bootloader cfg.file is prefered (#26323)
- fixed possible tmp filename security problem of installation
  on AXP (#26357)
- displaying partition that will be activated and MBR device that
  will be replaced with generic code (partial fix of #26278)
- added possibility to save MBR before bootloader installation and
  insert saved MBR image to GRUB menu (#16338)
- 2.8.0
* Tue Apr  8 2003 jsrain@suse.de
- added possibility to save all settings and reinstall bootloader
  although nothing was changed (#24346)
* Fri Apr  4 2003 jsrain@suse.de
- code cleanup and optimalization
- added bootloader parameters support, made routines more universal
- documentation update
* Thu Apr  3 2003 jsrain@suse.de
- allowed bootfloppy to format floppy disk and select device
- allowed bootfloppy to use custom image (22376)
- other minor bootfloppy updates and code cleanup
* Mon Mar 24 2003 jsrain@suse.de
- removed reading of initrd modules from install_inf (#24709)
* Fri Mar 21 2003 jsrain@suse.de
- updated documentation
- updated testsuite
- several minor updates and optimalizations
* Tue Mar 18 2003 jsrain@suse.de
- fixed undeclared variable title (#25560)
- 2.7.19
* Mon Mar 17 2003 jsrain@suse.de
- fixed displaying of logs on bootloader errors (#25470)
- 2.7.18
* Mon Mar 17 2003 jsrain@suse.de
- fixed updating GRUB configuration if entry with other system was
  present and set as default (#25418)
- 2.7.17
* Fri Mar 14 2003 jsrain@suse.de
- fixed behaviour when iditing empty section, when creating new
  section, add most common keys (#25305)
- fixed initrd modules cloning (#25351)
- 2.7.16
* Tue Mar 11 2003 jsrain@suse.de
- using activate instead of sfdisk to activate bootloader
  partition, because sfdisk has unwanted side effects (#24740)
- 2.7.15
* Mon Mar 10 2003 jsrain@suse.de
- fixed filtering of modules added to initrd (#24709)
- fixed partition activation if bootloader in logical disk (#24740)
- 2.7.14
* Fri Mar  7 2003 jsrain@suse.de
- fixed update from version without sysconfig variables specifying
  used bootloader (#24783)
- fixed reading configuration, not using agent's cache (#24821)
- 2.7.13
* Wed Mar  5 2003 jsrain@suse.de
- fixed multiple occurences of map option in one GRUB section
  (#24627)
- not adding automatically the apic kernel option (#24668)
- fixed error message in log during saving (#24705)
* Mon Mar  3 2003 jsrain@suse.de
- added possibility to force complete bootloader save (not save
  only if settings have changed - no UI change, only for other
  modules that need it)
- merged texts from final proofreading
- 2.7.12
* Fri Feb 28 2003 jsrain@suse.de
- updated the detection of changes of settings (#24422)
- 2.7.11
* Thu Feb 27 2003 jsrain@suse.de
- fixed ordering of bootloader options (#24420)
* Mon Feb 24 2003 jsrain@suse.de
- updated confirmation popup after bootloader is isntalled to
  floppy (#23903)
- fixed forgotten saving of cfg. files in some cases (#24073)
- in repair mode reading bootloader type from sysconfig, no probing
  (#24062)
- 2.7.10
* Fri Feb 21 2003 jsrain@suse.de
- fixed adding of memtest to bootloader menu (#23924)
- fixed help text and behaviour of password option popup (#23954)
- added support for easy updating initrd contents during system
  update (#23976)
- fixed setting focus in popups (#24050)
* Thu Feb 20 2003 jsrain@suse.de
- changed executing /sbin/mk_initrd -> /sbin/mkinitrd
- reorganized kernel parameters when using GRUB (#23829)
- fixed capitalization of YCC labels (#23848)
- 2.7.9
* Wed Feb 19 2003 jsrain@suse.de
- changed color of text-mode LILO menu - now is blue
- removed unwanted reseting of "disk" LILO option when reproposing
  configuraition - some systems could be unbootable with LILO
  without possibility to prevent it at installation time
- updated ydoc comments
- fixed conversion between GRUB and LILO (#23826)
* Mon Feb 17 2003 jsrain@suse.de
- added popup when bootloader saved to floppy (#23571)
- added extra stage in progress bar for reading disks partitioning
  (#23712)
- 2.7.8
* Fri Feb 14 2003 jsrain@suse.de
- added splash-screen's size parameter when calling mk_initrd
  (#23579)
* Thu Feb 13 2003 jsrain@suse.de
- fixed floppy entry in bootloader menu behaviour - if installing
  to floppy, hard disk is used instead (#23572)
* Mon Feb 10 2003 jsrain@suse.de
- fixed proposing with merging GRUB menus, resulted in doubled
  items (#23346)
- merged proofread texts from second and third round
- 2.7.7
* Wed Feb  5 2003 jsrain@suse.de
- fixed bootloader changing during installation (#20759)
- fixed list of locations to hold bootloader bootsector (#17320)
* Tue Feb  4 2003 jsrain@suse.de
- updates of autoinstallation
* Mon Feb  3 2003 jsrain@suse.de
- fixed NCurses usability - focus setting
- 2.7.6
* Fri Jan 31 2003 jsrain@suse.de
- not adding lvm groups and md disks to device map (#23217)
* Thu Jan 30 2003 jsrain@suse.cz
- fixed setting of vga= kernel parameter (#23188)
* Wed Jan 29 2003 jsrain@suse.de
- patched proofread texts
* Tue Jan 28 2003 jsrain@suse.de
- fixed compilation of MBR only on selected platforms
- 2.7.5
* Mon Jan 27 2003 jsrain@suse.de
- added new testsuites
- added missing translators comments
- added missing functions comments
- made Replace code in MBR function running
- 2.7.4
* Fri Jan 24 2003 jsrain@suse.de
- fixed too often blinking floppy
- fixed Changed column modifying
* Thu Jan 23 2003 jsrain@suse.de
- fixed fillup-template usage
- changed symbols in export map to strings because of
  autoinstallation
- 2.7.3
* Wed Jan 22 2003 jsrain@suse.de
- fixed meaningless log messages (#23025)
* Fri Jan 17 2003 jsrain@suse.de
- fixed detection of disks configuration changes that may decide to
  use other bootloader (#22918)
- updated S390 installation
- 2.7.2
* Fri Jan 10 2003 jsrain@suse.de
- fixed failsafe kernel parameters on i386 (#22539)
* Fri Dec 20 2002 jsrain@suse.de
- added documentation files
* Thu Dec 19 2002 jsrain@suse.de
- fixed path to elilo.conf (IA64 only affected) (#22502)
* Tue Dec 17 2002 jsrain@suse.de
- now using fillup-template for sysconfig/bootloader
* Fri Dec 13 2002 jsrain@suse.de
- fixed ordering of modules in initrd
- added function for changing write process settings
* Wed Dec 11 2002 jsrain@suse.de
- if something goes wrong during bootloader installation saving, it
  is now possible to fix configuration (#21076)
- possible to change section type an easy way (#19451)
- dialogs updates
- other updates and fixes
- adding sysconfig metadata
- 2.7.1
* Wed Dec  4 2002 jsrain@suse.cz
- Removed global variables from Liloagent, now able to be used at
  once for more bootloaders
- Added GRUB option types to LiloAgent
- Removed test mode and possible security problem from bootfloppy
  (#20962)
- Fixed several problems of LiloAgent
- Fixed ask for floppy popup (#10485)
- If no initrd created, GRUB's menu.lst doesn't contain it now
  (#21469)
- 2.7.0
* Tue Nov 19 2002 schwab@suse.de
- Use product name for EFI boot manager entry (#21879).
- Report error when boot loader installation fails.
* Wed Nov 13 2002 jsrain@suse.cz
- again fixed installing a kernel to *NWSSTG when root is on RAID
  on PPC (#21368)
- creating syntactically correct menu.lst file for GRUB, contents
  may be still incorrect on some servers (#20637)
- 2.6.66
* Tue Nov  5 2002 jsrain@suse.cz
- Bugfix - LTC1394 - FTP installation to root on LVM didn't install
  a kernel on PPC (#20933)
- 2.6.65
* Wed Oct 30 2002 kukuk@suse.de
- fix log path in dosilo script
- update_silo_conf: modify version number in /boot/message
- BootSILO.ycp: Don't show popup on success when installing silo
* Wed Oct 30 2002 kukuk@suse.de
- fix log path in dosilo script
- update_silo_conf: modify version number in /boot/message
- BootSILO.ycp: Don't show popup on success when installing silo
* Tue Oct 29 2002 jsrain@suse.cz
- fixed target dialog for x86-64 (#21258)
- fixed selecting a prep boot partition on the root drive on PPC
  (#21315)
- fixed installing a kernel to *NWSSTG when root is on RAID on PPC
  (#21368)
- 2.6.64
* Fri Oct 25 2002 arvin@suse.de
- log output of mk_initrd also on S390 (bug #21273)
- 2.6.63
* Mon Oct 14 2002 jsrain@suse.cz
- fixed activating of boot partition if not instaling bootloader
  (#20874)
- 2.6.62
* Fri Oct 11 2002 jsrain@suse.cz
- fixed security problem with permissions of /boot/grub/menu.lst
  (#20803)
- activating /boot partition if grub installed to mbr (part of
  [#20637])
- 2.6.61
* Thu Oct 10 2002 jsrain@suse.cz
- if bootloader which should be used is not selected for
  installation, backup one is installed on i386 and x86-64
  (grub instead of lilo and lilo instead of grub) (#20759)
* Wed Oct  9 2002 jsrain@suse.cz
- now not enabling 2 gettys on same serial line on p690 (#19788)
* Tue Oct  8 2002 jsrain@suse.cz
- fixed type in initrd modules ignore list for PPC (#20684)
- 2.6.59
* Mon Oct  7 2002 jsrain@suse.cz
- fixed activating boot method on PPC (#20407)
- fixed helptexts on PPC (#20605)
- fixed translating of PPC-specific strings
- 2.6.58
* Fri Oct  4 2002 jsrain@suse.cz
- added more comments to bootloader in sysconfig/bootloader (#20385)
- fixed restoring original configuration - could caused unbootable
  system (#20391)
- 2.6.57
* Wed Oct  2 2002 jsrain@suse.cz
- fixed update of lilo, resulted in corrupted lilo.conf (#20320)
- fixed errors reporting during bootloader update (#20321)
- fixed activating of initrd at update (#19643)
* Tue Oct  1 2002 jsrain@suse.cz
- fixed nasty trap in bootloader installation (now not reseting
  configuration without question) (#20073)
* Fri Sep 27 2002 jsrain@suse.cz
- applied patches for PPC (#20178 and #20205 - initrd modules list)
* Fri Sep 27 2002 lslezak@suse.cz
- fixed configuration reset at installation proposal
  if partitioning was changed (#20073)
- fixed failsafe options on x86-64 (removed disableapic,
  added iommu=noforce) (#19903)
* Tue Sep 24 2002 lslezak@suse.cz
- check if label already exists (in section edit),
  allow labels longer than 15 chars for grub (#19874)
- removed 'nosmp' from failsafe options on x86-64 (#19903)
- don't add rewritten other section to menu (#19990)
- version 2.6.56
* Tue Sep 17 2002 lslezak@suse.de
- fixed obsoleted help text in y2cc (#19466)
- version 2.6.55
* Fri Sep 13 2002 mvidner@suse.cz
- bootfloppy: enable asking the user for the CD (#19628).
- 2.6.54
* Fri Sep 13 2002 fehr@suse.de
- make supression of certain modules (cdrom and usb) work
- version 2.6.53
* Thu Sep 12 2002 lslezak@suse.cz
- do not regenerate device.map file at update (part of #19555)
- version 2.6.52
* Thu Sep 12 2002 fehr@suse.de
- fix to use lilo on update if there is no /etc/sysconfig/bootloader
  (#19558)
* Thu Sep 12 2002 lslezak@suse.cz
- add current kernel parameters to lilo.conf at update (#19415)
- added missing function DisplayLogFile to BootSILO.ycp, BootELILO.ycp
- version 2.6.51
* Thu Sep 12 2002 kkaempf@suse.de
- run mkinitrd on PPC if needed (#18276)
- 2.6.50
* Thu Sep 12 2002 kkaempf@suse.de
- exclude usb modules from initrd (#19432)
- 2.6.49
* Wed Sep 11 2002 lslezak@suse.cz
- don't change configuration if partitioning was changed
  and bootloader location is floppy (at installation proposal) (#19388)
- allow installation on extended partition (at installation) (#19184)
- version 2.6.48
* Tue Sep 10 2002 kkaempf@suse.de
- ppc bugfix #18849
- 2.6.47
* Tue Sep 10 2002 lslezak@suse.cz
- use lilo instead grub at update
- version 2.6.46
* Tue Sep 10 2002 fehr@suse.de
- fix root device detection of mk_lilo_conf
- change default mbr detection in Boot.ycp (#19117)
- prevent blanks in label in BootLILO.ycp (#19181)
- version 2.6.45
* Mon Sep  9 2002 lslezak@suse.cz
- allow installation on extended partion (#19184)
- version 2.6.44
* Mon Sep  9 2002 mvidner@suse.cz
- Replace whitespace (and nonprintable characters)
  in lilo section labels by an underscore (#19181).
- Properly use / or /boot/ in /boot/grub/menu.lst during upgrade (#19125).
- 2.6.43
* Sun Sep  8 2002 mvidner@suse.cz
- Fixed the testsuite.
- 2.6.42
* Sun Sep  8 2002 kkaempf@suse.de
- drop "make check" for the moment.
* Fri Sep  6 2002 kkaempf@suse.de
- workaround for hwinfo bug (#19071)
- 2.6.41
* Fri Sep  6 2002 jsrain@suse.cz
- fixed provides/obsoletes
- 2.6.40
* Fri Sep  6 2002 jsrain@suse.cz
- fixed deletion of cfg. file entries wjen using GRUB (Bug #18962)
- fixed rendering GRUB menu on installed system (Bug #18973)
- fixed handling of errors during bootlaoder installation
  (Bug #19020)
- 2.6.39
* Thu Sep  5 2002 kkaempf@suse.de
- properly check for update when determing boot type
- 2.6.38
* Thu Sep  5 2002 jsrain@suse.cz
- not calling Storage::UseLilo () in Boot module constructor
- 2.6.37
* Thu Sep  5 2002 schwab@suse.de
- Move elilo.conf to /boot/efi/SuSE.
* Wed Sep  4 2002 jsrain@suse.cz
- fixed bootfloppy function (Bug #17430)
- fixed checking for need to set active partition (Bug #18835)
- fixed reseting bootloader type after partitioning change
- fixed label of sections dialog (Bug #18877)
- 2.6.36
* Tue Sep  3 2002 kukuk@suse.de
- installation/src/silo/agents/update_silo_conf: New
  file, modifies silo.conf and boot/message if an update is done.
- installation/src/silo/BootSILO.ycp: Implement calling "dosilo"
  script.
- prom.cc: Add reg string if prom name exists at least once.
* Tue Sep  3 2002 jsrain@suse.cz
- fixed usage of Pkg::SourceProvideFile function
* Tue Sep  3 2002 jsrain@suse.cz
- if partitioning changes, resets bootloader location to MBR, only
  meaningful partitions possible as bootloader bootsector locations
  (Bug #18744)
- 2.6.35
* Mon Sep  2 2002 jsrain@suse.cz
- added reset function (for calling after partitioning changes
  during installation) (Bug #18744)
* Mon Sep  2 2002 jsrain@suse.cz
- updating prep boot partition during installation on PPC
  (Bug #18689)
- 2.6.34
* Fri Aug 30 2002 jsrain@suse.cz
- fixed bootfloppy creation (not yet tested) (Bug #17430)
- building fixed
- removed shadowed symbols (Bug #18622)
- 2.6.33
* Wed Aug 28 2002 kkaempf@suse.de
- fix checking for splashscreen
- 2.6.31
* Wed Aug 28 2002 jsrain@suse.cz
- fixed building on SPARC
- removed unneeded files from GRUB installation
- fixed boot floppies location
- fixed logging
- 2.6.32
* Tue Aug 27 2002 jsrain@suse.cz
- if no boot message exists not including in menu.lst (Bug #18381)
- fixed ordering of list of kernel images / other partitions
- 2.6.30
* Tue Aug 27 2002 nashif@suse.de
- do not reset location value in autoinst mode
- if location is not empty, configure boot device in autoinst
  mode (Avoid calling ConfigureLocation)
- 2.6.29
* Mon Aug 26 2002 jsrain@suse.cz
- removed icons from control center on S390 (Bugs #18371 and #18367)
- fixed curses UI buttons (Bug #18333)
- fixed handling of nonwritable floppy (Bug #18312)
- fixed PPC installation (Bug #18140)
- 2.6.28
* Fri Aug 23 2002 jsrain@suse.cz
- fixed lists of devices (Bug #18269)
- fixed installation on compaq disk array (Bug #18134)
- 2.6.27
* Tue Aug 20 2002 arvin@suse.de
- correctly handle hvc console on ppc
- 2.6.26
* Tue Aug 20 2002 jsrain@suse.cz
- fixed original configuration restore when using GRUB
- fixed partition list reading
- 2.6.25
* Mon Aug 19 2002 jsrain@suse.cz
- modified failsafe kernel image name for update of lilo
- fixed GRUB save after configuration
- not deleting old device map during installation
- /sbin/elilo now not running after configuration change
- 2.6.24
* Fri Aug 16 2002 jsrain@suse.cz
- added universal functions for accessing kernel parameters
  independent on bootloader
- modified failsafe kernel image name
- fixed kdoc comments
- merged proofread texts
- now building initrd on S390
- 2.6.23
* Tue Aug 13 2002 jsrain@suse.cz
- fixed handling different BIOS Ids (Bug #17594)
- added disableapic to failsafe kernel command
- 2.6.22
* Fri Aug  9 2002 jsrain@suse.de
- fixed installation on S390 (Bug #17244)
- 2.6.21
* Fri Aug  9 2002 jsrain@suse.de
- now setting framebuffer vga mode (Bug #17537)
- 2.6.20
* Thu Aug  8 2002 jsrain@suse.de
- fixed device name translation for GRUB during installation for
  other systems
- 2.6.19
* Wed Aug  7 2002 jsrain@suse.de
- Fix adaptation for multiple 'other' partitions for booting
  for GRUB (#17458)
- 2.6.18
* Wed Aug  7 2002 kkaempf@suse.de
- Allow for multiple 'other' partitions for booting (#17458)
* Wed Aug  7 2002 jsrain@suse.de
- added support for changing kernel command line for other modules
  when using GRUB easily
- 2.6.17
* Tue Aug  6 2002 jsrain@suse.de
- fixed abort button behaviour
- 2.6.16
* Tue Aug  6 2002 jsrain@suse.de
- fixed ordering of GRUB commands in menu.lst
- added expert configuration of /etc/grub.conf
- 2.6.15
* Mon Aug  5 2002 jsrain@suse.cz
- fixed lilo update problem (Bug #15819)
- fixed bootloader loaction dialog contents (Bug #17320)
* Mon Aug  5 2002 arvin@suse.de
- changes for new /etc/install.inf agent
* Mon Aug  5 2002 fehr@suse.de
- make BootS390.ycp work again (was broken after 8.0 changes)
- 2.6.13
* Thu Aug  1 2002 jsrain@suse.cz
- minor updates and fixes
- 2.6.12
* Tue Jul 30 2002 jsrain@suse.cz
- added comments for translators
* Tue Jul 30 2002 arvin@suse.de
- fixed configuration of grub
* Mon Jul 29 2002 jsrain@suse.cz
- added basic expert dialogs for GRUB
- several fixes
- 2.6.10
* Fri Jul 26 2002 jsrain@suse.cz
- fixed configuration of installed system for GRUB
- added password support for GRUB
- added boot from floppy support for GRUB
- 2.6.9
* Fri Jul 26 2002 jsrain@suse.cz
- added bootloader graphical screen support for GRUB
- added other OS during installation support for GRUB
- 2.6.8
* Thu Jul 25 2002 schwab@suse.de
- Fix doelilo script.
* Thu Jul 25 2002 jsrain@suse.cz
- added support for GRUB configuration on running system
- added support for installing GRUB during installation process
- fixed for lilo startup (#17142)
- 2.6.7
* Mon Jul 22 2002 kkaempf@suse.de
- prepare for GRUB support
* Wed Jul 17 2002 arvin@suse.de
- fixed file list for i386 (use %%ix86 macro)
* Fri Jul 12 2002 arvin@suse.de
- use proper namespace for Args and CallFunction (#16776)
* Mon Jul  8 2002 mvidner@suse.cz
- fixed Provides/Obsoletes (yast2-agent-liloconf)
* Thu Jul  4 2002 arvin@suse.de
- moved non binary files to /usr/share/YaST2
* Wed Jul  3 2002 lslezak@suse.cz
- fixed installation/src/ppc/agents/Makefile.am (ppc build bug)
- version 2.6.2
* Tue Jul  2 2002 lslezak@suse.cz
- merged with yast2-agent-lilo, yast2-agent-prom,
  yast2-config-bootfloppy and yast2 lilo installation part
- renamed to yast2-bootloader
- version 2.6.1
* Tue Jun 25 2002 lslezak@suse.cz
- addded editor for expert user
- changed ABC::`abc -> ABC::abc
- version 2.6.0
* Thu Apr 11 2002 lslezak@suse.cz
- SuSE-8_0-Branch merged to the head
* Thu Mar 21 2002 mvidner@suse.cz
- Obsoletes yast2-config-bootloader. (#15135)
- 2.5.13
* Fri Mar 15 2002 dmeszar@suse.cz
- fixed #14935 (can't close with WM)
* Mon Mar  4 2002 dmeszar@suse.cz
- fixed bug #14100 (main dialog not hiden when exiting)
- screenshot mode implemented
* Mon Feb 18 2002 dmeszar@suse.cz
- fixed bug #13505 (incomplete label "Uninstall boot loader from"->
  device name is missing)
- fixed bug #13524 (broken writing of special lilo options
  (like change-rules, disk, map-drive...)
* Mon Feb 11 2002 dmeszar@suse.cz
- fixed restoring original settings from installation
* Tue Feb  5 2002 dmeszar@suse.cz
- implemented section order changing
* Mon Jan 28 2002 dmeszar@suse.cz
- don't read 'user_settings'
* Wed Jan 23 2002 dmeszar@suse.cz
- fixed rpm dependencied
* Fri Jan 11 2002 dmeszar@suse.cz
- fixed original lilo.conf restoring
* Sat Dec 22 2001 dmeszar@suse.cz
- autoinstallation adaptation
- installed linux's scanner
- 3rd param for 'select', fixed specfile
* Fri Nov  9 2001 dmeszar@suse.cz
- major ui changes- new startup dialog, sequence changed
- addaptation for installation
* Thu Sep 20 2001 dmeszar@suse.cz
- module icon changed to 'boot.png' ;)
* Tue Sep 18 2001 dmeszar@suse.cz
- module icon changed to 'lilo.png' (#10656)
* Mon Sep 17 2001 dmeszar@suse.cz
- bug #10661 fixed (lilo configuration written without change !!)
- bug #10667 fixed (No section is marked as default, if there is the
    keyword 'default' missing in the lilo.conf.)
* Thu Sep 13 2001 kendy@suse.cz
- Write the lilo.conf first and then run lilo (not in the reverse
  order...)
- Some unused code removed, lilo_write.ycp is not distributed.
* Mon Sep 10 2001 dmeszar@suse.cz
- use Arch:: instead of user_settings
* Tue Sep  4 2001 dmeszar@suse.cz
- fix #10062
- fixed the qt-IntField update bug (after creation of
  dialog the intfield doesn't show its actual value
  but shows 0 under qt)
* Fri Aug 31 2001 dmeszar@suse.cz
- use 'Add other section' radio button instead of 'add windows/os2 section'
  for sparcs
- removed debug logging
* Mon Aug 27 2001 dmeszar@suse.cz
- removed 'uninstall silo', 'install to boot/root' for sparcs
- sparc: if kernel image's path is /'kernel', add '/boot' as prefix
  when checking the kernel existence and description
* Mon Aug 20 2001 dmeszar@suse.cz
- fixed section label displaying in summary table ("section label" - > section label)
* Mon Aug 13 2001 dmeszar@suse.cz
- fixed description for other sections in summary table
* Wed Aug  8 2001 dmeszar@suse.cz
- correct handling od '\' '"' chars when reading ui input fields
- fixed 'other' section removing
- section quota set to 16
* Tue Jul 31 2001 dmeszar@suse.cz
- uninstall ability implemnted
- section removing fixed
- don't show 'image' option in options list of image/other section
- help text for options stripped to minimal acceptable extent
- options dialog layout changes
- option editing dialog added
* Mon Jul 30 2001 dmeszar@suse.cz
- save confirm dialog added
* Thu Jul 26 2001 dmeszar@suse.cz
- proof-read texts, platform dependent code added
* Thu Mar 22 2001 dmeszar@suse.cz
- initial version
